aair	http://xmlns.notu.be/aair#	20111028
aapi	http://rdf.alchemyapi.com/rdf/v1/s/aapi-schema#	20111028
abc	http://www.metadata.net/harmony/ABCSchemaV5Commented.rdf#	20111028
ac	http://umbel.org/umbel/ac/	20111028
acc	http://purl.org/NET/acc#	20111028
acl	http://www.w3.org/ns/auth/acl#	20111028
acm	http://www.rkbexplorer.com/ontologies/acm#	20111028
act	http://www.w3.org/2007/rif-builtin-action#	20111028
ad	http://schemas.talis.com/2005/address/schema#	20111028
address	http://schemas.talis.com/2005/address/schema#	20111028
admin	http://webns.net/mvcb/	20111028
admingeo	http://data.ordnancesurvey.co.uk/ontology/admingeo/	20111028
af	http://purl.org/ontology/af/	20111028
affy	http://www.affymetrix.com/community/publications/affymetrix/tmsplice#	20111028
afn	http://jena.hpl.hp.com/ARQ/function#	20111028
agent	http://eulersharp.sourceforge.net/2003/03swap/agent#	20111028
agents	http://eulersharp.sourceforge.net/2003/03swap/agent#	20111028
agetec	http://www.agetec.org/	20111028
aifb	http://www.aifb.kit.edu/id/	20111028
aiiso	http://purl.org/vocab/aiiso/schema#	20111028
aims	http://aims.fao.org/aos/common/	20111028
air	http://dig.csail.mit.edu/TAMI/2007/amord/air#	20111028
airport	http://www.daml.org/2001/10/html/airport-ont#	20111028
akt	http://www.aktors.org/ontology/portal#	20111028
akts	http://www.aktors.org/ontology/support#	20111028
am	http://vocab.deri.ie/am#	20111028
anca	http://users.utcluj.ro/~raluca/rdf_ontologies_ralu/ralu_modified_ontology_pizzas2_0#	20111028
aneo	http://akonadi-project.org/ontologies/aneo#	20111028
ann	http://www.w3.org/2000/10/annotation-ns#	20111028
ao	http://purl.org/ontology/ao/core#	20111028
arch	http://purl.org/archival/vocab/arch#	20111028
artstor	http://simile.mit.edu/2003/10/ontologies/artstor#	20111028
ass	http://uptheasset.org/ontology#	20111028
atom	http://www.w3.org/2005/Atom/	20111028
atomix	http://buzzword.org.uk/rdf/atomix#	20111028
atomowl	http://bblfish.net/work/atom-owl/2006-06-06/#	20111028
audio	http://purl.org/media/audio#	20111028
awol	http://bblfish.net/work/atom-owl/2006-06-06/#	20111028
b2rpubchem	http://bio2rdf.org/ns/ns/ns/pubchem#	20111028
bcnbio	http://datos.bcn.cl/ontologies/bcn-biographies#	20111028
bcncon	http://datos.bcn.cl/ontologies/bcn-congress#	20111028
bcngeo	http://datos.bcn.cl/ontologies/bcn-geographics#	20111028
bcnnorms	http://datos.bcn.cl/ontologies/bcn-norms#	20111028
bib	http://zeitkunst.org/bibtex/0.1/bibtex.owl#	20111028
biblio	http://purl.org/net/biblio#	20111028
bibo	http://purl.org/ontology/bibo/	20111028
bibtex	http://purl.oclc.org/NET/nknouf/ns/bibtex#	20111028
bill	http://www.rdfabout.com/rdf/schema/usbill/	20111028
bio	http://purl.org/vocab/bio/0.1/	20111028
bio2rdf	http://bio2rdf.org/	20111028
biocore	http://bio2rdf.org/core:	20111028
biol	http://purl.org/NET/biol/ns#	20111028
biordf	http://purl.org/net/biordfmicroarray/ns#	20111028
bioskos	http://eulersharp.sourceforge.net/2003/03swap/bioSKOSSchemes#	20111028
blt	http://data.bl.uk/schema/bibliographic#	20111028
book	http://purl.org/NET/book/vocab#	20111028
bookmark	http://www.w3.org/2002/01/bookmark#	20111028
botany	http://purl.org/NET/biol/botany#	20111028
bsbm	http://www4.wiwiss.fu-berlin.de/bizer/bsbm/v01/vocabulary/	20111028
c4dm	http://purl.org/NET/c4dm/event.owl#	20111028
c4n	http://vocab.deri.ie/c4n#	20111028
c4o	http://purl.org/spar/c4o/	20111028
cal	http://www.w3.org/2002/12/cal/ical#	20111028
campsite	http://www.openlinksw.com/campsites/schema#	20111028
card	http://www.ashutosh.com/test/	20111028
care	http://eulersharp.sourceforge.net/2003/03swap/care#	20111028
cbase	http://ontologycentral.com/2010/05/cb/vocab#	20111028
cc	http://creativecommons.org/ns#	20111028
ccard	http://purl.org/commerce/creditcard#	20111028
cco	http://purl.org/ontology/cco/core#	20111028
ccom	http://purl.org/ontology/cco/mappings#	20111028
cdm	http://purl.org/twc/ontology/cdm.owl#	20111028
ceo	http://www.ebusiness-unibw.org/ontologies/consumerelectronics/v1#	20111028
cert	http://www.w3.org/ns/auth/cert#	20111028
cfp	http://sw.deri.org/2005/08/conf/cfp.owl#	20111028
chebi	http://bio2rdf.org/chebi:	20111028
chord	http://purl.org/ontology/chord/	20111028
cito	http://purl.org/net/cito/	20111028
cld	http://purl.org/cld/terms/	20111028
climb	http://climb.dataincubator.org/vocabs/climb/	20111028
clineva	http://www.agfa.com/w3c/2009/clinicalEvaluation#	20111028
clinproc	http://www.agfa.com/w3c/2009/clinicalProcedure#	20111028
cmo	http://purl.org/twc/ontologies/cmo.owl#	20111028
cmp	http://www.ontologydesignpatterns.org/cp/owl/componency.owl#	20111028
cnt	http://www.w3.org/2008/content#	20111028
co	http://purl.org/ontology/co/core#	20111028
code	http://telegraphis.net/ontology/measurement/code#	20111028
coeus	http://bioinformatics.ua.pt/coeus/	20111028
coin	http://purl.org/court/def/2009/coin#	20111028
com	http://purl.org/commerce#	20111028
commerce	http://purl.org/commerce#	20111028
common	http://www.w3.org/2007/uwa/context/common.owl#	20111028
commons	http://commons.psi.enakting.org/def/	20111028
compass	http://purl.org/net/compass#	20111028
con	http://www.w3.org/2000/10/swap/pim/contact#	20111028
conserv	http://conserv.deri.ie/ontology#	20111028
contact	http://www.w3.org/2000/10/swap/pim/contact#	20111028
content	http://purl.org/rss/1.0/modules/content/	20111028
conv	http://purl.org/twc/vocab/conversion/	20111028
conversion	http://purl.org/twc/vocab/conversion/	20111028
coo	http://purl.org/coo/ns#	20111028
copyright	http://rhizomik.net/ontologies/2008/05/copyrightonto.owl#	20111028
cordis	http://www4.wiwiss.fu-berlin.de/cordis/resource/cordis/	20111028
core	http://vivoweb.org/ontology/core#	20111028
coref	http://www.rkbexplorer.com/ontologies/coref#	20111028
cos	http://www.inria.fr/acacia/corese#	20111028
countries	http://eulersharp.sourceforge.net/2003/03swap/countries#	20111028
courseware	http://courseware.rkbexplorer.com/ontologies/courseware#	20111028
cpm	http://catalogus-professorum.org/cpm/	20111028
cpv	http://purl.org/weso/cpv/	20111028
crm	http://purl.org/NET/cidoc-crm/core#	20111028
crypto	http://www.w3.org/2000/10/swap/crypto#	20111028
cs	http://purl.org/vocab/changeset/schema#	20111028
ct	http://data.linkedct.org/resource/linkedct/	20111028
ctag	http://commontag.org/ns#	20111028
cube	http://purl.org/linked-data/cube#	20111028
custom	http://www.openrdf.org/config/sail/custom#	20111028
cv	http://rdfs.org/resume-rdf/	20111028
cvbase	http://purl.org/captsolo/resume-rdf/0.2/base#	20111028
cyc	http://sw.opencyc.org/concept/	20111028
cycann	http://sw.cyc.com/CycAnnotations_v1#	20111028
d2rq	http://www.wiwiss.fu-berlin.de/suhl/bizer/D2RQ/0.1#	20111028
dady	http://purl.org/NET/dady#	20111028
daia	http://purl.org/ontology/daia/	20111028
dailymed	http://www4.wiwiss.fu-berlin.de/dailymed/resource/dailymed/	20111028
daml	http://www.daml.org/2001/03/daml+oil#	20111028
dawgt	http://www.w3.org/2001/sw/DataAccess/tests/test-dawg#	20111028
days	http://ontologi.es/days#	20111028
dayta	http://dayta.me/resource#	20111028
dblp	http://www4.wiwiss.fu-berlin.de/dblp/terms.rdf#	20111028
dbo	http://dbpedia.org/ontology/	20111028
dbp	http://dbpedia.org/property/	20111028
dbpedia	http://dbpedia.org/resource/	20111028
dbpediaowl	http://dbpedia.org/ontology/	20111028
dbpp	http://dbpedia.org/property/	20111028
dbpprop	http://dbpedia.org/property/	20111028
dbprop	http://dbpedia.org/property/	20111028
dbptmpl	http://dbpedia.org/resource/Template:	20111028
dbr	http://dbpedia.org/resource/	20111028
dc	http://purl.org/dc/elements/1.1/	20111028
dc11	http://purl.org/dc/elements/1.1/	20111028
dcam	http://purl.org/dc/dcam/	20111028
dcat	http://www.w3.org/ns/dcat#	20111028
dcmit	http://purl.org/dc/dcmitype/	20111028
dcmitype	http://purl.org/dc/dcmitype/	20111028
dcn	http://www.w3.org/2007/uwa/context/deliverycontext.owl#	20111028
dcq	http://purl.org/dc/terms/	20111028
dct	http://purl.org/dc/terms/	20111028
dcterm	http://purl.org/dc/terms/	20111028
dcterms	http://purl.org/dc/terms/	20111028
dctype	http://purl.org/dc/dcmitype/	20111028
ddc	http://purl.org/NET/decimalised#	20111028
ddl	http://purl.org/vocab/riro/ddl#	20111028
decl	http://www.linkedmodel.org/1.0/schema/decl#	20111028
derecho	http://purl.org/derecho#	20111028
dgfoaf	http://west.uni-koblenz.de/ontologies/2010/07/dgfoaf.owl#	20111028
dgtwc	http://data-gov.tw.rpi.edu/2009/data-gov-twc.rdf#	20111028
dir	http://schemas.talis.com/2005/dir/schema#	20111028
disease	http://www.agfa.com/w3c/2009/humanDisorder#	20111028
diseasome	http://www4.wiwiss.fu-berlin.de/diseasome/resource/diseasome/	20111028
dnr	http://www.dotnetrdf.org/configuration#	20111028
doac	http://ramonantonio.net/doac/0.1/#	20111028
doap	http://usefulinc.com/ns/doap#	20111028
doc	http://www.w3.org/2000/10/swap/pim/doc#	20111028
doclist	http://www.junkwork.net/xml/DocumentList#	20111028
drug	http://www.agfa.com/w3c/2009/drugTherapy#	20111028
drugbank	http://www4.wiwiss.fu-berlin.de/drugbank/resource/drugbank/	20111028
dtype	http://www.linkedmodel.org/schema/dtype#	20111028
dul	http://www.loa-cnr.it/ontologies/DUL.owl#	20111028
dummy	http://hello.com/	20111028
dv	http://rdf.data-vocabulary.org/#	20111028
ean	http://openean.kaufkauf.net/id/	20111028
earl	http://www.w3.org/ns/earl#	20111028
eat	http://www.awesomesauce.net/urmom/	20111028
eco	http://www.ebusiness-unibw.org/ontologies/eclass/5.1.4/#	20111028
ecs	http://rdf.ecs.soton.ac.uk/ontology/ecs#	20111028
edam	http://purl.bioontology.org/ontology/EDAM/	20111028
edm	http://www.europeana.eu/schemas/edm/	20111028
eg	http://eulergui.sourceforge.net/engine.owl#	20111028
elog	http://eulersharp.sourceforge.net/2003/03swap/log-rules#	20111028
enc	http://www.w3.org/2001/04/xmlenc#	20111028
environ	http://eulersharp.sourceforge.net/2003/03swap/environment#	20111028
es	http://eulersharp.sourceforge.net/2003/03swap/log-rules#	20111028
esd	http://def.esd.org.uk/	20111028
eu	http://eulersharp.sourceforge.net/2003/03swap/log-rules#	20111028
eui	http://institutions.publicdata.eu/#	20111028
event	http://purl.org/NET/c4dm/event.owl#	20111028
events	http://eulersharp.sourceforge.net/2003/03swap/event#	20111028
evopat	http://ns.aksw.org/Evolution/	20111028
evset	http://dsnotify.org/vocab/eventset/0.1/	20111028
ex	http://example.com/	20111028
exif	http://www.w3.org/2003/12/exif/ns#	20111028
eye	http://jena.hpl.hp.com/Eyeball#	20111028
ezcontext	http://ontologies.ezweb.morfeo-project.org/ezcontext/ns#	20111028
eztag	http://ontologies.ezweb.morfeo-project.org/eztag/ns#	20111028
fab	http://purl.org/fab/ns#	20111028
fabio	http://purl.org/spar/fabio#	20111028
factbook	http://www4.wiwiss.fu-berlin.de/factbook/ns#	20111028
fb	http://rdf.freebase.com/ns/	20111028
fc	http://www.freeclass.eu/freeclass_v1#	20111028
fct	http://openlinksw.com/services/facets/1.0/	20111028
fec	http://www.rdfabout.com/rdf/schema/usfec/	20111028
fed	http://www.openrdf.org/config/sail/federation#	20111028
fingal	http://vocab.deri.ie/fingal#	20111028
fn	http://www.w3.org/2005/xpath-functions#	20111028
foaf	http://xmlns.com/foaf/0.1/	20111028
formats	http://www.w3.org/ns/formats/	20111028
frbr	http://purl.org/vocab/frbr/core#	20111028
frbrcore	http://purl.org/vocab/frbr/core#	20111028
frbre	http://purl.org/vocab/frbr/extended#	20111028
freebase	http://rdf.freebase.com/ns/	20111028
fresnel	http://www.w3.org/2004/09/fresnel#	20111028
frir	http://purl.org/twc/ontology/frir.owl#	20111028
game	http://data.totl.net/game/	20111028
gazetteer	http://data.ordnancesurvey.co.uk/ontology/50kGazetteer/	20111028
gbv	http://purl.org/ontology/gbv/	20111028
gc	http://www.oegov.org/core/owl/gc#	20111028
gd	http://rdf.data-vocabulary.org/#	20111028
gelo	http://krauthammerlab.med.yale.edu/ontologies/gelo#	20111028
gen	http://www.w3.org/2006/gen/ont#	20111028
genab	http://eulersharp.sourceforge.net/2003/03swap/genomeAbnormality#	20111028
geo	http://www.w3.org/2003/01/geo/wgs84_pos#	20111028
geodata	http://sws.geonames.org/	20111028
geoes	http://geo.linkeddata.es/resource/	20111028
geographis	http://telegraphis.net/ontology/geography/geography#	20111028
geonames	http://www.geonames.org/ontology#	20111028
geospecies	http://rdf.geospecies.org/ont/geospecies#	20111028
geovocab	http://geovocab.org/	20111028
gesis	http://lod.gesis.org/lodpilot/ALLBUS/vocab.rdf#	20111028
giving	http://ontologi.es/giving#	20111028
gml	http://www.opengis.net/gml/	20111028
gn	http://www.geonames.org/ontology#	20111028
go	http://www.geneontology.org/go#	20111028
gob	http://purl.org/ontology/last-fm/	20111028
gold	http://purl.org/linguistics/gold/	20111028
govtrackus	http://www.rdfabout.com/rdf/usgov/geo/us/	20111028
govwild	http://govwild.org/ontology/GWOntology.owl#	20111028
gpt	http://purl.org/vocab/riro/gpt#	20111028
gr	http://purl.org/goodrelations/v1#	20111028
granatum	http://chem.deri.ie/granatum/	20111028
grddl	http://www.w3.org/2003/g/data-view#	20111028
greg	http://kasei.us/about/foaf.xrdf#	20111028
gridworks	http://purl.org/net/opmv/types/gridworks#	20111028
gv	http://rdf.data-vocabulary.org/#	20111028
h5	http://buzzword.org.uk/rdf/h5#	20111028
hard	http://www.w3.org/2007/uwa/context/hardware.owl#	20111028
harrisons	http://harrisons.cc/	20111028
hartigprov	http://purl.org/net/provenance/ns#	20111028
hcard	http://purl.org/uF/hCard/terms/	20111028
hcterms	http://purl.org/uF/hCard/terms/	20111028
healthcare	http://www.agfa.com/w3c/2009/healthCare#	20111028
hemogram	http://www.agfa.com/w3c/2009/hemogram#	20111028
hints2005	http://purl.org/twc/cabig/model/HINTS2005-1.owl#	20111028
hlisting	http://sindice.com/hlisting/0.1/	20111028
hospital	http://www.agfa.com/w3c/2009/hospital#	20111028
http	http://www.w3.org/2006/http#	20111028
httph	http://www.w3.org/2007/ont/httph#	20111028
httpvoc	http://www.w3.org/2006/http#	20111028
human	http://eulersharp.sourceforge.net/2003/03swap/human#	20111028
humanbody	http://eulersharp.sourceforge.net/2003/03swap/humanBody#	20111028
iao	http://purl.obolibrary.org/obo/iao.owl#	20111028
ibis	http://purl.org/ibis#	20111028
ical	http://www.w3.org/2002/12/cal/ical#	20111028
imm	http://schemas.microsoft.com/imm/	20111028
imreg	http://www.w3.org/2004/02/image-regions#	20111028
infection	http://www.agfa.com/w3c/2009/infectiousDisorder#	20111028
ir	http://www.ontologydesignpatterns.org/cp/owl/informationrealization.owl#	20111028
ire	http://www.ontologydesignpatterns.org/cpont/ire.owl#	20111028
iron	http://purl.org/ontology/iron#	20111028
irrl	http://www.ontologydesignpatterns.org/cp/owl/informationobjectsandrepresentationlanguages.owl#	20111028
irw	http://www.ontologydesignpatterns.org/ont/web/irw.owl#	20111028
is	http://purl.org/ontology/is/core#	20111028
isi	http://purl.org/ontology/is/inst/	20111028
isq	http://purl.org/ontology/is/quality/	20111028
ist	http://purl.org/ontology/is/types/	20111028
iswc	http://annotation.semanticweb.org/2004/iswc#	20111028
java	http://www.w3.org/2007/uwa/context/java.owl#	20111028
jdbc	http://d2rq.org/terms/jdbc/	20111028
kb	http://deductions.sf.net/ontology/knowledge_base.owl#	20111028
kontakt	http://richard.cyganiak.de/	20111028
kw	http://kwantu.net/kw/	20111028
kwijibo	http://kwijibo.talis.com/	20111028
label	http://purl.org/net/vocab/2004/03/label#	20111028
lang	http://ontologi.es/lang/core#	20111028
languages	http://eulersharp.sourceforge.net/2003/03swap/languages#	20111028
lark1	http://users.utcluj.ro/~raluca/ontology/Ontology1279614123500.owl#	20111028
lastfm	http://purl.org/ontology/last-fm/	20111028
ldap	http://purl.org/net/ldap/	20111028
lfm	http://purl.org/ontology/last-fm/	20111028
lfn	http://www.dotnetrdf.org/leviathan#	20111028
lgd	http://linkedgeodata.org/ontology/	20111028
lgdo	http://linkedgeodata.org/ontology/	20111028
lgv	http://linkedgeodata.org/ontology/	20111028
lib	http://schemas.talis.com/2005/library/schema#	20111028
lifecycle	http://purl.org/vocab/lifecycle/schema#	20111028
like	http://ontologi.es/like#	20111028
lingvoj	http://www.lingvoj.org/ontology#	20111028
link	http://www.w3.org/2006/link#	20111028
linkedct	http://data.linkedct.org/resource/linkedct/	20111028
linkedmdb	http://data.linkedmdb.org/sparql/	20111028
list	http://www.w3.org/2000/10/swap/list#	20111028
loc	http://www.w3.org/2007/uwa/context/location.owl#	20111028
lod2	http://lod2.eu/schema/	20111028
lodac	http://lod.ac/ns/lodac#	20111028
lode	http://linkedevents.org/ontology/	20111028
log	http://www.w3.org/2000/10/swap/log#	20111028
lom	http://ltsc.ieee.org/rdf/lomv1p0/lom#	20111028
lomvoc	http://ltsc.ieee.org/rdf/lomv1p0/vocabulary#	20111028
lotico	http://www.lotico.com/resource/	20111028
loticoowl	http://www.lotico.com/ontology/	20111028
lp	http://launchpad.net/rdf/launchpad#	20111028
lt	http://diplomski.nelakolundzija.org/LTontology.rdf#	20111028
lvont	http://lexvo.org/ontology#	20111028
lx	http://purl.org/NET/lx#	20111028
ma	http://www.w3.org/ns/ma-ont#	20111028
madsrdf	http://www.loc.gov/mads/rdf/v1#	20111028
malignneo	http://www.agfa.com/w3c/2009/malignantNeoplasm#	20111028
math	http://www.w3.org/2000/10/swap/math#	20111028
media	http://purl.org/media#	20111028
meetup	http://www.lotico.com/meetup/	20111028
mei	http://www.music-encoding.org/ns/mei/	20111028
memo	http://ontologies.smile.deri.ie/2009/02/27/memo#	20111028
meta	http://www.openrdf.org/rdf/2009/metadata#	20111028
meteo	http://purl.org/ns/meteo#	20111028
mf	http://poshrdf.org/ns/mf#	20111028
mit	http://purl.org/ontology/mo/mit#	20111028
mo	http://purl.org/ontology/mo/	20111028
moat	http://moat-project.org/ns#	20111028
money	http://purl.org/net/rdf-money/	20111028
movie	http://data.linkedmdb.org/resource/movie/	20111028
ms	http://purl.org/obo/owl/MS#	20111028
mte	http://nl.ijs.si/ME/owl/	20111028
mtecore	http://purl.org/olia/mte/multext-east.owl#	20111028
mu	http://www.kanzaki.com/ns/music#	20111028
muo	http://purl.oclc.org/NET/muo/muo#	20111028
music	http://musicontology.com/	20111028
musim	http://purl.org/ontology/similarity/	20111028
mygrid	http://www.mygrid.org.uk/ontology#	20111028
myspace	http://purl.org/ontology/myspace#	20111028
myspo	http://purl.org/ontology/myspace#	20111028
mysql	http://web-semantics.org/ns/mysql/	20111028
name	http://example.org/name#	20111028
nao	http://www.semanticdesktop.org/ontologies/2007/08/15/nao#	20111028
ncal	http://www.semanticdesktop.org/ontologies/2007/04/02/ncal#	20111028
nco	http://www.semanticdesktop.org/ontologies/2007/03/22/nco#	20111028
ne	http://umbel.org/umbel/ne/	20111028
net	http://www.w3.org/2007/uwa/context/network.owl#	20111028
nexif	http://www.semanticdesktop.org/ontologies/2007/05/10/nexif#	20111028
nfo	http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#	20111028
ngeo	http://geovocab.org/geometry#	20111028
nid3	http://www.semanticdesktop.org/ontologies/2007/05/10/nid3#	20111028
nie	http://www.semanticdesktop.org/ontologies/2007/01/19/nie#	20111028
nmo	http://www.semanticdesktop.org/ontologies/2007/03/22/nmo#	20111028
nndsr	http://semanticdiet.com/schema/usda/nndsr/	20111028
nocal	http://vocab.deri.ie/nocal#	20111028
nrl	http://www.semanticdesktop.org/ontologies/2007/08/15/nrl#	20111028
nsa	http://multimedialab.elis.ugent.be/organon/ontologies/ninsuna#	20111028
nt	http://ns.inria.fr/nicetag/2010/09/09/voc#	20111028
nuts	http://nuts.psi.enakting.org/id/BE335/doc/	20111028
nytimes	http://data.nytimes.com/elements/	20111028
oat	http://openlinksw.com/schemas/oat/	20111028
oauth	http://demiblog.org/vocab/oauth#	20111028
obj	http://www.openrdf.org/rdf/2009/object#	20111028
obo	http://purl.obolibrary.org/obo/	20111028
oboro	http://obofoundry.org/ro/ro.owl#	20111028
oboso	http://purl.org/obo/owl/SO#	20111028
oc	http://opencoinage.org/rdf/	20111028
odp	http://ontologydesignpatterns.org/	20111028
og	http://opengraphprotocol.org/schema/	20111028
ogp	http://ogp.me/ns#	20111028
ok	http://okkam.org/terms#	20111028
okkam	http://models.okkam.org/ENS-core-vocabulary#	20111028
olia	http://purl.org/olia/olia.owl#	20111028
olo	http://purl.org/ontology/olo/core#	20111028
omb	http://purl.org/ontomedia/ext/common/being#	20111028
omc	http://purl.org/ontomedia/ext/common/bestiary#	20111028
ome	http://purl.org/ontomedia/core/expression#	20111028
omm	http://purl.org/ontomedia/core/media#	20111028
omp	http://purl.org/ontomedia/ext/common/profession#	20111028
omt	http://purl.org/ontomedia/ext/common/trait#	20111028
oo	http://purl.org/openorg/	20111028
openlinks	http://www.openlinksw.com/schemas/virtrdf#	20111028
opensearch	http://a9.com/-/spec/opensearch/1.1/	20111028
oper	http://sweet.jpl.nasa.gov/2.0/mathOperation.owl#	20111028
opm	http://openprovenance.org/ontology#	20111028
opmv	http://purl.org/net/opmv/ns#	20111028
opo	http://online-presence.net/opo/ns#	20111028
opus	http://lsdis.cs.uga.edu/projects/semdis/opus#	20111028
opwn	http://www.ontologyportal.org/WordNet.owl#	20111028
ore	http://www.openarchives.org/ore/terms/	20111028
org	http://www.w3.org/ns/org#	20111028
organism	http://eulersharp.sourceforge.net/2003/03swap/organism#	20111028
organiz	http://eulersharp.sourceforge.net/2003/03swap/organization#	20111028
os	http://www.w3.org/2000/10/swap/os#	20111028
osag	http://www.ordnancesurvey.co.uk/ontology/AdministrativeGeography/v2.0/AdministrativeGeography.rdf#	20111028
osgb	http://data.ordnancesurvey.co.uk/id/	20111028
osoc	http://web-semantics.org/ns/opensocial#	20111028
osukdt	http://www.ordnancesurvey.co.uk/ontology/Datatypes.owl#	20111028
out	http://ontologies.hypios.com/out#	20111028
ov	http://open.vocab.org/terms/	20111028
overheid	http://standaarden.overheid.nl/owms/	20111028
owl	http://www.w3.org/2002/07/owl#	20111028
owlim	http://www.ontotext.com/trree/owlim#	20111028
owls	http://www.daml.org/services/owl-s/1.2/Service.owl#	20111028
owlse	http://www.daml.org/services/owl-s/1.2/generic/Expression.owl#	20111028
p20	http://zbw.eu/beta/p20/vocab/	20111028
p3p	http://www.w3.org/2002/01/p3prdfv1#	20111028
payment	http://reference.data.gov.uk/def/payment#	20111028
pbo	http://purl.org/ontology/pbo/core#	20111028
pc	http://purl.org/opendata-cz/public-contracts#	20111028
pdo	http://ontologies.smile.deri.ie/pdo#	20111028
pgterms	http://www.gutenberg.org/2009/pgterms/	20111028
phil	http://philosurfical.open.ac.uk/ontology/philosurfical.owl/	20111028
phss	http://ns.poundhill.com/phss/1.0/	20111028
pimo	http://www.semanticdesktop.org/ontologies/2007/11/01/pimo#	20111028
ping	http://purl.org/net/pingback/	20111028
place	http://purl.org/ontology/places/	20111028
play	http://uriplay.org/spec/ontology/#	20111028
plink	http://buzzword.org.uk/rdf/personal-link-types#	20111028
pmlj	http://inference-web.org/2.0/pml-justification.owl#	20111028
pmlp	http://inference-web.org/2.0/pml-provenance.owl#	20111028
pmlr	http://inference-web.org/2.0/pml-relation.owl#	20111028
pmlt	http://inference-web.org/2.0/pml-trust.owl#	20111028
pmt	http://tipsy.googlecode.com/svn/trunk/vocab/pmt#	20111028
pns	http://data.press.net/ontology/stuff/	20111028
po	http://purl.org/ontology/po/	20111028
pobo	http://purl.obolibrary.org/obo/	20111028
pois	http://purl.oclc.org/POIS/vcblr#	20111028
politico	http://www.rdfabout.com/rdf/schema/politico/	20111028
pom	http://maven.apache.org/POM/4.0.0#	20111028
pos	http://www.w3.org/2003/01/geo/wgs84_pos#	20111028
posh	http://poshrdf.org/ns/posh/	20111028
postcode	http://data.ordnancesurvey.co.uk/id/postcodeunit/	20111028
powder	http://www.w3.org/2007/05/powder#	20111028
ppo	http://vocab.deri.ie/ppo#	20111028
pr	http://ontologi.es/profiling#	20111028
prism	http://prismstandard.org/namespaces/1.2/basic/	20111028
prissma	http://ns.inria.fr/prissma/v1#	20111028
prj	http://purl.org/stuff/project/	20111028
product	http://purl.org/commerce/product#	20111028
profiling	http://ontologi.es/profiling#	20111028
prog	http://purl.org/prog/	20111028
prot	http://www.proteinontology.info/po.owl#	20111028
protege	http://protege.stanford.edu/system#	20111028
protons	http://proton.semanticweb.org/2005/04/protons#	20111028
prov	http://dvcs.w3.org/hg/prov/raw-file/tip/ontology/ProvenanceOntology.owl#	20111028
provenir	http://knoesis.wright.edu/provenir/provenir.owl#	20111028
prv	http://purl.org/net/provenance/ns#	20111028
prvr	http://purl.org/ontology/prv/rules#	20111028
prvtypes	http://purl.org/net/provenance/types#	20111028
ps	http://purl.org/payswarm#	20111028
psh	http://psh.techlib.cz/skos/	20111028
psych	http://purl.org/vocab/psychometric-profile/	20111028
pto	http://www.productontology.org/id/	20111028
ptr	http://www.w3.org/2009/pointers#	20111028
puc	http://purl.org/NET/puc#	20111028
puelia	http://kwijibo.talis.com/vocabs/puelia#	20111028
push	http://www.w3.org/2007/uwa/context/push.owl#	20111028
qb	http://purl.org/linked-data/cube#	20111028
qdoslf	http://foaf.qdos.com/lastfm/schema/	20111028
quak	http://dev.w3.org/cvsweb/2000/quacken/vocab#	20111028
quantities	http://eulersharp.sourceforge.net/2003/03swap/quantitiesExtension#	20111028
qudt	http://qudt.org/1.1/schema/qudt#	20111028
r2r	http://www4.wiwiss.fu-berlin.de/bizer/r2r/	20111028
rail	http://ontologi.es/rail/vocab#	20111028
rdacarrier	http://rdvocab.info/termList/RDACarrierType/	20111028
rdacontent	http://rdvocab.info/termList/RDAContentType/	20111028
rdamedia	http://rdvocab.info/termList/RDAMediaType/	20111028
rdb	http://www.dbs.cs.uni-duesseldorf.de/RDF/relational#	20111028
rdf	http://www.w3.org/1999/02/22-rdf-syntax-ns#	20111028
rdfa	http://www.w3.org/ns/rdfa#	20111028
rdfdata	http://rdf.data-vocabulary.org/rdf.xml#	20111028
rdfdf	http://www.openlinksw.com/virtrdf-data-formats#	20111028
rdfg	http://www.w3.org/2004/03/trix/rdfg-1/	20111028
rdfs	http://www.w3.org/2000/01/rdf-schema#	20111028
rdo	http://purl.org/rdo/ns#	20111028
re	http://www.w3.org/2000/10/swap/reason#	20111028
rec	http://purl.org/ontology/rec/core#	20111028
reco	http://purl.org/reco#	20111028
ref	http://purl.org/vocab/relationship/	20111028
rei	http://www.w3.org/2004/06/rei#	20111028
rel	http://purl.org/vocab/relationship/	20111028
remus	http://www.semanticweb.org/ontologies/2010/6/Ontology1279614123500.owl#	20111028
rep	http://www.openrdf.org/config/repository#	20111028
req	http://ns.softwiki.de/req/	20111028
res	http://www.w3.org/2005/sparql-results#	20111028
resex	http://resex.rkbexplorer.com/ontologies/resex#	20111028
resist	http://www.rkbexplorer.com/ontologies/resist#	20111028
resource	http://purl.org/vocab/resourcelist/schema#	20111028
rev	http://purl.org/stuff/rev#	20111028
rich	http://rdf.data-vocabulary.org/	20111028
rif	http://www.w3.org/2007/rif#	20111028
rnews	http://iptc.org/std/rNews/2011-10-07#	20111028
ro	http://purl.org/obo/owl/ro#	20111028
room	http://vocab.deri.ie/rooms#	20111028
rooms	http://vocab.deri.ie/rooms#	20111028
rpubl	http://rinfo.lagrummet.se/ns/2008/11/rinfo/publ#	20111028
rr	http://www.w3.org/ns/r2rml#	20111028
rsa	http://www.w3.org/ns/auth/rsa#	20111028
rss	http://purl.org/rss/1.0/	20111028
rulz	http://purl.org/NET/rulz#	20111028
rv	http://wifo-ravensburg.de/semanticweb.rdf#	20111028
s2s	http://escience.rpi.edu/ontology/sesf/s2s/2/0/	20111028
s3db	http://www.s3db.org/core#	20111028
s4ac	http://ns.inria.fr/s4ac/v1#	20111028
sail	http://www.openrdf.org/config/sail#	20111028
sawsdl	http://www.w3.org/ns/sawsdl#	20111028
saxon	http://saxon.sf.net/	20111028
sc	http://umbel.org/umbel/sc/	20111028
schema	http://schema.org/	20111028
sco	http://purl.org/ontology/sco#	20111028
scot	http://scot-project.org/scot/ns#	20111028
scovo	http://purl.org/NET/scovo#	20111028
scowt	http://purl.org/weso/ontologies/scowt#	20111028
scsv	http://purl.org/NET/schema-org-csv#	20111028
scv	http://purl.org/NET/scovo#	20111028
sd	http://www.w3.org/ns/sparql-service-description#	20111028
sdl	http://purl.org/vocab/riro/sdl#	20111028
sdmx	http://purl.org/linked-data/sdmx#	20111028
sdmxdim	http://purl.org/linked-data/sdmx/2009/dimension#	20111028
search	http://sindice.com/vocab/search#	20111028
sec	http://purl.org/security#	20111028
sede	http://eventography.org/sede/0.1/	20111028
semtweet	http://semantictweet.com/	20111028
sesame	http://www.openrdf.org/schema/sesame#	20111028
session	http://redfoot.net/2005/session#	20111028
shv	http://ns.aksw.org/spatialHierarchy/	20111028
sider	http://www4.wiwiss.fu-berlin.de/sider/resource/sider/	20111028
sig	http://purl.org/signature#	20111028
sim	http://purl.org/ontology/similarity/	20111028
sindice	http://vocab.sindice.net/	20111028
sio	http://semanticscience.org/resource/	20111028
sioc	http://rdfs.org/sioc/ns#	20111028
sioca	http://rdfs.org/sioc/actions#	20111028
sioct	http://rdfs.org/sioc/types#	20111028
sioctypes	http://rdfs.org/sioc/types#	20111028
sism	http://purl.oclc.org/NET/sism/0.1/	20111028
sit	http://www.ontologydesignpatterns.org/cp/owl/situation.owl#	20111028
skip	http://skipforward.net/skipforward/resource/	20111028
skiresort	http://www.openlinksw.com/ski_resorts/schema#	20111028
skos	http://www.w3.org/2004/02/skos/core#	20111028
skosxl	http://www.w3.org/2008/05/skos-xl#	20111028
sl	http://www.semanlink.net/2001/00/semanlink-schema#	20111028
sm	http://topbraid.org/sparqlmotion#	20111028
smf	http://topbraid.org/sparqlmotionfunctions#	20111028
smiley	http://www.smileyontology.com/ns#	20111028
sml	http://topbraid.org/sparqlmotionlib#	20111028
so	http://purl.org/ontology/symbolic-music/	20111028
soap	http://www.w3.org/2003/05/soap-envelope/	20111028
soft	http://www.w3.org/2007/uwa/context/software.owl#	20111028
sp	http://spinrdf.org/sp#	20111028
space	http://purl.org/net/schemas/space/	20111028
spacerel	http://data.ordnancesurvey.co.uk/ontology/spatialrelations/	20111028
span	http://www.ifomis.org/bfo/1.1/span#	20111028
sparql	http://www.openrdf.org/config/repository/sparql#	20111028
spatial	http://geovocab.org/spatial#	20111028
spc	http://purl.org/ontomedia/core/space#	20111028
spin	http://spinrdf.org/spin#	20111028
spl	http://spinrdf.org/spl#	20111028
sport	http://www.bbc.co.uk/ontologies/sport/	20111028
sr	http://www.openrdf.org/config/repository/sail#	20111028
sso	http://nlp2rdf.lod2.eu/schema/sso/	20111028
states	http://www.w3.org/2005/07/aaa#	20111028
status	http://ontologi.es/status#	20111028
steel	http://ontorule-project.eu/resources/steel-30#	20111028
str	http://nlp2rdf.lod2.eu/schema/string/	20111028
string	http://www.w3.org/2000/10/swap/string#	20111028
sv	http://schemas.talis.com/2005/service/schema#	20111028
swanag	http://purl.org/swan/1.2/agents/	20111028
swanci	http://purl.org/swan/1.2/citations/	20111028
swanco	http://purl.org/swan/1.2/swan-commons/	20111028
swande	http://purl.org/swan/1.2/discourse-elements/	20111028
swandr	http://purl.org/swan/1.2/discourse-relationships/	20111028
swanpav	http://purl.org/swan/1.2/pav/	20111028
swanq	http://purl.org/swan/1.2/qualifiers/	20111028
swanqs	http://purl.org/swan/1.2/qualifiers/	20111028
swc	http://data.semanticweb.org/ns/swc/ontology#	20111028
swh	http://plugin.org.uk/swh-plugins/	20111028
swid	http://semanticweb.org/id/	20111028
swivt	http://semantic-mediawiki.org/swivt/1.0#	20111028
swp	http://www.w3.org/2004/03/trix/swp-2/	20111028
swrc	http://swrc.ontoware.org/ontology#	20111028
swrl	http://www.w3.org/2003/11/swrl#	20111028
swrlb	http://www.w3.org/2003/11/swrlb#	20111028
sysont	http://ns.ontowiki.net/SysOnt/	20111028
tag	http://www.holygoat.co.uk/owl/redwood/0.1/tags/	20111028
tags	http://www.holygoat.co.uk/owl/redwood/0.1/tags/	20111028
tarot	http://data.totl.net/tarot/card/	20111028
taxo	http://purl.org/rss/1.0/modules/taxonomy/	20111028
tblcard	http://www.w3.org/People/Berners-Lee/card#	20111028
tdb	http://jena.hpl.hp.com/2008/tdb#	20111028
teach	http://linkedscience.org/teach/ns#	20111028
tei	http://www.tei-c.org/ns/1.0/	20111028
telix	http://purl.org/telix#	20111028
telmap	http://purl.org/telmap/	20111028
test	http://test2.example.com/	20111028
test2	http://this.invalid/test2#	20111028
theatre	http://purl.org/theatre#	20111028
ti	http://www.ontologydesignpatterns.org/cp/owl/timeinterval.owl#	20111028
time	http://www.w3.org/2006/time#	20111028
timeline	http://purl.org/NET/c4dm/timeline.owl#	20111028
tio	http://purl.org/tio/ns#	20111028
tl	http://purl.org/NET/c4dm/timeline.owl#	20111028
tmo	http://www.semanticdesktop.org/ontologies/2008/05/20/tmo#	20111028
tmpl	http://purl.org/restdesc/http-template#	20111028
toby	http://tobyinkster.co.uk/#	20111028
trackback	http://madskills.com/public/xml/rss/module/trackback/	20111028
transmed	http://www.w3.org/2001/sw/hcls/ns/transmed/	20111028
tripfs	http://purl.org/tripfs/2010/02#	20111028
tripfs2	http://purl.org/tripfs/2010/06#	20111028
ttl	http://www.w3.org/2008/turtle#	20111028
txn	http://lod.taxonconcept.org/ontology/txn.owl#	20111028
tzont	http://www.w3.org/2006/timezone#	20111028
ufmedia	http://purl.org/microformat/hmedia/	20111028
ui	http://www.w3.org/ns/ui#	20111028
umbel	http://umbel.org/umbel#	20111028
umbelrc	http://umbel.org/umbel/rc/	20111028
uni	http://purl.org/weso/uni/uni.html#	20111028
uniprot	http://purl.uniprot.org/core/	20111028
unit	http://qudt.org/vocab/unit#	20111028
units	http://eulersharp.sourceforge.net/2003/03swap/unitsExtension#	20111028
urn	http://fliqz.com/	20111028
user	http://schemas.talis.com/2005/user/schema#	20111028
usgov	http://www.rdfabout.com/rdf/schema/usgovt/	20111028
uta	http://uptheasset.org/ontology#	20111028
vaem	http://www.linkedmodel.org/schema/vaem#	20111028
vann	http://purl.org/vocab/vann/	20111028
vcard	http://www.w3.org/2006/vcard/ns#	20111028
vcard2006	http://www.w3.org/2006/vcard/ns#	20111028
vcardx	http://buzzword.org.uk/rdf/vcardx#	20111028
vdpp	http://data.lirmm.fr/ontologies/vdpp#	20111028
video	http://purl.org/media/video#	20111028
visko	http://trust.utep.edu/visko/ontology/visko-operator-v3.owl#	20111028
viskoo	http://trust.utep.edu/visko/ontology/visko-operator-v3.owl#	20111028
viskov	http://trust.utep.edu/visko/ontology/visko-view-v3.owl#	20111028
vitro	http://vitro.mannlib.cornell.edu/ns/vitro/public#	20111028
vivo	http://vivoweb.org/ontology/core#	20111028
voaf	http://mondeca.com/foaf/voaf#	20111028
voag	http://voag.linkedmodel.org/schema/voag#	20111028
void	http://rdfs.org/ns/void#	20111028
vote	http://www.rdfabout.com/rdf/schema/vote/	20111028
vs	http://www.w3.org/2003/06/sw-vocab-status/ns#	20111028
vso	http://purl.org/vso/ns#	20111028
vsto	http://escience.rpi.edu/ontology/vsto/2/0/vsto.owl#	20111028
w3con	http://www.w3.org/2000/10/swap/pim/contact#	20111028
w3p	http://prov4j.org/w3p/	20111028
wai	http://purl.org/wai#	20111028
wairole	http://www.w3.org/2005/01/wai-rdf/GUIRoleTaxonomy#	20111028
wao	http://webtlab.it.uc3m.es/2010/10/WebAppsOntology#	20111028
water	http://escience.rpi.edu/ontology/semanteco/2/0/water.owl#	20111028
wdr	http://www.w3.org/2007/05/powder#	20111028
wdrs	http://www.w3.org/2007/05/powder-s#	20111028
web	http://www.w3.org/2007/uwa/context/web.owl#	20111028
webtlab	http://webtlab.it.uc3m.es/	20111028
wf	http://www.w3.org/2005/01/wf/flow#	20111028
wgs	http://www.w3.org/2003/01/geo/wgs84_pos#	20111028
wgs84	http://www.w3.org/2003/01/geo/wgs84_pos#	20111028
wgspos	http://www.w3.org/2003/01/geo/wgs84_pos#	20111028
whois	http://www.kanzaki.com/ns/whois#	20111028
wisski	http://wiss-ki.eu/	20111028
wlp	http://weblab-project.org/core/model/property/processing/	20111028
wm	http://ns.inria.fr/webmarks#	20111028
wn	http://xmlns.com/wordnet/1.6/	20111028
wn20schema	http://www.w3.org/2006/03/wn/wn20/schema/	20111028
wnschema	http://www.cogsci.princeton.edu/~wn/schema/	20111028
wo	http://purl.org/ontology/wo/	20111028
wordmap	http://purl.org/net/ns/wordmap#	20111028
wordnet	http://purl.org/vocabularies/princeton/wordnet/schema#	20111028
wot	http://xmlns.com/wot/0.1/	20111028
wsc	http://www.openk.org/wscaim.owl#	20111028
wv	http://vocab.org/waiver/terms/	20111028
xbrli	http://www.xbrl.org/2003/instance#	20111028
xch	http://oanda2rdf.appspot.com/xch/	20111028
xds	http://www.w3.org/2001/XMLSchema#	20111028
xen	http://buzzword.org.uk/rdf/xen#	20111028
xesam	http://freedesktop.org/standards/xesam/1.0/core#	20111028
xf	http://www.w3.org/2002/xforms/	20111028
xfn	http://vocab.sindice.com/xfn#	20111028
xfnv	http://vocab.sindice.com/xfn#	20111028
xforms	http://www.w3.org/2002/xforms/	20111028
xhe	http://buzzword.org.uk/rdf/xhtml-elements#	20111028
xhtml	http://www.w3.org/1999/xhtml/vocab#	20111028
xhtmlvocab	http://www.w3.org/1999/xhtml/vocab/	20111028
xhv	http://www.w3.org/1999/xhtml/vocab#	20111028
xl	http://langegger.at/xlwrap/vocab#	20111028
xlink	http://www.w3.org/1999/xlink/	20111028
xro	http://www.stalsoft.com/ontologies/xro/ns#	20111028
xs	http://www.w3.org/2001/XMLSchema#	20111028
xsd	http://www.w3.org/2001/XMLSchema#	20111028
xsl	http://www.w3.org/1999/XSL/Transform#	20111028
xt	http://purl.org/twc/vocab/cross-topix#	20111028
xtypes	http://purl.org/xtypes/	20111028
ya	http://blogs.yandex.ru/schema/foaf/	20111028
yago	http://dbpedia.org/class/yago/	20111028
yoda	http://purl.org/NET/yoda#	20111028
zbwext	http://zbw.eu/namespaces/zbw-extensions/	20111028
zem	http://s.zemanta.com/ns#	20111028
zoology	http://purl.org/NET/biol/zoology#	20111028
daiaserv	http://purl.org/ontology/daia/service/	20111031
vvo	http://purl.org/vvo/ns#	20111031
vsw	http://verticalsearchworks.com/ontology/	20111102
commerce	http://search.yahoo.com/searchmonkey/commerce/	20111124
gnd	http://d-nb.info/gnd/	20111124
grs	http://www.georss.org/georss/	20111124
htir	http://www.w3.org/2011/http#	20111124
infosys	http://www.infosys.com/	20111124
muto	http://purl.org/muto/core#	20111124
omapi	http://purl.org/omapi/0.2/#	20111124
prf	http://www.openmobilealliance.org/tech/profiles/UAPROF/ccppschema-20021212#	20111124
webbox	http://webbox.ecs.soton.ac.uk/ns#	20111124
calli	http://callimachusproject.org/rdf/2009/framework#	20111208
dwc	http://rs.tdwg.org/dwc/terms/	20111208
eunis	http://eunis.eea.europa.eu/rdf/species-schema.rdf#	20111208
georss	http://www.georss.org/georss/	20111208
pna	http://data.press.net/ontology/asset/	20111208
swpatho	http://swpatho.ag-nbi.de/context/meta.owl#	20111208
voidp	http://www.enakting.org/provenance/voidp/	20111208
arecipe	http://purl.org/amicroformat/arecipe/	20120124
cis	http://purl.org/NET/cloudisus#	20120124
daiaserv	http://purl.org/ontology/daia/Service/	20120124
datafaqs	http://purl.org/twc/vocab/datafaqs#	20120124
db	http://dbpedia.org/	20120124
ends	http://labs.mondeca.com/vocab/endpointStatus#	20120124
identity	http://purl.org/twc/ontologies/identity.owl#	20120124
italy	http://data.kasabi.com/dataset/italy/schema/	20120124
jita	http://aims.fao.org/aos/jita/	20120124
media	http://search.yahoo.com/searchmonkey/media/	20120124
moby	http://www.mygrid.org.uk/mygrid-moby-service#	20120124
nfo	http://www.semanticdesktop.org/ontologies/nfo/#	20120124
np	http://www.nanopub.org/nschema#	20120124
ocd	http://dati.camera.it/ocd/	20120124
places	http://purl.org/ontology/places#	20120124
protegedc	http://protege.stanford.edu/plugins/owl/dc/protege-dc.owl#	20120124
transit	http://vocab.org/transit/terms/	20120124
vsr	http://purl.org/twc/vocab/vsr#	20120124
wfdesc	http://purl.org/wf4ever/wfdesc#	20120124
wikipedia	http://www.systemone.at/2006/03/wikipedia#	20120124
aerols	http://xmlns.com/aerols/0.1/	20120426
carfo	http://purl.org/carfo#	20120426
cerif	http://spi-fm.uca.es/neologism/cerif#	20120426
cheminf	http://www.semanticweb.org/ontologies/cheminf.owl#	20120426
cts2	http://schema.omg.org/spec/CTS2/1.0/	20120426
example	http://www.example.org/rdf#	20120426
func	http://www.w3.org/2007/rif-builtin-function#	20120426
geom	http://geovocab.org/geometry#	20120426
gldp	http://www.w3.org/ns/people#	20120426
goef	http://purl.org/twc/vocab/goef#	20120426
hg	http://www.holygoat.co.uk/owl/redwood/0.1/tags/	20120426
ipad	http://www.padinthecity.com/	20120426
isbd	http://iflastandards.info/ns/isbd/elements/	20120426
kupkb	http://www.e-lico.eu/data/kupkb/	20120426
lexvo	http://lexvo.org/ontology#	20120426
linkedct	http://data.linkedct.org/vocab/	20120426
lr	http://linkedrecipes.org/schema/	20120426
lv	http://lobid.org/vocab/lobid#	20120426
marcrel	http://id.loc.gov/vocabulary/relators/	20120426
metalex	http://www.metalex.eu/metalex/2008-05-02#	20120426
mohammad	http://manesht.ir/	20120426
nfo	http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#	20120426
npg	http://ns.nature.com/terms/	20120426
nsogi	http://prefix.cc/nsogi:	20120426
oac	http://www.openannotation.org/ns/	20120426
ogorg	http://opengraph.org/schema/	20120426
omv	http://omv.ontoware.org/2005/05/ontology#	20120426
onssprel	http://www.ordnancesurvey.co.uk/ontology/SpatialRelations/v0.2/SpatialRelations.owl#	20120426
ospost	http://data.ordnancesurvey.co.uk/ontology/postcode/	20120426
pay	http://purl.org/commerce/payment#	20120426
pc	http://purl.org/procurement/public-contracts#	20120426
pf	http://jena.hpl.hp.com/ARQ/property#	20120426
pne	http://data.press.net/ontology/event/	20120426
prism21	http://prismstandard.org/namespaces/basic/2.1/	20120426
pro	http://purl.org/hpi/patchr#	20120426
prov	http://www.w3.org/ns/prov#	20120426
prviv	http://purl.org/net/provenance/integrity#	20120426
ql	http://www.w3.org/2004/ql#	20120426
r2rml	http://www.w3.org/ns/r2rml#	20120426
rating	http://www.tvblob.com/ratings/#	20120426
recipe	http://linkedrecipes.org/schema/	20120426
scufl2	http://ns.taverna.org.uk/2010/scufl2#	20120426
ssn	http://www.w3.org/2005/Incubator/ssn/ssnx/ssn#	20120426
vapour	http://vapour.sourceforge.net/vocab.rdf#	20120426
vsws	http://verticalsearchworks.com/ontology/synset#	20120426
wbc	http://worldbank.270a.info/classification/	20120426
wbp	http://worldbank.270a.info/property/	20120426
wkd	http://schema.wolterskluwer.de/	20120426
wp	http://vocabularies.wikipathways.org/	20120426
wscaim	http://www.openk.org/wscaim.owl#	20120426
xhtml	http://www.w3.org/1999/xhtml#	20120426
xkos	http://purl.org/linked-data/xkos#	20120426
d2r	http://sites.wiwiss.fu-berlin.de/suhl/bizer/d2r-server/config.rdf#	20120521
efo	http://www.ebi.ac.uk/efo/	20120521
enhancer	http://stanbol.apache.org/ontology/enhancer/enhancer#	20120521
fcm	http://eulersharp.sourceforge.net/2006/02swap/fcm#	20120521
fise	http://fise.iks-project.eu/ontology/	20120521
fl	http://eulersharp.sourceforge.net/2003/03swap/fl-rules#	20120521
fls	http://lukasblaho.sk/football_league_schema#	20120521
oboe	http://ecoinformatics.org/oboe/oboe.1.0/oboe-core.owl#	20120521
pccz	http://purl.org/procurement/public-contracts-czech#	20120521
rdrel	http://rdvocab.info/RDARelationshipsWEMI/	20120521
rec54	http://www.w3.org/2001/02pd/rec54.rdf#	20120521
acco	http://purl.org/acco/ns#	20120827
acm	http://www.semanticweb.org/ontologies/2012/acm.owl#	20120827
admssw	http://purl.org/adms/sw/	20120827
aers	http://aers.data2semantics.org/resource/	20120827
arg	http://rdfs.org/sioc/argument#	20120827
br	http://purl.org/business-register#	20120827
cao	http://purl.org/makolab/caont/	20120827
cogs	http://vocab.deri.ie/cogs#	20120827
crm	http://erlangen-crm.org/current/	20120827
dive	http://scubadive.networld.to/dive.rdf#	20120827
dpl	http://dbpedialite.org/things/	20120827
eprints	http://eprints.org/ontology/	20120827
eumida	http://data.kasabi.com/dataset/eumida/terms/	20120827
germplasm	http://purl.org/germplasm/terms#	20120827
intervals	http://reference.data.gov.uk/def/intervals/	20120827
lctr	http://data.linkedct.org/vocab/resource/	20120827
lemon	http://www.monnet-project.eu/lemon#	20120827
library	http://purl.org/library/	20120827
life	http://life.deri.ie/schema/	20120827
marl	http://purl.org/marl/ns#	20120827
muni	http://purl.org/ontology/muni#	20120827
ncbitaxon	http://purl.org/obo/owl/NCBITaxon#	20120827
no	http://km.aifb.kit.edu/projects/numbers/number#	20120827
npgd	http://ns.nature.com/datasets/	20120827
npgg	http://ns.nature.com/graphs/	20120827
npgx	http://ns.nature.com/extensions/	20120827
open	http://open.vocab.org/terms/	20120827
pav	http://purl.org/pav/	20120827
pkmn	http://pokedex.dataincubator.org/pkm/	20120827
pml	http://provenanceweb.org/ns/pml#	20120827
poder	http://poderopedia.com/vocab/	20120827
pol	http://escience.rpi.edu/ontology/semanteco/2/0/pollution.owl#	20120827
prism	http://prismstandard.org/namespaces/basic/2.0/	20120827
prv	http://purl.org/ontology/prv/core#	20120827
r4ta	http://ns.inria.fr/ratio4ta/v1#	20120827
rda	http://rdvocab.info/elements/	20120827
rdagr1	http://rdvocab.info/Elements/	20120827
rssynd	http://web.resource.org/rss/1.0/modules/syndication/	20120827
s4ac	http://ns.inria.fr/s4ac/v2#	20120827
sdgp	http://stats.data-gov.ie/property/	20120827
set	http://www.w3.org/2000/10/swap/set#	20120827
sgv	http://www.w3.org/TR/SVG/	20120827
spif	http://spinrdf.org/spif#	20120827
tcga	http://purl.org/tcga/core#	20120827
mpeg7	http://rhizomik.net/ontologies/2005/03/Mpeg7-2001.owl#	20120829
myprefix	http://myprefix.org/	20120829
ngeoi	http://vocab.lenka.no/geo-deling#	20120829
okg	http://openknowledgegraph.org/ontology/	20120829
flow	http://www.w3.org/2005/01/wf/flow#	20120905
osmsemnet	http://spatial.ucd.ie/2012/08/osmsemnet/	20120905
wfprov	http://purl.org/wf4ever/wfprov#	20120905
category	http://dbpedia.org/resource/Category:	20120917
ero	http://purl.obolibrary.org/obo/	20120917
interval	http://reference.data.gov.uk/def/intervals/	20120917
adms	http://www.w3.org/ns/adms#	20130208
aersv	http://aers.data2semantics.org/vocab/	20130208
agg	http://purl.org/twc/health/vocab/aggregate/	20130208
apivc	http://purl.org/linked-data/api/vocab#	20130208
arpfo	http://vocab.ouls.ox.ac.uk/projectfunding#	20130208
asn	http://purl.org/ASN/schema/core/	20130208
atomrdf	http://atomowl.org/ontologies/atomrdf#	20130208
b2bo	http://purl.org/iig2/b2bo#	20130208
bd	http://www.bigdata.com/rdf/search#	20130208
bing	http://bing.com/schema/media/	20130208
biopax	http://bio2rdf.org/ns/biopax#	20130208
bne	http://datos.bne.es/resource/	20130208
bp	http://open-services.net/ns/basicProfile#	20130208
bte	http://purl.org/twc/vocab/between-the-edges/	20130208
cidoccrm	http://purl.org/NET/cidoc-crm/core#	20130208
cv	http://purl.org/captsolo/resume-rdf/0.2/cv#	20130208
daisy	http://www.daisy.org/z3998/2012/vocab/	20130208
dce	http://purl.org/dc/elements/1.1/	20130208
dco	http://deepcarbon.net/	20130208
dcr	http://www.isocat.org/ns/dcr.rdf#	20130208
disco	http://vocab.ddialliance.org/discovery#	20130208
dita	http://zebrana.net/dita/ditavoc.ttl#	20130208
dnb	http://d-nb.info/gnd/	20130208
dsp	http://purl.org/metainfo/terms/dsp#	20130208
dssn	http://purl.org/net/dssn/	20130208
ekaw	http://data.semanticweb.org/conference/ekaw/2012/complete/	20130208
ens	http://models.okkam.org/ENS-core-vocabulary.owl#	20130208
eseduc	http://www.purl.org/ontologia/eseduc#	20130208
fd	http://foodable.co/ns/	20130208
food	http://data.lirmm.fr/ontologies/food#	20130208
fos	http://futurios.org/fos/spec/	20130208
gawd	http://gawd.atlantides.org/terms/	20130208
genea	http://www.owl-ontologies.com/generations.owl#	20130208
geocontext	http://www.geocontext.org/publ/2013/vocab#	20130208
geoes	http://geo.linkeddata.es/ontology/	20130208
gsp	http://www.opengis.net/ont/geosparql#	20130208
gxa	http://www.ebi.ac.uk/gxa/	20130208
health	http://purl.org/twc/health/vocab/	20130208
hgnc	http://bio2rdf.org/hgnc:	20130208
icaltzd	http://www.w3.org/2002/12/cal/icaltzd#	20130208
idemo	http://rdf.insee.fr/graphes/def/demo#	20130208
igeo	http://rdf.insee.fr/def/geo#	20130208
jjd	http://www.joshuajeeson.com/	20130208
kdo	http://kdo.render-project.eu/kdo#	20130208
l4a	http://labels4all.info/ns/	20130208
laposte	http://data.lirmm.fr/ontologies/laposte#	20130208
ldp	http://www.w3.org/ns/ldp#	20130208
lex	http://purl.org/lex#	20130208
lyou	http://purl.org/linkingyou/	20130208
marshall	http://sites.google.com/site/xgmaitc/	20130208
md	http://www.w3.org/ns/md#	20130208
media	http://purl.org/microformat/hmedia/	20130208
metalex	http://www.metalex.eu/schema/1.0#	20130208
nfo	http://www.semanticdesktop.org/ontologies/nfo/#	20130208
nxp	http://purl.org/nxp/schema/v1/	20130208
oa	http://www.w3.org/ns/openannotation/core/	20130208
oarj	http://opendepot.org/reference/linked/1.0/	20130208
oax	http://www.w3.org/ns/openannotation/extensions/	20130208
osn	http://spatial.ucd.ie/lod/osn/	20130208
owltime	http://www.w3.org/TR/owl-time#	20130208
particip	http://purl.org/vocab/participation/schema#	20130208
person	http://www.w3.org/ns/person#	20130208
photoshop	http://ns.adobe.com/photoshop/1.0/	20130208
pingback	http://purl.org/net/pingback/	20130208
prefix	http://prefix.cc/	20130208
pronom	http://reference.data.gov.uk/technical-registry/	20130208
prv	http://purl.org/net/provenance/ns#	20130208
qa	http://www.mit.jyu.fi/ai/TRUST_Ontologies/QA.owl#	20130208
qud	http://qudt.org/1.1/schema/qudt#	20130208
rad	http://www.w3.org/ns/rad#	20130208
rov	http://www.w3.org/ns/regorg#	20130208
ssso	http://purl.org/ontology/ssso#	20130208
strdf	http://strdf.di.uoa.gr/ontology#	20130208
tisc	http://observedchange.com/tisc/ns#	20130208
uco	http://purl.org/uco/ns#	20130208
viaf	http://viaf.org/ontology/1.1/#	20130208
visit	http://purl.org/net/vocab/2004/07/visit#	20130208
w3po	http://purl.org/provenance#	20130208
wn20	http://www.w3.org/2006/03/wn/wn20/	20130208
xmls	http://www.w3.org/2001/XMLSchema#	20130208
xro	http://purl.org/xro/ns#	20130208
acm	http://www.rkbexplorer.com/ontologies/acm#	20130327
agls	http://www.agls.gov.au/agls/terms/	20130327
agrelon	http://d-nb.info/standards/elementset/agrelon.owl#	20130327
aigp	http://swat.cse.lehigh.edu/resources/onto/aigp.owl#	20130327
aos	http://rdf.muninn-project.org/ontologies/appearances#	20130327
api	http://purl.org/linked-data/api/vocab#	20130327
being	http://purl.org/ontomedia/ext/common/being#	20130327
bf	http://bibframe.org/vocab/	20130327
bif	http://www.openlinksw.com/schema/sparql/extensions#	20130327
biotop	http://purl.org/biotop/biotop.owl#	20130327
biro	http://purl.org/spar/biro/	20130327
br	http://vocab.deri.ie/br#	20130327
cb	http://cbasewrap.ontologycentral.com/vocab#	20130327
cgov	http://reference.data.gov.uk/def/central-government/	20130327
city	http://datos.localidata.com/def/City#	20130327
cold	http://purl.org/configurationontology#	20130327
coll	http://purl.org/co/	20130327
comm	http://vocab.resc.info/communication#	20130327
coun	http://www.daml.org/2001/09/countries/iso-3166-ont#	20130327
cpa	http://www.ontologydesignpatterns.org/schemas/cpannotationschema.owl#	20130327
crm	http://www.cidoc-crm.org/cidoc-crm/	20130327
crsw	http://courseware.rkbexplorer.com/ontologies/courseware#	20130327
csp	http://vocab.deri.ie/csp#	20130327
ctorg	http://purl.org/ctic/infraestructuras/organizacion#	20130327
dbtont	http://dbtropes.org/ont/	20130327
dcite	http://purl.org/spar/datacite/	20130327
dcndl	http://ndl.go.jp/dcndl/terms/	20130327
deo	http://purl.org/spar/deo/	20130327
disco	http://rdf-vocabulary.ddialliance.org/discovery#	20130327
dita	http://purl.org/ditavoc/schema/	20130327
dl	http://ontology.ip.rm.cnr.it/ontologies/DOLCE-Lite#	20130327
doco	http://purl.org/spar/doco/	20130327
dqm	http://purl.org/dqm-vocabulary/v1/dqm#	20130327
dr	http://purl.org/swan/2.0/discourse-relationships/	20130327
drm	http://vocab.data.gov/def/drm#	20130327
ds	http://purl.org/ctic/dcat#	20130327
dso	http://purl.org/ontology/dso#	20130327
ecos	http://kmm.lboro.ac.uk/ecos/1.0#	20130327
edgar	http://edgarwrap.ontologycentral.com/vocab/edgar#	20130327
elec	http://purl.org/ctic/sector-publico/elecciones#	20130327
emp	http://purl.org/ctic/empleo/oferta#	20130327
ep	http://eprints.org/ontology/	20130327
fcp	http://www.newmedialab.at/fcp/	20130327
food	http://purl.org/foodontology#	20130327
fowl	http://www.w3.org/TR/2003/PR-owl-guide-20031209/food#	20130327
gadm	http://gadm.geovocab.org/ontology#	20130327
gastro	http://www.ebsemantics.net/gastro#	20130327
geod	http://vocab.lenka.no/geo-deling#	20130327
geosp	http://rdf.geospecies.org/ont/geospecies#	20130327
gnm	http://www.geonames.org/ontology/mappings/	20130327
graffle	http://purl.org/twc/vocab/vsr/graffle#	20130327
graves	http://rdf.muninn-project.org/ontologies/graves#	20130327
gso	http://www.w3.org/2006/gen/ont#	20130327
idemo	http://rdf.insee.fr/def/demo#	20130327
infor	http://www.ontologydesignpatterns.org/cp/owl/informationrealization.owl#	20130327
inno	http://purl.org/innovation/ns#	20130327
iol	http://www.ontologydesignpatterns.org/ont/dul/IOLite.owl#	20130327
itsmo	http://ontology.it/itsmo/v1#	20130327
lcy	http://purl.org/vocab/lifecycle/schema#	20130327
lh	http://vocab.inf.ed.ac.uk/library/holdings#	20130327
lib	http://purl.org/library/	20130327
lingvo	http://www.lingvoj.org/ontology#	20130327
lmm1	http://www.ontologydesignpatterns.org/ont/lmm/LMM_L1.owl#	20130327
lmm2	http://www.ontologydesignpatterns.org/ont/lmm/LMM_L2.owl#	20130327
lsc	http://linkedscience.org/lsc/ns#	20130327
mads	http://www.loc.gov/mads/rdf/v1#	20130327
mds	http://doc.metalex.eu/id/	20130327
meb	http://rdf.myexperiment.org/ontologies/base/	20130327
mil	http://rdf.muninn-project.org/ontologies/military#	20130327
mime	http://purl.org/NET/mediatypes/	20130327
moac	http://observedchange.com/moac/ns#	20130327
mrel	http://id.loc.gov/vocabulary/relators/	20130327
msr	http://www.telegraphis.net/ontology/measurement/measurement#	20130327
mvco	http://purl.oclc.org/NET/mvco.owl#	20130327
ntag	http://ns.inria.fr/nicetag/2010/09/09/voc#	20130327
nyt	http://data.nytimes.com/element/	20130327
obsm	http://rdf.geospecies.org/methods/observationMethod#	20130327
odapp	http://vocab.deri.ie/odapp#	20130327
odpart	http://www.ontologydesignpatterns.org/cp/owl/participation.owl#	20130327
odv	http://reference.data.gov.uk/def/organogram/	20130327
oecc	http://www.oegov.org/core/owl/cc#	20130327
ontopic	http://www.ontologydesignpatterns.org/ont/dul/ontopic.owl#	20130327
opl	http://openlinksw.com/schema/attribution#	20130327
opmo	http://openprovenance.org/model/opmo#	20130327
oprovo	http://openprovenance.org/ontology#	20130327
ordf	http://purl.org/NET/ordf/	20130327
osadm	http://data.ordnancesurvey.co.uk/ontology/admingeo/	20130327
osgeom	http://data.ordnancesurvey.co.uk/ontology/geometry/	20130327
osp	http://data.lirmm.fr/ontologies/osp#	20130327
osr	http://purl.org/ontomedia/core/space#	20130327
osspr	http://data.ordnancesurvey.co.uk/ontology/spatialrelations/	20130327
ostop	http://www.ordnancesurvey.co.uk/ontology/Topography/v0.1/Topography.owl#	20130327
part	http://purl.org/vocab/participation/schema#	20130327
passim	http://data.lirmm.fr/ontologies/passim#	20130327
prvt	http://purl.org/net/provenance/types#	20130327
ps	https://w3id.org/payswarm#	20130327
pso	http://purl.org/spar/pso/	20130327
ptop	http://www.ontotext.com/proton/protontop#	20130327
pwo	http://purl.org/spar/pwo/	20130327
quty	http://www.telegraphis.net/ontology/measurement/quantity#	20130327
raul	http://vocab.deri.ie/raul#	20130327
rdafrbr	http://rdvocab.info/uri/schema/FRBRentitiesRDA/	20130327
rdag1	http://rdvocab.info/Elements/	20130327
rdag3	http://rdvocab.info/ElementsGr3/	20130327
rdarel	http://rdvocab.info/RDARelationshipsWEMI/	20130327
s2s	http://escience.rpi.edu/ontology/sesf/s2s/4/0/	20130327
sc	http://purl.org/science/owl/sciencecommons/	20130327
sec	https://w3id.org/security#	20130327
semio	http://www.lingvoj.org/semio#	20130327
seq	http://www.ontologydesignpatterns.org/cp/owl/sequence.owl#	20130327
situ	http://www.ontologydesignpatterns.org/cp/owl/situation.owl#	20130327
snarm	http://rdf.myexperiment.org/ontologies/snarm/	20130327
spt	http://spitfire-project.eu/ontology/ns/	20130327
swpo	http://sw-portal.deri.org/ontologies/swportal#	20130327
tao	http://vocab.deri.ie/tao#	20130327
te	http://www.w3.org/2006/time-entry#	20130327
tis	http://www.ontologydesignpatterns.org/cp/owl/timeindexedsituation.owl#	20130327
trait	http://contextus.net/ontology/ontomedia/ext/common/trait#	20130327
turismo	http://idi.fundacionctic.org/cruzar/turismo#	20130327
tvc	http://www.essepuntato.it/2012/04/tvc/	20130327
vocab	http://rdf.ontology2.com/vocab#	20130327
vrank	http://purl.org/voc/vrank#	20130327
wlo	http://purl.org/ontology/wo/	20130327
wsl	http://www.wsmo.org/ns/wsmo-lite#	20130327
xmp	http://ns.adobe.com/xap/1.0/	20130327
zoomaterms	http://rdf.ebi.ac.uk/vocabulary/zooma/	20130327
dcm	http://dcm.com/	20130402
gnvc	http://purl.org/gc/	20130402
occult	http://data.totl.net/occult/	20130402
pizza	http://www.co-ode.org/ontologies/pizza/pizza.owl#	20130402
role	http://purl.org/vocab/participation/schema#	20130402
w3po	http://purl.org/provenance/w3p/w3po#	20130402
algo	http://securitytoolbox.appspot.com/securityAlgorithms#	20130802
b2bo	http://purl.org/b2bo#	20130802
biocore	http://bio2rdf.org/core#	20130802
bsb	http://lod.b3kat.de/title/	20130802
centrifuge	http://purl.org/twc/vocab/centrifuge#	20130802
cex	http://purl.org/weso/ontology/computex#	20130802
cf	http://mmisw.org/ont/cf/parameter/	20130802
cidoc	http://erlangen-crm.org/current/	20130802
cito	http://purl.org/spar/cito/	20130802
crtv	http://open-services.net/ns/crtv#	20130802
dbc	http://dbpedia.org/resource/Category:	20130802
dbnary	http://kaiko.getalp.org/dbnary#	20130802
dbpr	http://dbpedia.org/resource/	20130802
dbt	http://dbpedia.org/resource/Template:	20130802
dctypes	http://purl.org/dc/dcmitype/	20130802
dis	http://stanbol.apache.org/ontology/disambiguation/disambiguation#	20130802
dita	http://purl.org/dita/ns#	20130802
dso	http://inference-web.org/2.0/ds.owl#	20130802
dvia	http://data.eurecom.fr/ontology/dvia#	20130802
ebu	http://semantic.eurobau.com/eurobau-utility.owl#	20130802
ecb	http://ecb.270a.info/dataset/	20130802
ecpo	http://purl.org/ontology/ecpo#	20130802
exterms	http://www.example.org/terms/	20130802
frapo	http://purl.org/cerif/frapo/	20130802
geof	http://www.opengis.net/def/function/geosparql/	20130802
geofla	http://data.ign.fr/ontologies/geofla#	20130802
gfo	http://www.onto-med.de/ontologies/gfo.owl#	20130802
hifm	http://purl.org/net/hifm/data#	20130802
httpm	http://www.w3.org/2011/http-methods#	20130802
iot	http://www.linkedthings.com/iot/	20130802
itsrdf	http://www.w3.org/2005/11/its/rdf#	20130802
kbp	http://tackbp.org/2013/ontology#	20130802
l4lod	http://ns.inria.fr/l4lod/v2/	20130802
laabs	http://dbpedia.org/resource/	20130802
lgd	http://linkedgeodata.org/vocabulary#	20130802
locwd	http://purl.org/locwd/schema#	20130802
lv	http://purl.org/lobid/lv#	20130802
mods	http://www.loc.gov/mods/v3#	20130802
namespaces	https://vg.no/	20130802
nif	http://persistence.uni-leipzig.org/nlp2rdf/ontologies/nif-core#	20130802
nsl	http://purl.org/ontology/storyline/	20130802
oa	http://www.w3.org/ns/oa#	20130802
odcs	http://opendata.cz/infrastructure/odcleanstore/	20130802
oecd	http://oecd.270a.info/dataset/	20130802
omn	http://www.openmobilenetwork.org/resource/	20130802
opmw	http://www.opmw.org/ontology/	20130802
oslc	http://open-services.net/ns/core#	20130802
osr	http://dati.senato.it/osr/	20130802
pam	http://prismstandard.org/namespaces/pam/2.0/	20130802
penn	http://purl.org/olia/penn.owl#	20130802
pkgsrc	http://pkgsrc.co/schema#	20130802
ple	http://pleiades.stoa.org/places/	20130802
poste	http://data.lirmm.fr/ontologies/poste#	20130802
pr	http://purl.org/ontology/prv/core#	20130802
premis	http://multimedialab.elis.ugent.be/users/samcoppe/ontologies/Premis/premis.owl#	20130802
prolog	http://eulersharp.sourceforge.net/2003/03swap/prolog#	20130802
qrl	http://www.aifb.kit.edu/project/ld-retriever/qrl#	20130802
qvoc	http://mlode.nlp2rdf.org/quranvocab#	20130802
radion	http://www.w3.org/ns/radion#	20130802
rdarole	http://rdvocab.info/roles/	20130802
rdf123	http://rdf123.umbc.edu/ns/	20130802
req	http://purl.org/req/	20130802
reve	http://data.eurecom.fr/ontology/reve#	20130802
rlno	http://rdflivenews.aksw.org/ontology/	20130802
rlnr	http://rdflivenews.aksw.org/resource/	20130802
rlog	http://persistence.uni-leipzig.org/nlp2rdf/ontologies/rlog#	20130802
ro	http://purl.org/wf4ever/ro#	20130802
roevo	http://purl.org/wf4ever/roevo#	20130802
roterms	http://purl.org/wf4ever/roterms#	20130802
sci	http://data.scientology.org/ns/	20130802
sem	http://semanticweb.cs.vu.nl/2009/11/sem/	20130802
site	http://ns.ontowiki.net/SysOnt/Site/	20130802
stac	http://securitytoolbox.appspot.com/stac#	20130802
stats	http://purl.org/rdfstats/stats#	20130802
voaf	http://purl.org/vocommons/voaf#	20130802
wf4ever	http://purl.org/wf4ever/wf4ever#	20130802
wfm	http://purl.org/net/wf-motifs#	20130802
wfs	http://schemas.opengis.net/wfs/	20130802
wikterms	http://wiktionary.dbpedia.org/terms/	20130802
wl	http://www.wsmo.org/ns/wsmo-lite#	20130802
won	http://purl.org/webofneeds/model#	20130802
worldbank	http://worldbank.270a.info/dataset/	20130802
copyright	http://rhizomik.net/ontologies/copyrightonto.owl#	20130812
lldr	http://purl.oclc.org/NET/lldr/ns#	20130812
up	http://users.ugent.be/~tdenies/up/	20130812
fea	http://vocab.data.gov/def/fea#	20130816
penis	http://penis.to/#	20130816
scms	http://ns.aksw.org/scms/annotations/	20130816
sdo	http://schema.org/	20130816
wapp	http://ns.rww.io/wapp#	20130816
agrelon	http://d-nb.info/standards/elementset/agrelon#	20130924
alchemy	http://rdf.alchemyapi.com/rdf/v1/s/aapi-schema#	20130924
archdesc	http://archdesc.info/archEvent#	20130924
cnt	http://www.w3.org/2011/content#	20130924
co	http://rhizomik.net/ontologies/copyrightonto.owl#	20130924
cosmo	http://purl.org/ontology/cosmo#	20130924
cro	http://rhizomik.net/ontologies/copyrightonto.owl#	20130924
dbpo	http://dbpedia.org/ontology/	20130924
dt	http://dbpedia.org/datatype/	20130924
frbrer	http://iflastandards.info/ns/fr/frbr/frbrer/	20130924
frsad	http://iflastandards.info/ns/fr/frad/	20130924
gndo	http://d-nb.info/standards/elementset/gnd#	20130924
icane	http://www.icane.es/opendata/vocab#	20130924
ludo	http://vocab.ox.ac.uk/ludo#	20130924
oj	http://ontojob.at/	20130924
oliasystem	http://purl.org/olia/system.owl#	20130924
orca	http://geni-orca.renci.org/owl/topology.owl#	20130924
saif	http://wwwiti.cs.uni-magdeburg.de/~srahman/	20130924
sdmxa	http://purl.org/linked-data/sdmx/2009/attribute#	20130924
sdmxd	http://purl.org/linked-data/sdmx/2009/dimension#	20130924
sdo	http://salt.semanticauthoring.org/ontologies/sdo#	20130924
stream	http://dbpedia.org/ontology/Stream/	20130924
tsioc	http://rdfs.org/sioc/types#	20130924
twaapi	http://purl.org/twc/vocab/aapi-schema#	20130924
wd	http://www.wikidata.org/entity/	20130924
who	http://www.who.int/vocab/ontology#	20130924
wikidata	http://www.wikidata.org/entity/	20130924
yago	http://yago-knowledge.org/resource/	20130924
cdtype	http://purl.org/cld/cdtype/	20131002
fincaselaw	http://purl.org/finlex/schema/oikeus/	20131002
finlaw	http://purl.org/finlex/schema/laki/	20131002
amalgame	http://purl.org/vocabularies/amalgame#	20131115
camelot	http://vocab.ox.ac.uk/camelot#	20131115
conf	http://richard.cyganiak.de/2007/pubby/config.rdf#	20131115
crv	http://purl.org/twc/vocab/datacarver#	20131115
csm	http://purl.org/csm/1.0#	20131115
curr	https://w3id.org/cc#	20131115
dbrc	http://dbpedia.org/resource/Category:	20131115
dbyago	http://dbpedia.org/class/yago/	20131115
dso	http://purl.org/ontology/dso#	20131115
frad	http://iflastandards.info/ns/fr/frad/	20131115
frsad	http://iflastandards.info/ns/fr/frsad/	20131115
gnd	http://d-nb.info/standards/elementset/gnd#	20131115
gq	http://genomequest.com/	20131115
hxl	http://hxl.humanitarianresponse.info/ns/#	20131115
mp	http://jicamaro.info/mp#	20131115
ogbd	http://www.ogbd.fr/2012/ontologie#	20131115
olad	http://openlad.org/vocab#	20131115
ox	http://vocab.ox.ac.uk/projectfunding#	20131115
pat	http://purl.org/hpi/patchr#	20131115
pext	http://www.ontotext.com/proton/protonext#	20131115
qb4o	http://purl.org/olap#	20131115
refe	http://orion.tw.rpi.edu/~xgmatwc/refe/	20131115
swperson	http://data.semanticweb.org/person/	20131115
ub	http://www.lehigh.edu/~zhp2/2004/0401/univ-bench.owl#	20131115
bbc	http://www.bbc.co.uk/ontologies/news/	20131205
bibframe	http://bibframe.org/vocab/	20131205
bm	http://bio2rdf.org/	20131205
emoca	http://ns.inria.fr/emoca#	20131205
emotion	http://ns.inria.fr/emoca#	20131205
limoo	http://purl.org/LiMo/0.1/	20131205
mged	http://mged.sourceforge.net/ontologies/MGEDOntology.owl#	20131205
mocanal	http://www.semanticweb.org/asow/ontologies/2013/9/untitled-ontology-36#	20131205
muldicat	http://iflastandards.info/ns/muldicat#	20131205
nidm	http://nidm.nidash.org/	20131205
paia	http://purl.org/ontology/paia#	20131205
pubmed	http://bio2rdf.org/pubmed_vocabulary:	20131205
ro	http://purl.org/obo/owl/ro#	20131205
sdo	http://schema.org/	20131205
service	http://purl.org/ontology/service#	20131205
tr	http://www.thomsonreuters.com/	20131205
aat	http://vocab.getty.edu/aat/	20140901
accom	http://purl.org/acco/ns#	20140901
acrt	http://privatealpha.com/ontology/certification/1#	20140901
agrd	http://agrinepaldata.com/	20140901
agro	http://agrinepaldata.com/vocab/	20140901
app	http://jmvanel.free.fr/ontology/software_applications.n3#	20140901
asgv	http://aims.fao.org/aos/agrovoc/	20140901
aws	http://purl.oclc.org/NET/ssnx/meteo/aws#	20140901
babelnet	http://babelnet.org/2.0/	20140901
basic	http://def.seegrid.csiro.au/isotc211/iso19103/2005/basic#	20140901
bbccms	http://www.bbc.co.uk/ontologies/cms/	20140901
bbccore	http://www.bbc.co.uk/ontologies/coreconcepts/	20140901
bbcprov	http://www.bbc.co.uk/ontologies/provenance/	20140901
bco	http://purl.obolibrary.org/obo/bco.owl#	20140901
bevon	http://rdfs.co/bevon/	20140901
bihap	http://bihap.kb.gov.tr/ontology/	20140901
bis	http://bis.270a.info/dataset/	20140901
bk	http://www.provbook.org/ns/#	20140901
bwb	http://doc.metalex.eu/bwb/ontology/	20140901
call	http://webofcode.org/wfn/call:	20140901
citof	http://www.essepuntato.it/2013/03/cito-functions#	20140901
cjr	http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/callejero#	20140901
cmd	http://clarin.eu/cmd#	20140901
cmdi	http://www.clarin.eu/cmd/	20140901
cmdm	http://infra.clarin.eu/cmd/	20140901
contsem	http://contsem.unizar.es/def/sector-publico/contratacion#	20140901
csv	http://vocab.sindice.net/csv/	20140901
dblp	http://dblp.l3s.de/d2r/page/authors/	20140901
dbpedia2	http://dbpedia.org/property/	20140901
dbug	http://ontologi.es/doap-bugs#	20140901
dco	http://info.deepcarbon.net/schema#	20140901
dcoid	http://dx.deepcarbon.net/	20140901
dcq	http://purl.org/dc/qualifiers/1.0/	20140901
defns	http://www.openarchives.org/OAI/2.0/	20140901
delta	http://www.w3.org/2004/delta#	20140901
diag	http://www.loc.gov/zing/srw/diagnostic/	20140901
dicom	http://purl.org/healthcarevocab/v1#	20140901
dn	http://purl.org/datanode/ns/	20140901
dogont	http://elite.polito.it/ontologies/dogont.owl#	20140901
dpd	http://www.kanzaki.com/ns/dpd#	20140901
dq	http://def.seegrid.csiro.au/isotc211/iso19115/2003/dataquality#	20140901
dsn	http://purl.org/dsnotify/vocab/eventset/	20140901
ebucore	http://www.ebu.ch/metadata/ontologies/ebucore/ebucore#	20140901
ec	http://eulergui.sourceforge.net/contacts.owl.n3#	20140901
ecb	http://ecb.270a.info/class/1.0/	20140901
ecrm	http://erlangen-crm.org/current/	20140901
employee	http://www.employee.com/data#	20140901
erce	http://xxefe.de/	20140901
esadm	http://vocab.linkeddata.es/datosabiertos/def/sector-publico/territorio#	20140901
escjr	http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/callejero#	20140901
estatwrap	http://ontologycentral.com/2009/01/eurostat/ns#	20140901
estrn	http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/transporte#	20140901
eurlex	http://eur-lex.publicdata.eu/ontology/	20140901
evident	http://purl.org/net/evident#	20140901
ext	http://def.seegrid.csiro.au/isotc211/iso19115/2003/extent#	20140901
fabio	http://purl.org/spar/fabio/	20140901
fam	http://vocab.fusepool.info/fam#	20140901
fao	http://fao.270a.info/dataset/	20140901
fbgeo	http://rdf.freebase.com/ns/location/geocode/	20140901
fcs	http://clarin.eu/fcs/resource#	20140901
fma	http://sig.uw.edu/fma#	20140901
form	http://deductions-software.com/ontologies/forms.owl.ttl#	20140901
fp3	http://vocab.fusepool.info/fp3#	20140901
frb	http://frb.270a.info/dataset/	20140901
friends	http://www.openarchives.org/OAI/2.0/friends/	20140901
ftcontent	http://www.ft.com/ontology/content/	20140901
gaf	http://groundedannotationframework.org/	20140901
gcis	http://data.globalchange.gov/gcis.owl#	20140901
geop	http://aims.fao.org/aos/geopolitical.owl#	20140901
geos	http://www.telegraphis.net/ontology/geography/geography#	20140901
geosparql	http://www.opengis.net/ont/geosparql#	20140901
geovoid	http://purl.org/geovocamp/ontology/geovoid/	20140901
gf	http://def.seegrid.csiro.au/isotc211/iso19109/2005/feature#	20140901
gm	http://def.seegrid.csiro.au/isotc211/iso19107/2003/geometry#	20140901
govwild	http://govwild.org/0.6/GWOntology.rdf/	20140901
gts	http://resource.geosciml.org/ontology/timescale/gts#	20140901
gvp	http://vocab.getty.edu/ontology#	20140901
h2o	http://def.seegrid.csiro.au/isotc211/iso19150/-2/2012/basic#	20140901
hdo	http://www.samos.gr/ontologies/helpdeskOnto.owl#	20140901
hlygt	http://www.holygoat.co.uk/owl/redwood/0.1/tags/	20140901
hr	http://iserve.kmi.open.ac.uk/ns/hrests#	20140901
http	http://www.w3.org/2011/http#	20140901
hydra	http://www.w3.org/ns/hydra/core#	20140901
ignf	http://data.ign.fr/def/ignf#	20140901
ilap	http://data.posccaesar.org/ilap/	20140901
imf	http://imf.270a.info/dataset/	20140901
irstea	http://ontology.irstea.fr/	20140901
irsteaont	http://ontology.irstea.fr/weather/ontology#	20140901
iso	http://purl.org/iso25964/skos-thes#	20140901
isothes	http://purl.org/iso25964/skos-thes#	20140901
itm	http://spi-fm.uca.es/spdef/models/genericTools/itm/1.0#	20140901
jp1	http://rdf.muninn-project.org/ontologies/jp1/	20140901
kai	http://kai.uni-kiel.de/	20140901
keys	http://purl.org/NET/c4dm/keys.owl#	20140901
kml	http://www.opengis.net/kml/2.2#	20140901
koly	http://www.ensias.ma/	20140901
l2sp	http://www.linked2safety-project.eu/properties/	20140901
language	http://id.loc.gov/vocabulary/iso639-1/	20140901
lda	http://purl.org/linked-data/api/vocab#	20140901
ldr	http://purl.oclc.org/NET/ldr/ns#	20140901
lemon	http://www.lemon-model.net/lemon#	20140901
lexcz	http://purl.org/lex/cz#	20140901
lexicon	http://www.example.org/lexicon#	20140901
lexinfo	http://www.lexinfo.net/ontology/2.0/lexinfo#	20140901
lfov	https://w3id.org/legal_form#	20140901
li	http://def.seegrid.csiro.au/isotc211/iso19115/2003/lineage#	20140901
lime	http://art.uniroma2.it/ontologies/lime#	20140901
limo	http://www.purl.org/limo-ontology/limo#	20140901
ling	http://purl.org/voc/ling/	20140901
lio	http://purl.org/net/lio#	20140901
lmf	http://www.lexinfo.net/lmf#	20140901
locah	http://data.archiveshub.ac.uk/def/	20140901
location	http://sw.deri.org/2006/07/location/loc#	20140901
locn	http://www.w3.org/ns/locn#	20140901
lofv	http://purl.org/legal_form/vocab#	20140901
loted	http://loted.eu/ontology#	20140901
mammal	http://lod.taxonconcept.org/ontology/p01/Mammalia/index.owl#	20140901
marl	http://www.gsi.dit.upm.es/ontologies/marl/ns#	20140901
maso	http://securitytoolbox.appspot.com/MASO#	20140901
mb	http://dbtune.org/musicbrainz/resource/instrument/	20140901
metadata	http://purl.oreilly.com/ns/meta/	20140901
mf	http://www.w3.org/2001/sw/DataAccess/tests/test-manifest#	20140901
mm	http://linkedmultimedia.org/sparql-mm/functions#	20140901
mmt	http://linkedmultimedia.org/sparql-mm/functions/temporal#	20140901
msm	http://iserve.kmi.open.ac.uk/ns/msm#	20140901
mt	http://www.w3.org/2001/sw/DataAccess/tests/test-manifest#	20140901
muni	http://vocab.linkeddata.es/urbanismo-infraestructuras/territorio#	20140901
my	http://www.mobile.com/model/	20140901
naval	http://rdf.muninn-project.org/ontologies/naval#	20140901
navm	https://w3id.org/navigation_menu#	20140901
ndl	http://schemas.ogf.org/nml/2013/05/base#	20140901
nxs	http://www.neclimateus.org/	20140901
nyt	http://data.nytimes.com/	20140901
oad	http://lod.xdams.org/reload/oad/	20140901
oan	http://data.lirmm.fr/ontologies/oan/	20140901
od	http://purl.org/twc/vocab/opendap#	20140901
odapps	http://semweb.mmlab.be/ns/odapps#	20140901
odrl	http://www.w3.org/ns/odrl/2/	20140901
odrs	http://schema.theodi.org/odrs#	20140901
of	http://owlrep.eu01.aws.af.cm/fridge#	20140901
oh	http://semweb.mmlab.be/ns/oh#	20140901
oils	http://lemon-model.net/oils#	20140901
olac	http://www.language-archives.org/OLAC/1.0/	20140901
olac11	http://www.language-archives.org/OLAC/1.1/	20140901
olca	http://www.lingvoj.org/olca#	20140901
om	http://opendata.caceres.es/def/ontomunicipio#	20140901
omdoc	http://omdoc.org/ontology/	20140901
onisep	http://rdf.onisep.fr/resource/	20140901
ont	http://purl.org/net/ns/ontology-annot#	20140901
ontosec	http://www.semanticweb.org/ontologies/2008/11/OntologySecurity.owl#	20140901
onyx	http://www.gsi.dit.upm.es/ontologies/onyx/ns#	20140901
op	http://environment.data.gov.au/def/op#	20140901
openskos	http://openskos.org/xmlns#	20140901
oplacl	http://www.openlinksw.com/ontology/acl#	20140901
oplprod	http://www.openlinksw.com/ontology/products#	20140901
oplres	http://www.openlinksw.com/ontology/restrictions#	20140901
origins	http://origins.link/	20140901
oslo	http://purl.org/oslo/ns/localgov#	20140901
parl	http://reference.data.gov.uk/def/parliament/	20140901
pattern	http://www.essepuntato.it/2008/12/pattern#	20140901
pco	http://purl.org/procurement/public-contracts#	20140901
physo	http://merlin.phys.uni.lodz.pl/onto/physo/physo.owl#	20140901
pic	http://www.ipaw.info/ns/picaso#	20140901
pkm	http://www.ontotext.com/proton/protonkm#	20140901
plo	http://purl.org/net/po#	20140901
pnc	http://data.press.net/ontology/classification/	20140901
pni	http://data.press.net/ontology/identifier/	20140901
pnt	http://data.press.net/ontology/tag/	20140901
pproc	http://contsem.unizar.es/def/sector-publico/pproc#	20140901
provone	http://purl.org/provone#	20140901
psys	http://www.ontotext.com/proton/protonsys#	20140901
purl	http://purl.org/dc/terms/	20140901
pvcs	http://purl.org/twc/vocab/pvcs#	20140901
qu	http://purl.oclc.org/NET/ssnx/qu/qu#	20140901
rdaa	http://rdaregistry.info/Elements/a/	20140901
rdac	http://rdaregistry.info/Elements/c/	20140901
rdae	http://rdaregistry.info/Elements/e/	20140901
rdag2	http://rdvocab.info/ElementsGr2/	20140901
rdai	http://rdaregistry.info/Elements/i/	20140901
rdam	http://rdaregistry.info/Elements/m/	20140901
rdarel2	http://metadataregistry.org/uri/schema/RDARelationshipsGR2/	20140901
rdau	http://rdaregistry.info/Elements/u/	20140901
rdaw	http://rdaregistry.info/Elements/w/	20140901
rdl	http://data.posccaesar.org/rdl/	20140901
reegle	http://reegle.info/schema#	20140901
roadmap	http://mappings.roadmap.org/	20140901
rso	http://www.researchspace.org/ontology/	20140901
ru	http://purl.org/imbi/ru-meta.owl#	20140901
ruto	http://rdfunit.aksw.org/ns/core#	20140901
rvl	http://purl.org/rvl/	20140901
sad	http://vocab.deri.ie/sad#	20140901
sam	http://def.seegrid.csiro.au/isotc211/iso19156/2011/sampling#	20140901
sao	http://salt.semanticauthoring.org/ontologies/sao#	20140901
sbench	http://swat.cse.lehigh.edu/onto/univ-bench.owl#	20140901
scip	http://lod.taxonconcept.org/ontology/sci_people.owl#	20140901
scoro	http://purl.org/spar/scoro/	20140901
sdo	http://salt.semanticauthoring.org/ontologies/sdo#	20140901
security	http://securitytoolbox.appspot.com/securityMain#	20140901
ses	http://lod.taxonconcept.org/ses/	20140901
sf	http://www.opengis.net/ont/sf#	20140901
shex	http://www.w3.org/2013/ShEx/ns#	20140901
shw	http://paul.staroch.name/thesis/SmartHomeWeather.owl#	20140901
siocserv	http://rdfs.org/sioc/services#	20140901
skos08	http://www.w3.org/2008/05/skos#	20140901
sparql	http://ontologi.es/sparql#	20140901
spcm	http://spi-fm.uca.es/spdef/models/deployment/spcm/1.0#	20140901
spdx	http://spdx.org/rdf/terms#	20140901
spfood	http://kmi.open.ac.uk/projects/smartproducts/ontologies/food.owl#	20140901
sql	http://ns.inria.fr/ast/sql#	20140901
sro	http://salt.semanticauthoring.org/ontologies/sro#	20140901
sru	http://www.loc.gov/zing/srw/	20140901
ssn	http://purl.oclc.org/NET/ssnx/ssn#	20140901
stanford	http://purl.org/olia/stanford.owl#	20140901
static	http://vocab-ld.org/vocab/static-ld#	20140901
stories	http://purl.org/ontology/stories/	20140901
swpm	http://spi-fm.uca.es/spdef/models/deployment/swpm/1.0#	20140901
swrcfe	http://www.morelab.deusto.es/ontologies/swrcfe#	20140901
tac	http://ns.bergnet.org/tac/0.1/triple-access-control#	20140901
tavprov	http://ns.taverna.org.uk/2012/tavernaprov/	20140901
taxon	http://purl.org/biodiversity/taxon/	20140901
tddo	http://databugger.aksw.org/ns/core#	20140901
tgn	http://vocab.getty.edu/tgn/	20140901
thors	http://resource.geosciml.org/ontology/timescale/thors#	20140901
tm	http://def.seegrid.csiro.au/isotc211/iso19108/2002/temporal#	20140901
topo	http://data.ign.fr/def/topo#	20140901
travel	http://www.co-ode.org/roberts/travel.owl#	20140901
trig	http://www.w3.org/2004/03/trix/rdfg-1/	20140901
tw	http://tw.rpi.edu/schema/	20140901
uis	http://uis.270a.info/dataset/	20140901
ulan	http://vocab.getty.edu/ulan/	20140901
un	http://www.w3.org/2007/ont/unit#	20140901
unspsc	http://ontoview.org/schema/unspsc/1#	20140901
uri4uri	http://uri4uri.net/vocab#	20140901
va	http://code-research.eu/ontology/visual-analytics#	20140901
vext	http://ldf.fi/void-ext#	20140901
vgo	http://purl.org/net/vgo#	20140901
videogame	http://purl.org/net/vgo#	20140901
vin	http://www.w3.org/TR/2003/PR-owl-guide-20031209/wine#	20140901
viso	http://purl.org/viso/	20140901
vmm	http://spi-fm.uca.es/spdef/models/genericTools/vmm/1.0#	20140901
voidext	http://rdfs.org/ns/void-ext#	20140901
voidwh	http://www.ics.forth.gr/isl/VoIDWarehouse/VoID_Extension_Schema.owl#	20140901
vra	http://simile.mit.edu/2003/10/ontologies/vraCore3#	20140901
wfn	http://webofcode.org/wfn/	20140901
whisky	http://vocab.org/whisky/terms/	20140901
wi	http://purl.org/ontology/wi/core#	20140901
wiki	http://en.wikipedia.org/wiki/	20140901
wikim	http://spi-fm.uca.es/spdef/models/genericTools/wikim/1.0#	20140901
wikimedia	http://upload.wikimedia.org/wikipedia/commons/f/f6/	20140901
wn30	http://purl.org/vocabularies/princeton/wn30/	20140901
xml	http://www.w3.org/XML/1998/namespace/	20140901
xsi	http://www.w3.org/2001/XMLSchema-instance#	20140901
xslopm	http://purl.org/net/opmv/types/xslt#	20140901
zr	http://explain.z3950.org/dtd/2.0/	20140901
abs	http://abs.270a.info/dataset/	20140908
article	http://ogp.me/ns/article#	20140908
cdc	http://www.contextdatacloud.org/resource/	20140908
opencyc	http://sw.opencyc.org/concept/	20140908
smg	http://ns.cerise-project.nl/energy/def/cim-smartgrid#	20140908
opllic	http://www.openlinksw.com/ontology/licenses#	20140909
affymetrix	http://bio2rdf.org/affymetrix_vocabulary:	20150725
airs	https://raw.githubusercontent.com/airs-linked-data/lov/latest/src/airs_vocabulary.ttl#	20150725
aktivesa	http://sa.aktivespace.org/ontologies/aktivesa#	20150725
amsl	http://vocab.ub.uni-leipzig.de/amsl/	20150725
as	http://www.w3.org/ns/activitystreams#	20150725
bag	http://lod.geodan.nl/vocab/bag#	20150725
beth	http://www.google.com/	20150725
bfo	http://www.ifomis.org/bfo/1.1#	20150725
bgcat	http://bg.dbpedia.org/resource/Категория:	20150725
bgdbp	http://bg.dbpedia.org/property/	20150725
bgdbr	http://bg.dbpedia.org/resource/	20150725
bgn	http://bibliograph.net/schemas/	20150725
bibrm	http://vocab.ub.uni-leipzig.de/bibrm/	20150725
biopax	http://www.biopax.org/release/biopax-level3.owl#	20150725
blt	http://www.bl.uk/schemas/bibliographic/blterms#	20150725
bmo	http://collection.britishmuseum.org/id/ontology/	20150725
bn	http://babelnet.org/rdf/	20150725
bner	http://datos.bne.es/resource/	20150725
bnf	http://www.w3.org/2000/10/swap/grammar/bnf#	20150725
bridge	http://purl.org/vocommons/bridge#	20150725
bsym	http://bsym.bloomberg.com/sym/	20150725
bv	http://purl.org/vocommons/bv#	20150725
c9d	http://purl.org/twc/vocab/conversion/	20150725
caplibacl	http://schemas.capita-libraries.co.uk/2015/acl/schema#	20150725
cart	http://purl.org/net/cartCoord#	20150725
cbo	http://comicmeta.org/cbo/	20150725
ccrel	http://creativecommons.org/ns#	20150725
cex	http://purl.org/weso/computex/ontology#	20150725
cff	http://purl.oclc.org/NET/ssnx/cf/cf-feature#	20150725
changeset	http://purl.org/vocab/changeset/schema#	20150725
chembl	http://rdf.ebi.ac.uk/terms/chembl#	20150725
cl	http://advene.org/ns/cinelab/	20150725
clirio	http://clirio.kaerle.com/clirio.owl#	20150725
company	http://intellimind.io/ns/company#	20150725
condition	http://www.kinjal.com/condition:	20150725
cpant	http://purl.org/NET/cpan-uri/terms#	20150725
cpsv	http://purl.org/vocab/cpsv#	20150725
crmdig	http://www.ics.forth.gr/isl/CRMext/CRMdig.rdfs/	20150725
cv	http://rdfs.org/resume-rdf/	20150725
cwl	https://w3id.org/cwl/cwl#	20150725
cwork	http://www.bbc.co.uk/ontologies/creativework/	20150725
d0	http://ontologydesignpatterns.org/ont/wikipedia/d0.owl#	20150725
d2d	http://rdfns.org/d2d/	20150725
dannet	http://www.wordnet.dk/owl/instance/2009/03/instances/	20150725
daq	http://purl.org/eis/vocab/daq#	20150725
date	http://contextus.net/ontology/ontomedia/misc/date#	20150725
dbcat	http://dbpedia.org/resource/Category:	20150725
dblp	http://dblp.uni-trier.de/rdf/schema-2015-01-26#	20150725
dcs	http://ontologi.es/doap-changeset#	20150725
decision	https://decision-ontology.googlecode.com/svn/trunk/decision.owl#	20150725
demlab	http://www.demcare.eu/ontologies/demlab.owl#	20150725
deps	http://ontologi.es/doap-deps#	20150725
dgfr	http://colin.maudry.com/ontologies/dgfr#	20150725
dicera	http://semweb.mmlab.be/ns/dicera#	20150725
dm2e	http://onto.dm2e.eu/schemas/dm2e/	20150725
doas	http://deductions-software.com/ontologies/doas.owl.ttl#	20150725
dpc	http://dpc.Data/	20150725
ecc	https://ns.eccenca.com/	20150725
eccrev	https://vocab.eccenca.com/revision/	20150725
ecgl	http://schema.geolink.org/	20150725
ecglview	http://schema.geolink.org/view/	20150725
eclap	http://www.eclap.eu/schema/eclap/	20150725
edgarcik	http://edgarwrap.ontologycentral.com/cik/	20150725
emtr	http://purl.org/NET/ssnext/electricmeters#	20150725
esaloj	http://vocab.linkeddata.es/datosabiertos/def/turismo/alojamiento#	20150725
esapar	http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/aparcamiento#	20150725
esco	http://data.europa.eu/esco/model#	20150725
escom	http://vocab.linkeddata.es/datosabiertos/def/comercio/tejidoComercial#	20150725
esdir	http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/direccionPostal#	20150725
esequip	http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/equipamiento#	20150725
espresup	http://vocab.linkeddata.es/datosabiertos/def/hacienda/presupuestos#	20150725
essglobal	http://purl.org/essglobal/vocab/v1.0/	20150725
estrf	http://vocab.linkeddata.es/datosabiertos/def/transporte/trafico#	20150725
ev	http://www.w3.org/2001/xml-events/	20150725
factbook	http://wifo5-04.informatik.uni-mannheim.de/factbook/ns#	20150725
faldo	http://biohackathon.org/resource/faldo#	20150725
faq	http://www.openlinksw.com/ontology/faq#	20150725
fdbp	http://fr.dbpedia.org/property/	20150725
figigii	http://www.omg.org/spec/FIGI/GlobalInstrumentIdentifiers/	20150725
fluidops	http://www.fluidops.com/	20150725
galaksiya	http://ontoloji.galaksiya.com/vocab/	20150725
geojson	http://ld.geojson.org/vocab#	20150725
gl	http://schema.geolink.org/	20150725
glview	http://schema.geolink.org/dev/view/	20150725
gml	http://www.opengis.net/ont/gml#	20150725
gnd	http://d-nb.info/gnd/	20150725
gov	http://gov.genealogy.net/ontology.owl#	20150725
gpml	http://vocabularies.wikipathways.org/gpml#	20150725
gtfs	http://vocab.gtfs.org/terms#	20150725
guo	http://purl.org/hpi/guo#	20150725
ha	http://sensormeasurement.appspot.com/ont/home/homeActivity#	20150725
hasneto	http://jefferson.tw.rpi.edu/ontology/hasneto#	20150725
holding	http://purl.org/ontology/holding#	20150725
hp	http://pictogram.tokyo/vocabulary#	20150725
ic	http://imi.ipa.go.jp/ns/core/210#	20150725
imind	http://schema.intellimind.ns/symbology#	20150725
insdc	http://ddbj.nig.ac.jp/ontologies/sequence#	20150725
isocat	http://www.isocat.org/datcat/	20150725
itcat	http://th-brandenburg.de/ns/itcat#	20150725
jerm	http://www.mygrid.org.uk/ontology/JERMOntology#	20150725
kegg	http://bio2rdf.org/ns/kegg#	20150725
lawd	http://lawd.info/ontology/	20150725
lc	http://semweb.mmlab.be/ns/linkedconnections#	20150725
lcdr	http://ns.lucid-project.org/revision/	20150725
lden	http://www.linklion.org/lden/	20150725
ldvm	http://linked.opendata.cz/ontology/ldvm/	20150725
lemon	http://lemon-model.net/lemon#	20150725
lemonuby	http://lemon-model.net/lexica/uby/	20150725
lgd	http://linkedgeodata.org/ontology/	20150725
lindt	http://purl.org/NET/lindt#	20150725
ljkl	http://teste.com/	20150725
ll	http://lodlaundromat.org/resource/	20150725
llm	http://lodlaundromat.org/metrics/ontology/	20150725
llo	http://lodlaundromat.org/ontology/	20150725
llont	http://www.linklion.org/ontology#	20150725
lmx	http://www.w3.org/XML/1998/namespace/	20150725
lpeu	http://purl.org/linkedpolitics/vocabulary/eu/plenary/	20150725
ls	http://linkedspending.aksw.org/instance/	20150725
lsd	http://linkedwidgets.org/statisticaldata/ontology/	20150725
lso	http://linkedspending.aksw.org/ontology/	20150725
lsqv	http://lsq.aksw.org/vocab#	20150725
luc	http://www.ontotext.com/owlim/lucene#	20150725
lw	http://linkedwidgets.org/ontologies/	20150725
mbgd	http://mbgd.genome.ad.jp/owl/mbgd.owl#	20150725
mexalgo	http://mex.aksw.org/mex-algo#	20150725
mexcore	http://mex.aksw.org/mex-core#	20150725
mexperf	http://mex.aksw.org/mex-perf#	20150725
mexv	http://mex.aksw.org/mex-algo#	20150725
mico	http://www.mico-project.eu/ns/platform/1.0/schema#	20150725
minim	http://purl.org/minim/minim#	20150725
mmd	http://musicbrainz.org/ns/mmd-1.0#	20150725
mmf	http://linkedmultimedia.org/sparql-mm/ns/1.0.0/function#	20150725
mtlo	http://www.ics.forth.gr/isl/MarineTLO/v4/marinetlo.owl#	20150725
ncit	http://ncicb.nci.nih.gov/xml/owl/EVS/Thesaurus.owl#	20150725
nerd	http://nerd.eurecom.fr/ontology#	20150725
newsevents	http://www.aifb.uni-karlsruhe.de/WBS/uhe/ontologies#	20150725
nex	http://www.nexml.org/2009/	20150725
nfo	http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#	20150725
npdv	http://sws.ifi.uio.no/vocab/npd#	20150725
oae	http://www.ics.forth.gr/isl/oae/core#	20150725
oboinowl	http://www.geneontology.org/formats/oboInOwl#	20150725
odbc	http://www.openlinksw.com/ontology/odbc#	20150725
odo	http://ocean-data.org/schema/	20150725
ofrd	http://purl.org/opdm/refrigerator#	20150725
omn	http://open-multinet.info/ontology/omn#	20150725
omnfed	http://open-multinet.info/ontology/omn-federation#	20150725
omnlife	http://open-multinet.info/ontology/omn-lifecycle#	20150725
onc	http://www.ics.forth.gr/isl/oncm/core#	20150725
onto	http://www.ontotext.com/	20150725
opengov	http://www.w3.org/opengov#	20150725
oplcb	http://www.openlinksw.com/schemas/crunchbase#	20150725
oplcert	http://www.openlinksw.com/schemas/cert#	20150725
oplecrm	http://www.openlinksw.com/ontology/ecrm#	20150725
oplmkt	http://www.openlinksw.com/ontology/market#	20150725
ops	http://vocabularies.bridgedb.org/ops#	20150725
oss	http://opendata.caceres.es/def/ontosemanasanta#	20150725
owsom	https://onlinesocialmeasures.wordpress.com/	20150725
oxi	http://omerxi.com/ontologies/core.owl.ttl#	20150725
phdd	http://rdf-vocabulary.ddialliance.org/phdd#	20150725
phil	http://philosurfical.open.ac.uk/ontology/philosurfical.owl#	20150725
piero	http://reactionontology.org/piero/	20150725
pim	http://www.w3.org/ns/pim/space#	20150725
pod	https://project-open-data.cio.gov/v1.1/schema/#	20150725
quantity	http://qudt.org/schema/quantity#	20150725
r4r	http://guava.iis.sinica.edu.tw/r4r/	20150725
ramon	http://rdfdata.eionet.europa.eu/ramon/ontology/	20150725
rda	http://www.rdaregistry.info/	20150725
rdabf	http://rdaregistry.info/termList/bookFormat/	20150725
rdabm	http://rdaregistry.info/termList/RDABaseMaterial/	20150725
rdacc	http://rdaregistry.info/termList/RDAColourContent/	20150725
rdacct	http://rdaregistry.info/termList/collTitle/	20150725
rdaco	http://rdaregistry.info/termList/RDAContentType/	20150725
rdact	http://rdaregistry.info/termList/RDACarrierType/	20150725
rdaemm	http://rdaregistry.info/termList/emulsionMicro/	20150725
rdafmn	http://rdaregistry.info/termList/MusNotation/	20150725
rdafnm	http://rdaregistry.info/termList/FormNoteMus/	20150725
rdafnv	http://rdaregistry.info/termList/noteForm/	20150725
rdafr	http://rdaregistry.info/termList/frequency/	20150725
rdafs	http://rdaregistry.info/termList/fontSize/	20150725
rdaftn	http://rdaregistry.info/termList/TacNotation/	20150725
rdagd	http://rdaregistry.info/termList/gender/	20150725
rdagrp	http://rdaregistry.info/termList/groovePitch/	20150725
rdagw	http://rdaregistry.info/termList/grooveWidth/	20150725
rdami	http://rdaregistry.info/termList/modeIssue/	20150725
rdamt	http://rdaregistry.info/termList/RDAMediaType/	20150725
rdapmt	http://rdaregistry.info/termList/prodTactile/	20150725
rdapo	http://rdaregistry.info/termList/RDAPolarity/	20150725
rdarm	http://registry.info/termList/recMedium/	20150725
rdarr	http://rdaregistry.info/termList/RDAReductionRatio/	20150725
rdasco	http://rdaregistry.info/termList/soundCont/	20150725
rdasoi	http://rdaregistry.info/termList/statIdentification/	20150725
rdatc	http://rdaregistry.info/termList/trackConfig/	20150725
rdatr	http://rdaregistry.info/termList/typeRec/	20150725
rdaz	http://rdaregistry.info/Elements/z/	20150725
religion	http://rdf.muninn-project.org/ontologies/religion#	20150725
remetca	http://www.purl.org/net/remetca#	20150725
rml	http://semweb.mmlab.be/ns/rml#	20150725
rmo	http://eatld.et.tu-dresden.de/rmo#	20150725
ro	http://purl.org/wf4ever/ro#	20150725
rofch	http://rdaregistry.info/termList/rofch/	20150725
rofem	http://rdaregistry.info/termList/rofem/	20150725
rofer	http://rdaregistry.info/termList/rofer/	20150725
rofet	http://rdaregistry.info/termList/rofet/	20150725
rofhf	http://rdaregistry.info/termList/rofhf/	20150725
rofid	http://rdaregistry.info/termList/rofid/	20150725
rofim	http://rdaregistry.info/termList/rofim/	20150725
rofin	http://rdaregistry.info/termList/rofin/	20150725
rofit	http://rdaregistry.info/termList/rofit/	20150725
rofrm	http://rdaregistry.info/termList/rofrm/	20150725
rofrr	http://rdaregistry.info/termList/rofrr/	20150725
rofrt	http://rdaregistry.info/termList/rofrt/	20150725
rs	http://spektrum.ctu.cz/ontologies/radio-spectrum#	20150725
rvdata	http://data.rvdata.us/	20150725
sakthi	http://infotech.nitk.ac.in/research-scholars/sakthi-murugan-r/	20150725
san	http://www.irit.fr/recherches/MELODI/ontologies/SAN.owl#	20150725
saws	http://purl.org/saws/ontology#	20150725
scot	http://rdfs.org/scot/ns#	20150725
sdo	http://schema.org/	20150725
seas	http://purl.org/NET/seas#	20150725
sh	http://www.w3.org/ns/shacl#	20150725
shoah	http://dati.cdec.it/lod/shoah/	20150725
soc	http://purl.org/net/hdlipcores/ontology/soc#	20150725
st	http://semweb.mmlab.be/ns/stoptimes#	20150725
sw	http://linkedwidgets.org/statisticalwidget/ontology/	20150725
swcomp	https://github.com/ali1k/ld-reactor/blob/master/vocabulary/index.ttl#	20150725
tadirah	http://tadirah.dariah.eu/vocab/	20150725
td5	http://td5.org/#	20150725
traffic	http://www.sensormeasurement.appspot.com/ont/transport/traffic#	20150725
ubiq	http://server.ubiqore.com/ubiq/core#	20150725
um	http://intelleo.eu/ontologies/user-model/ns/	20150725
uneskos	http://purl.org/voc/uneskos#	20150725
vacseen1	http://www.semanticweb.org/parthasb/ontologies/2014/6/vacseen1/	20150725
vag	http://www.essepuntato.it/2013/10/vagueness/	20150725
verb	http://w3id.org/verb/	20150725
vgo	http://purl.org/net/VideoGameOntology#	20150725
vidont	http://vidont.org/	20150725
vstoi	http://jefferson.tw.rpi.edu/ontology/vstoi#	20150725
wb	http://data.worldbank.org/	20150725
webservice	http://www.openlinksw.com/ontology/webservices#	20150725
wn31	http://wordnet-rdf.princeton.edu/wn31/	20150725
wno	http://wordnet-rdf.princeton.edu/ontology#	20150725
wro	http://purl.org/net/wf4ever/ro#	20150725
xcql	http://docs.oasis-open.org/ns/search-ws/xcql#	20150725
xfn	http://gmpg.org/xfn/11#	20150725
xlime	http://xlime-project.org/vocab/	20150725
xrd	http://docs.oasis-open.org/ns/xri/xrd-1.0#	20150725
yo	http://yovisto.com/	20150725
ali	http://www.niso.org/schemas/ali/1.0/	20160408
aozora	http://purl.org/net/aozora/	20160408
auto	http://auto.schema.org/	20160408
b3kat	http://lod.b3kat.de/title/	20160408
bd	http://www.bigdata.com/rdf#	20160408
bgcat	http://bg.dbpedia.org/resource/?????????:	20160408
bif	http://www.openlinksw.com/schemas/bif#	20160408
bsb	http://opacplus.bsb-muenchen.de/title/	20160408
cordis	http://cordis.europa.eu/projects/	20160408
csdbp	http://cs.dbpedia.org/	20160408
csvw	http://www.w3.org/ns/csvw#	20160408
ctxdesc	http://www.demcare.eu/ontologies/contextdescriptor.owl#	20160408
cue	http://www.clarin.eu/cmdi/cues/display/1.0#	20160408
data	http://data.odw.tw/	20160408
datacite	http://purl.org/spar/datacite/	20160408
dataid	http://dataid.dbpedia.org/ns/core#	20160408
dbpediaowl	http://dbpedia.org/owl/	20160408
dcodt	http://info.deepcarbon.net/datatype/schema#	20160408
dcosample	http://info.deepcarbon.net/sample/schema#	20160408
dio	https://w3id.org/dio#	20160408
door	http://kannel.open.ac.uk/ontology#	20160408
dpc	http://hospee.org/ontologies/dpc/	20160408
dpla	http://dp.la/info/developers/map/	20160408
dqc	http://semwebquality.org/ontologies/dq-constraints#	20160408
dqv	http://www.w3.org/ns/dqv#	20160408
dsfv	http://sws.ifi.uio.no/vocab/dsf/henriwi/dsf#	20160408
dsv	http://purl.org/iso25964/DataSet/Versioning#	20160408
eccauth	https://vocab.eccenca.com/auth/	20160408
eccdi	https://vocab.eccenca.com/di/	20160408
ecowlim	http://ecowlim.tfri.gov.tw/lode/resource/	20160408
edac	http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-edac.owl#	20160408
eem	http://purl.org/eem#	20160408
efd	http://data.foodanddrinkeurope.eu/ontology#	20160408
eli	http://data.europa.eu/eli/ontology#	20160408
elod	http://linkedeconomy.org/ontology#	20160408
esair	http://vocab.linkeddata.es/datosabiertos/def/medio-ambiente/calidad-aire#	20160408
estatgph	http://estatwrap.ontologycentral.com/id/nama_aux_gph#	20160408
ethc	http://ethoinformatics.org/ethocore/	20160408
eurostat	http://wifo5-04.informatik.uni-mannheim.de/eurostat/resource/eurostat/	20160408
ex	http://example.org/	20160408
fe	http://www.ontologydesignpatterns.org/ont/framenet/abox/fe/	20160408
fire	http://tldp.org/HOWTO/XML-RPC-HOWTO/xmlrpc-howto-java.html#	20160408
fn	http://www.ontologydesignpatterns.org/ont/framenet/tbox/	20160408
fnabox	http://www.ontologydesignpatterns.org/ont/framenet/abox/	20160408
fntbox	http://www.ontologydesignpatterns.org/ont/framenet/tbox/	20160408
foo	http://filmontology.org/ontology/1.0/	20160408
frame	http://www.ontologydesignpatterns.org/ont/framenet/abox/frame/	20160408
frappe	http://streamreasoning.org/ontologies/frappe#	20160408
gci	http://ontology.eil.utoronto.ca/GCI/Foundation/GCI-Foundation.owl#	20160408
gist	http://ontologies.semanticarts.com/gist#	20160408
glycan	http://purl.jp/bio/12/glyco/glycan#	20160408
gns	http://sws.geonames.org/	20160408
go	http://purl.org/obo/owl/GO#	20160408
gont	https://gont.ch/	20160408
goog	http://schema.googleapis.com/	20160408
gs1	http://gs1.org/voc/	20160408
hasneto	http://hadatac.org/ont/hasneto#	20160408
hello	https://www.youtube.com/user/SuperTellAFriend/featured/	20160408
hto	http://project-haystack.org/hto#	20160408
ianarel	http://www.iana.org/assignments/relation/	20160408
ic	http://imi.ipa.go.jp/ns/core/rdf#	20160408
ideotalex	http://www.ideotalex.eu/datos/recurso/	20160408
iiif	http://iiif.io/api/image/2#	20160408
incident	http://vocab.resc.info/incident#	20160408
input	http://volt-name.space/vocab/input#	20160408
ipo	http://purl.org/ipo/core#	20160408
isbdu	http://iflastandards.info/ns/isbd/unc/elements/	20160408
iso37120	http://ontology.eil.utoronto.ca/ISO37120.owl#	20160408
jolux	http://data.legilux.public.lu/schema/jolux/	20160408
juso	http://rdfs.co/juso/	20160408
kbv	https://id.kb.se/vocab/	20160408
km4c	http://www.disit.org/km4city/schema#	20160408
lcsh	http://id.loc.gov/authorities/subjects/	20160408
lgd	http://linkedgeodata.org/triplify/	20160408
lgdm	http://linkedgeodata.org/meta/	20160408
lgdt	http://linkedgeodata.org/triplify/	20160408
lheo	http://www.conjecto.com/ontology/2015/lheo#	20160408
lslife	http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-lifemapper.owl#	20160408
lsmap	http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-data.owl#	20160408
lsweb	http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-data.owl#	20160408
lswmo	http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-modelling.owl#	20160408
lswpm	http://ontology.cybershare.utep.edu/ELSEWeb/elseweb-lifemapper-parameters.owl#	20160408
lu	http://www.ontologydesignpatterns.org/ont/framenet/abox/lu/	20160408
maeco	http://edg.topbraid.solutions/maeco/	20160408
maet	http://edg.topbraid.solutions/taxonomy/macroeconomics/	20160408
master1	http://idl.u-grenoble3.fr/	20160408
media	http://purl.org/media#	20160408
mm	http://linkedmultimedia.org/sparql-mm/ns/1.0.0/function#	20160408
moo	http://www.movieontology.org/2009/11/09/movieontology.owl#	20160408
mu	http://mu.semte.ch/vocabularies/core/	20160408
mv	http://eccenca.com/mobivoc/	20160408
ncicp	http://ncicb.nci.nih.gov/xml/owl/EVS/Thesaurus.owl#	20160408
nlon	http://lod.nl.go.kr/ontology/	20160408
ns1	http://www.w3.org/1999/xhtml/vocab#	20160408
odw	http://odw.tw/	20160408
ogc	http://www.opengis.net/ont/geosparql#	20160408
oml	http://def.seegrid.csiro.au/ontology/om/om-lite#	20160408
open311	http://ontology.eil.utoronto.ca/open311#	20160408
opllog	http://www.openlinksw.com/ontology/logging#	20160408
oplweb	http://www.openlinksw.com/schemas/oplweb#	20160408
orges	http://datos.gob.es/def/sector-publico/organizacion#	20160408
orgesv2	http://datos.gob.es/sites/default/files/OntologiaDIR3/orges.owl#	20160408
orth	http://purl.jp/bio/11/orth#	20160408
ost	http://w3id.org/ost/ns#	20160408
ou	http://opendata.unex.es/def/ontouniversidad#	20160408
output	http://volt-name.space/vocab/output#	20160408
owl2xml	http://www.w3.org/2006/12/owl2-xml#	20160408
pay	http://reference.data.gov.uk/def/payment#	20160408
pbody	http://reference.data.gov.uk/def/public-body/	20160408
pcit	http://public-contracts.nexacenter.org/id/propertiesRole/	20160408
pid	http://permid.org/ontology/organization/	20160408
pmhb	http://pmhb.org/	20160408
pp	http://peoplesplaces.de/ontology#	20160408
proms	http://promsns.org/def/proms#	20160408
provoc	http://ns.inria.fr/provoc/	20160408
psv	http://www.wikidata.org/prop/statement/value/	20160408
puml	http://plantuml.com/ontology#	20160408
pv	http://ns.inria.fr/provoc#	20160408
qms	http://data.europa.eu/esco/qms#	20160408
rdacct	http://rdaregistry.info/termList/CollTitle/	20160408
regorg	http://www.w3.org/ns/regorg#	20160408
rfd	http://com.intrinsec//ontology#	20160408
rgml	http://purl.org/puninj/2001/05/rgml-schema#	20160408
rimmf	http://rimmf.com/vocab/	20160408
rm	http://jazz.net/ns/rm#	20160408
rofsf	http://rdaregistry.info/termList/rofsf/	20160408
rofsm	http://rdaregistry.info/termList/rofsm/	20160408
rpath	https://w3id.org/lodsight/rdf-path#	20160408
rut	http://rdfunit.aksw.org/ns/core#	20160408
samfl	http://def.seegrid.csiro.au/ontology/om/sam-lite#	20160408
saref	http://ontology.tno.nl/saref#	20160408
scco	http://rdf.ebi.ac.uk/terms/surechembl#	20160408
scholl	http://menemeneml.com/school#	20160408
scor	http://purl.org/eis/vocab/scor#	20160408
sct	http://snomed.info/sct/	20160408
sdshare	http://www.sdshare.org/2012/extension/	20160408
sdt	http://statisticaldata.linkedwidgets.org/terms/	20160408
sem	http://www.ontologydesignpatterns.org/cp/owl/semiotics.owl#	20160408
si	http://sisteminformasi.com/	20160408
smxm	http://smxm.ga/	20160408
snac	http://socialarchive.iath.virginia.edu/	20160408
sor	http://purl.org/net/soron/	20160408
srx	http://www.w3.org/2005/sparql-results#	20160408
step	http://purl.org/net/step#	20160408
teamwork	http://topbraid.org/teamwork#	20160408
text	http://jena.apache.org/text#	20160408
theme	http://voc.odw.tw/theme/	20160408
tix	http://toptix.com/2010/esro/	20160408
tp	http://tour-pedia.org/download/tp.owl#	20160408
type	http://info.deepcarbon.net/schema/type#	20160408
uby	http://purl.org/olia/ubyCat.owl#	20160408
uom	http://www.opengis.net/def/uom/OGC/1.0/	20160408
valueflows	https://w3id.org/valueflows/	20160408
vf	https://w3id.org/valueflows/	20160408
voc	http://voc.odw.tw/	20160408
vocnet	http://schema.vocnet.org/	20160408
volt	http://volt-name.space/ontology/	20160408
vort	http://rockets.topbraid.solutions/vort/	20160408
vsearch	http://vocab.sti2.at/vsearch#	20160408
vstoi	http://hadatac.org/ont/vstoi#	20160408
wail	http://www.eyrie.org/~zednenem/2002/wail/	20160408
wde	http://www.wikidata.org/entity/	20160408
wdt	http://www.wikidata.org/prop/direct/	20160408
wikibase	http://wikiba.se/ontology#	20160408
wimpo	http://rdfex.org/withImports?uri=	20160408
wsdl	http://www.w3.org/ns/wsdl-rdf#	20160408
xapi	http://purl.org/xapi/ontology#	20160408
xkos	http://rdf-vocabulary.ddialliance.org/xkos#	20160408
yd	https://yodata.io/	20160408
dwciri	http://rs.tdwg.org/dwc/iri/	20160409
sdterms	http://statisticaldata.linkedwidgets.org/terms/	20160409
apf	http://jena.apache.org/ARQ/property#	20170111
art	http://w3id.org/art/terms/1.0/	20170111
asawoo	http://liris.cnrs.fr/asawoo/	20170111
bb	http://www.snik.eu/ontology/bb/	20170111
bblfish	http://bblfish.net/people/henry/card#	20170111
biml	http://schemas.varigence.com/biml.xsd#	20170111
bioc	http://deductions.github.io/biological-collections.owl.ttl#	20170111
cdm	http://publications.europa.eu/ontology/cdm#	20170111
cdt	http://w3id.org/lindt/custom_datatypes#	20170111
clinic	http://example.com/clinic#	20170111
content	http://yousuck.ca/	20170111
cpack	http://cliopatria.swi-prolog.org/schema/cpack#	20170111
crime	http://purl.org/vocab/reloc/	20170111
crowd	http://purl.org/crowd/	20170111
dash	http://datashapes.org/dash#	20170111
datex	http://vocab.datex.org/terms#	20170111
dbfo	http://dbpedia.org/facts/ontology#	20170111
dbpediaowl	http://dbpedia.org/ontology/	20170111
dcap	http://purl.org/ws-mmi-dc/terms/	20170111
dcatapit	http://dati.gov.it/onto/dcatapit#	20170111
dcodata	http://info.deepcarbon.net/data/schema#	20170111
dpn	http://purl.org/dpn#	20170111
driver	http://deductions.github.io/drivers.owl.ttl#	20170111
dul	http://www.ontologydesignpatterns.org/ont/dul/DUL.owl#	20170111
duv	http://www.w3.org/ns/duv#	20170111
eame	http://www.semanticweb.org/ontologia_EA#	20170111
eccpubsub	https://vocab.eccenca.com/pubsub/	20170111
ecoll	http://purl.org/ceu/eco/1.0#	20170111
efrbroo	http://erlangen-crm.org/efrbroo/	20170111
ensembl	http://rdf.ebi.ac.uk/resource/ensembl/	20170111
eol	http://purl.org/biodiversity/eol/	20170111
esproc	http://vocab.linkeddata.es/datosabiertos/def/sector-publico/procedimientos#	20170111
fn	http://www.w3.org/2005/xpath-functions#	20170111
fno	http://w3id.org/function/ontology#	20170111
fo	http://www.w3.org/1999/XSL/Format#	20170111
frgeo	http://rdf.insee.fr/geo/	20170111
gen	http://purl.org/gen/0.1#	20170111
html	http://izmus.cz/#	20170111
iana	http://www.iana.org/assignments/relation/	20170111
ic	http://imi.go.jp/ns/core/rdf#	20170111
ifc	http://ifcowl.openbimstandards.org/IFC2X3_Final#	20170111
ioto	http://www.irit.fr/recherches/MELODI/ontologies/IoT-O#	20170111
ipsv	http://id.esd.org.uk/list/	20170111
isidore	http://www.rechercheisidore.fr/class/	20170111
ispra	http://dati.isprambiente.it/ontology/core#	20170111
jolux	http://data.legilux.public.lu/resource/ontology/jolux#	20170111
jpost	http://jpostdb.org/ontology/jpost.owl#	20170111
kees	http://linkeddata.center/kees/v1#	20170111
latitude	https://www.w3.org/2006/vcard/ns#latitude#	20170111
ldq	http://www.linkeddata.es/ontology/ldq#	20170111
ldqm	http://linkeddata.es/resource/ldqm/	20170111
leak	http://data.ontotext.com/resource/leak/	20170111
leaks	http://data.ontotext.com/resource/leak/	20170111
literal	http://www.essepuntato.it/2010/06/literalreification/	20170111
llr	http://lodlaundromat.org/resource/	20170111
lsq	http://lsq.aksw.org/vocab#	20170111
ludo	http://ns.inria.fr/ludo/v1#	20170111
lyon	http://dbpedia.org/resource/Lyon/	20170111
markus	http://www.markus.com/	20170111
mdi	http://w3id.org/multidimensional-interface/ontology#	20170111
meat	http://example.com/	20170111
media	http://search.yahoo.com/searchmonkey/media/	20170111
merge	http://jazz.net/ns/lqe/merge/	20170111
meshv	http://id.nlm.nih.gov/mesh/vocab#	20170111
mls	http://www.w3.org/ns/mls#	20170111
mm	http://linkedmultimedia.org/sparql-mm/ns/2.0.0/function#	20170111
mmm	http://www.mico-project.eu/ns/mmm/2.0/schema#	20170111
mmoon	http://mmoon.org/mmoon/	20170111
mod	http://www.isibang.ac.in/ns/mod#	20170111
ncbigene	http://identifiers.org/ncbigene/	20170111
ndnp	http://chroniclingamerica.loc.gov/terms#	20170111
neotec	http://neotec.rc.unesp.br/resource/Neotectonics/	20170111
neotecbib	http://neotec.rc.unesp.br/resource/NeotectonicsBibliography/	20170111
nuts	http://dd.eionet.europa.eu/vocabulary/common/nuts/	20170111
obeu	http://data.openbudgets.eu/ontology/	20170111
ogc	http://www.opengis.net/def/	20170111
ondc	http://www.semanticweb.org/ontologies/2012/1/Ontology1329913965202.owl#	20170111
ontolex	http://www.w3.org/ns/lemon/ontolex#	20170111
ontology	http://dbpedia.org/ontology/	20170111
ontop	https://w3id.org/ontop/	20170111
or	http://openresearch.org/vocab/	20170111
organ	http://www.univalle.edu.co/ontologies/Organ#	20170111
pcdm	http://pcdm.org/models#	20170111
pdf	http://ns.adobe.com/pdf/1.3/	20170111
planet	http://dbpedia.org/	20170111
pm	http://premon.fbk.eu/resource/	20170111
pmd	http://publishmydata.com/def/dataset#	20170111
pmo	http://premon.fbk.eu/ontology/core#	20170111
pmofn	http://premon.fbk.eu/ontology/fn#	20170111
pmonb	http://premon.fbk.eu/ontology/nb#	20170111
pmopb	http://premon.fbk.eu/ontology/pb#	20170111
pmovn	http://premon.fbk.eu/ontology/vn#	20170111
ppr	http://purl.org/datanode/ppr/ns/	20170111
prohow	https://w3id.org/prohow#	20170111
rdaad	http://rdaregistry.info/Elements/a/datatype/	20170111
rdaar	http://rdaregistry.info/termList/AspectRatio/	20170111
rdabs	http://rdaregistry.info/termList/broadcastStand/	20170111
rdacarx	http://rdaregistry.info/termList/RDACarrierEU/	20170111
rdacdt	http://rdaregistry.info/termList/RDACartoDT/	20170111
rdacpc	http://rdaregistry.info/termList/configPlayback/	20170111
rdaft	http://rdaregistry.info/termList/fileType/	20170111
rdagen	http://rdaregistry.info/termList/RDAGeneration/	20170111
rdaill	http://rdaregistry.info/termList/IllusContent/	20170111
rdalay	http://rdaregistry.info/termList/layout/	20170111
rdapf	http://rdaregistry.info/termList/presFormat/	20170111
rdapm	http://rdaregistry.info/termList/RDAproductionMethod/	20170111
rdaspc	http://rdaregistry.info/termList/specPlayback/	20170111
rdaterm	http://rdaregistry.info/termList/RDATerms/	20170111
rdavf	http://rdaregistry.info/termList/videoFormat/	20170111
rdfp	https://w3id.org/rdfp/	20170111
rdfsharp	https://rdfsharp.codeplex.com/	20170111
res	http://dbpedia.org/resource/	20170111
role	https://w3id.org/role/	20170111
ruian	https://data.cssz.cz/ontology/ruian/	20170111
san	http://www.irit.fr/recherches/MELODI/ontologies/SAN#	20170111
sdm	http://standard.k-history.kr/resource/	20170111
sdmxc	http://purl.org/linked-data/sdmx/2009/concept#	20170111
sdmxcode	http://purl.org/linked-data/sdmx/2009/code#	20170111
sdmxm	http://purl.org/linked-data/sdmx/2009/measure#	20170111
seas	https://w3id.org/seas/	20170111
semiot	http://w3id.org/semiot/ontologies/semiot#	20170111
sg	http://name.scigraph.com/ontologies/core/	20170111
sgfn	http://w3id.org/sparql-generate/fn/	20170111
sgg	http://name.scigraph.com/core/graphs/	20170111
sgiter	http://w3id.org/sparql-generate/iter/	20170111
soch	http://kulturarvsdata.se/ksamsok#	20170111
solid	http://www.w3.org/ns/solid/terms#	20170111
sorg	http://schema.org/	20170111
spv	http://completeness.inf.unibz.it/sp-vocab#	20170111
studiop	http://purl.org/resource/pilatesstudio/	20170111
sx	http://shex.io/ns/shex#	20170111
system	http://www.univalle.edu.co/ontologies/System#	20170111
tarql	http://tarql.github.io/tarql#	20170111
tgm	http://id.loc.gov/vocabulary/graphicMaterials/	20170111
tissue	http://www.univalle.edu.co/ontologies/Tissue#	20170111
undata	http://citydata.wu.ac.at/Linked-UNData/data/	20170111
units	http://eulersharp.sourceforge.net/2003/03swap/units#	20170111
vam	http://www.metmuseum.org/	20170111
verb	https://w3id.org/verb/	20170111
vogd	http://ogd.ifs.tuwien.ac.at/vienna/geo/	20170111
voidex	http://www.swi-prolog.org/rdf/library/	20170111
vplan	http://www.ifs.tuwien.ac.at/~miksa/ontologies/VPlan.owl#	20170111
wab	http://wab.uib.no/cost-a32_philospace/wittgenstein.owl#	20170111
wdv	http://www.wikidata.org/value/	20170111
webac	http://fedora.info/definitions/v4/webac#	20170111
wikipedia	http://wikipedia.no/rdf/	20170111
wp	http://vocabularies.wikipathways.org/wp#	20170111
ws	http://www.w3.org/ns/pim/space#	20170111
year	http://www.w3.org/year/	20170111
yso	http://www.yso.fi/onto/yso/	20170111
add	http://www.datatourisme.fr/ontology/core/1.0#	20180213
ago	http://awesemantic-geo.link/ontology/	20180213
agr	http://promsns.org/def/agr#	20180213
alethio	http://aleth.io/	20180213
allot	https://w3id.org/akn/ontology/allot#	20180213
aml	https://w3id.org/i40/aml#	20180213
amt	http://academic-meta-tool.xyz/vocab#	20180213
aprov	http://purl.org/a-proc#	20180213
aseonto	http://requirement.ase.ru/requirements_ontology#	20180213
assoc	https://w3id.org/associations/vocab#	20180213
atlas	http://rdf.ebi.ac.uk/resource/atlas/	20180213
audit	http://fedora.info/definitions/v4/audit#	20180213
bag	http://bag.basisregistraties.overheid.nl/def/bag#	20180213
bci	https://w3id.org/BCI-ontology#	20180213
bdc	http://dbpedia.org/resource/Category:	20180213
bdd	http://purl.bdrc.io/data/	20180213
bdo	http://purl.bdrc.io/ontology/core/	20180213
bdr	http://purl.bdrc.io/resource/	20180213
bds	http://www.bigdata.com/rdf/search#	20180213
bflc	http://id.loc.gov/ontologies/bflc/	20180213
bob	http://good.dad/meaning/bob#	20180213
bot	https://w3id.org/bot#	20180213
brk	http://brk.basisregistraties.overheid.nl/def/brk#	20180213
brt	http://brt.basisregistraties.overheid.nl/def/top10nl#	20180213
cd	http://citydata.wu.ac.at/ns#	20180213
ceterms	http://purl.org/ctdl/terms/	20180213
clapit	http://dati.gov.it/onto/clapit/	20180213
composer	http://dbpedia.org/ontology/composer/	20180213
connard	https://mail.google.com/mail/u/1/#	20180213
content	http://purl.org/rss/1.0/modules/content/	20180213
cpi	http://www.ebusiness-unibw.org/ontologies/cpi/ns#	20180213
cpov	http://data.europa.eu/m8g/	20180213
customer	http://www.valuelabs.com/	20180213
cwlgit	https://w3id.org/cwl/view/git/	20180213
cwrc	http://sparql.cwrc.ca/ontology/cwrc#	20180213
d3s	http://vocbench.solidaridad.cloud/taxonomies#	20180213
datacron	http://www.datacron-project.eu/datAcron#	20180213
dbkwik	http://dbkwik.webdatacommons.org/	20180213
dcatnl	http://standaarden.overheid.nl/dcatnl/terms/	20180213
ddb	http://www.deutsche-digitale-bibliothek.de/edm/	20180213
decprov	http://promsns.org/def/decprov#	20180213
dk	http://www.data-knowledge.org/dk/schema/rdf/latest/	20180213
doacc	http://purl.org/net/bel-epa/doacc#	20180213
doas	http://deductions.github.io/doas.owl.ttl#	20180213
docker	http://www.w3.org/ns/bde/docker/	20180213
doi	http://dx.doi.org/	20180213
dsw	http://purl.org/dsw/	20180213
dto	http://www.datatourisme.fr/ontology/core/1.0#	20180213
eat	http://www.eat.rl.ac.uk/#	20180213
edg	http://edg.topbraid.solutions/model/	20180213
emergel	http://purl.org/emergel/core#	20180213
emergelm	http://purl.org/emergel/modules#	20180213
eustd	http://eurostat.linked-statistics.org/data#	20180213
euvoc	http://publications.europa.eu/ontology/euvoc#	20180213
fhir	http://hl7.org/fhir/	20180213
fnml	http://semweb.mmlab.be/ns/fnml#	20180213
fr	https://w3id.org/fr/def/core#	20180213
fssp	http://linkeddata.fssprus.ru/resource/	20180213
fun	http://w3id.org/sparql-generate/fn/	20180213
fuseki	http://jena.apache.org/fuseki#	20180213
gdc	https://portal.gdc.cancer.gov/cases/	20180213
geo	http://www.opengis.net/ont/geosparql#	20180213
geoloc	http://deductions.github.io/geoloc.owl.ttl#	20180213
geom	http://data.ign.fr/def/geometrie#	20180213
geor	http://www.opengis.net/def/rule/geosparql/	20180213
gg	http://www.gemeentegeschiedenis.nl/gg-schema#	20180213
globalcube	http://kalmar32.fzi.de/triples/global-cube.ttl#	20180213
gobierno	http://www.gobierno.es/gobierno/	20180213
gvoi	http://assemblee-virtuelle.github.io/grands-voisins-v2/gv.owl.ttl#	20180213
gvoith	http://assemblee-virtuelle.github.io/grands-voisins-v2/thesaurus.ttl#	20180213
halyard	http://merck.github.io/Halyard/ns#	20180213
hasco	http://hadatac.org/ont/hasco/	20180213
huto	http://ns.inria.fr/huto/	20180213
hva	http://www.ebusiness-unibw.org/ontologies/hva/ontology#	20180213
iab	https://www.iab.com/guidelines/taxonomy/	20180213
id	http://identifiers.org/	20180213
ido	http://purl.obolibrary.org/obo/ido.owl#	20180213
ifcowl	http://www.buildingsmart-tech.org/ifcOWL/IFC4_ADD2#	20180213
im	http://imgpedia.dcc.uchile.cl/resource/	20180213
imo	http://imgpedia.dcc.uchile.cl/ontology#	20180213
ims	http://www.imsglobal.org/xsd/imsmd_v1p2/	20180213
iotlite	http://purl.oclc.org/NET/UNIS/fiware/iot-lite#	20180213
isaterms	http://purl.org/isaterms/	20180213
it	http://www.influencetracker.com/ontology#	20180213
iter	http://w3id.org/sparql-generate/iter/	20180213
its	http://www.w3.org/2005/11/its/rdf#	20180213
ja	http://jena.hpl.hp.com/2005/11/Assembler#	20180213
jerm	http://jermontology.org/ontology/JERMOntology#	20180213
jpost	http://rdf.jpostdb.org/ontology/jpost.owl#	20180213
json	https://www.ecma-international.org/publications/files/ECMA-ST/ECMA-404.pdf#	20180213
ldl	https://w3id.org/ldpdl/ns#	20180213
ldn	https://www.w3.org/TR/ldn/#	20180213
lgt	http://linkedgadget.com/wiki/Property:	20180213
linkrel	https://www.w3.org/ns/iana/link-relations/relation#	20180213
literature	http://purl.org/net/cnyt-literature#	20180213
llalg	http://www.linklion.org/algorithm/	20180213
lmdb	http://data.linkedmdb.org/movie/	20180213
loupe	http://ont-loupe.linkeddata.es/def/core/	20180213
m3	http://sensormeasurement.appspot.com/m3#	20180213
marcrole	http://id.loc.gov/vocabulary/relators/	20180213
mdont	http://ont.matchdeck.com/	20180213
medred	http://w3id.org/medred/medred#	20180213
meeting	http://www.w3.org/2002/07/meeting#	20180213
memento	http://mementoweb.org/ns#	20180213
mesh	http://id.nlm.nih.gov/mesh/	20180213
mime	https://www.iana.org/assignments/media-types/	20180213
mv	http://schema.mobivoc.org/	20180213
nature	http://deductions.github.io/nature_observation.owl.ttl#	20180213
nih	http://ncicb.nci.nih.gov/xml/owl/EVS/Thesaurus.owl#	20180213
nkos	http://w3id.org/nkos#	20180213
nobel	http://data.nobelprize.org/terms/	20180213
nrv	http://ns.inria.fr/nrv#	20180213
ns2	http://ogp.me/ns#video:	20180213
og	http://ogp.me/ns#	20180213
ogdl4m	https://github.com/martynui/OGDL4M/	20180213
ontoneo	http://purl.obolibrary.org/obo/ontoneo/	20180213
opa	https://w3id.org/laas-iot/adream#	20180213
oplangel	http://www.openlinksw.com/schemas/angel#	20180213
oplbenefit	http://www.openlinksw.com/ontology/benefits#	20180213
oplli	http://www.openlinksw.com/schemas/linkedin#	20180213
oplp	http://www.openlinksw.com/ontology/purchases#	20180213
oplstocks	http://www.openlinksw.com/ontology/stocks#	20180213
oplwebsrv	http://www.openlinksw.com/ontology/webservices#	20180213
orcid	http://orcid.org/	20180213
orth	http://purl.org/net/orth#	20180213
osd	http://a9.com/-/spec/opensearch/1.1/	20180213
ottr	http://ns.ottr.xyz/templates#	20180213
owms	http://standaarden.overheid.nl/owms/terms/	20180213
pair	http://virtual-assembly.org/pair/PAIR_LOD_V3.owl/	20180213
pand	http://bag.basisregistraties.overheid.nl/bag/id/pand/	20180213
pato	http://purl.obolibrary.org/obo/	20180213
pcdmuse	http://pcdm.org/use#	20180213
pcdt	http://purl.org/procurement/public-contracts-datatypes#	20180213
pep	https://w3id.org/pep/	20180213
persee	http://data.persee.fr/ontology/persee_ontology/	20180213
pmc	http://identifiers.org/pmc/	20180213
pop	http://wiki.dbpedia.org/	20180213
premis	http://www.loc.gov/premis/rdf/v1#	20180213
provinsi	http://provinsi.com/	20180213
purl	http://www.purl.org/	20180213
qbe	http://citydata.wu.ac.at/qb-equations#	20180213
rankrage	https://rankrage.de/	20180213
rdare	http://rdaregistry.info/termList/RDARegionalEncoding/	20180213
rdax	http://rdaregistry.info/Elements/x/	20180213
s3n	http://w3id.org/s3n/	20180213
s4bldg	https://w3id.org/def/saref4bldg#	20180213
s4envi	https://w3id.org/def/saref4envi#	20180213
salad	https://w3id.org/cwl/salad#	20180213
saref	https://w3id.org/saref#	20180213
sciprov	http://sweetontology.net/reprSciProvenance/	20180213
scra	http://purl.org/net/schemarama#	20180213
seeds	http://deductions.github.io/seeds.owl.ttl#	20180213
sem	http://semanticweb.cs.vu.nl/2009/11/sem/	20180213
sfn	http://semweb.datasciencelab.be/ns/sfn#	20180213
sg	http://www.springernature.com/scigraph/ontologies/core/	20180213
sgg	http://www.springernature.com/scigraph/graphs/	20180213
shacl	http://www.w3.org/ns/shacl#	20180213
smartapi	http://smart-api.io/ontology/1.0/smartapi#	20180213
sosa	http://www.w3.org/ns/sosa/	20180213
ssno	http://www.w3.org/ns/ssn/	20180213
sto	https://w3id.org/i40/sto#	20180213
svcs	http://rdfs.org/sioc/services#	20180213
task	http://deductions.github.io/task-management.owl.ttl#	20180213
td	http://www.w3.org/ns/td#	20180213
tg	http://www.turnguard.com/turnguard#	20180213
tosh	http://topbraid.org/tosh#	20180213
tsn	http://purl.org/net/tsn#	20180213
tsnchange	http://purl.org/net/tsnchange#	20180213
ttla	https://w3id.org/ttla/	20180213
ttp	http://eample.com/test#	20180213
tui	http://data.ifs.tuwien.ac.at/study/resource/	20180213
tx	http://swtmp.gitlab.io/vocabulary/templates.owl#	20180213
umls	http://bioportal.bioontology.org/ontologies/umls/	20180213
vehma	http://deductions.github.io/vehicule-management.owl.ttl#	20180213
vehman	http://deductions.github.io/vehicule-management.owl.ttl#	20180213
ver	https://w3id.org/version/ontology#	20180213
w3cgeo	http://www.w3.org/2003/01/geo/wgs84_pos#	20180213
besluit	http://data.vlaanderen.be/ns/besluit#	20180227
bgt	http://bgt.basisregistraties.overheid.nl/def/bgt#	20180227
geo7	https://www.geo7.ch/	20180227
shui	https://vocab.eccenca.com/shui/	20180227
activity	http://activitystrea.ms/specs/atom/1.0/	20181102
adr	https://w3id.org/laas-iot/adream#	20181102
antenne	https://id.milieuinfo.be/ns/zendantenne#	20181102
atlasterms	http://rdf.ebi.ac.uk/terms/atlas/	20181102
az	https://w3id.org/people/az/	20181102
bioentity	http://bioentity.io/vocab/	20181102
cco	http://www.ontologyrepository.com/CommonCoreOntologies/	20181102
cocoon	https://w3id.org/cocoon/v1.0#	20181102
cpm	http://catalogus-professorum.org/cpm/2/	20181102
crml	http://semweb.mmlab.be/ns/rml/condition#	20181102
cubeont	http://ontology.cube.global/	20181102
cwlprov	https://w3id.org/cwl/prov#	20181102
da	https://www.wowman.org/index.php?id=1&type=get#	20181102
dao	http://purl.org/dao#	20181102
dcx	http://dublincore.org/dcx/	20181102
dead	http://utpl.edu.ec/sbc/data/	20181102
dnbt	http://d-nb.info/standards/elementset/dnb#	20181102
doi	https://doi.org/	20181102
dossier	https://lod.milieuinfo.be/ns/dossier#	20181102
ecore	http://www.eclipse.org/emf/2002/Ecore#	20181102
edam	http://edamontology.org/	20181102
faostat	http://reference.eionet.europa.eu/faostat/schema/	20181102
foaffff	http://gogl.com/	20181102
frbroo	http://iflastandards.info/ns/fr/frbr/frbroo/	20181102
gbol	http://gbol.life/0.1#	20181102
gdpr	https://vocab.eccenca.com/gdpr/	20181102
goaf	http://goaf.fr/goaf#	20181102
grel	http://semweb.datasciencelab.be/ns/grel#	20181102
gt	https://vocab.eccenca.com/geniustex/	20181102
ids	https://w3id.org/idsa/core/	20181102
imas	https://sparql.crssnky.xyz/imasrdf/URIs/imas-schema.ttl#	20181102
jpo	http://rdf.jpostdb.org/ontology/jpost.owl#	20181102
kmgeo	http://km.aifb.kit.edu/services/geo/ontology#	20181102
ldt	https://www.w3.org/ns/ldt#	20181102
led	http://led.kmi.open.ac.uk/term/	20181102
legal	http://www.w3.org/ns/legal#	20181102
lido	http://www.lido-schema.org/	20181102
lime	http://www.w3.org/ns/lemon/lime#	20181102
lindt	https://w3id.org/lindt/voc#	20181102
mandaat	http://data.vlaanderen.be/ns/mandaat#	20181102
mem	http://mementoweb.org/ns#	20181102
mml	http://www.w3.org/1998/Math/MathML/	20181102
mmo	http://purl.org/momayo/mmo/	20181102
mobivoc	http://schema.mobivoc.org/	20181102
mydb	http://mydb.org/	20181102
nosql	http://purl.org/db/nosql#	20181102
number	http://km.aifb.kit.edu/projects/numbers/number#	20181102
numbers	http://km.aifb.kit.edu/projects/numbers/	20181102
opm	https://w3id.org/opm#	20181102
parl	https://id.parliament.uk/schema/	20181102
physics	http://www.astro.umd.edu/~eshaya/astro-onto/owl/physics.owl#	20181102
plg	http://parliament.uk/ontologies/legislation/	20181102
ppn	http://parliament.uk/ontologies/person-name/	20181102
r3d	http://www.re3data.org/schema/3-0#	20181102
seo	http://sda.tech/SEOontology/SEO/	20181102
seokoeln	http://rankrage.de/	20181102
sfd	http://semantic-forms.cc:9112/ldp/	20181102
sparql	http://www.w3.org/ns/sparql#	20181102
ssn	http://www.w3.org/ns/ssn/	20181102
swo	http://www.ebi.ac.uk/swo/	20181102
swrc2	https://www.cs.vu.nl/~mcaklein/onto/swrc_ext/2005/05#	20181102
sylld	http://www.semanticweb.org/syllabus/data/	20181102
tikag	https://www.tikag.com/	20181102
timex	http://data.wu.ac.at/ns/timex#	20181102
uc	http://ucuenca.edu.ec/ontology#	20181102
vartrans	http://www.w3.org/ns/lemon/vartrans#	20181102
video	http://purl.org/ontology/video#	20181102
vss	http://automotive.eurecom.fr/vsso#	20181102
vsso	http://automotive.eurecom.fr/vsso#	20181102
waarde	https://lod.milieuinfo.be/ns/waarde#	20181102
wordnet	http://wordnet-rdf.princeton.edu/ontology#	20181102
agrovoc	http://aims.fao.org/aos/agrovoc/	20190227
aksw	http://aksw.org/	20190227
as	https://www.w3.org/ns/activitystreams#	20190227
bl	http://w3id.org/biolink/vocab/	20190227
cbim	http://www.coinsweb.nl/cbim-2.0.rdf#	20190227
cdao	http://purl.obolibrary.org/obo/	20190227
cim	http://iec.ch/TC57/2013/CIM-schema-cim16#	20190227
conference	https://w3id.org/scholarlydata/ontology/conference-ontology.owl#	20190227
dot	https://w3id.org/dot#	20190227
edr	https://w3id.org/laas-iot/edr#	20190227
eepsa	https://w3id.org/eepsa#	20190227
esdbpr	http://es.dbpedia.org/resource/	20190227
foam	https://www.koerperfettwaage-test.de/	20190227
fog	https://w3id.org/fog#	20190227
fred	http://www.ontologydesignpatterns.org/ont/fred/domain.owl#	20190227
hp	http://purl.org/voc/hp/	20190227
iati	http://purl.org/collections/iati/	20190227
leak	http://data.ontotext.com/resource/leaks#	20190227
lmo	http://linkedmultimedia.org/sparql-mm/ns/2.0.0/ontology#	20190227
lmu	https://w3id.org/laas-iot/lmu#	20190227
ln	https://w3id.org/ln#	20190227
logies	https://data.vlaanderen.be/ns/logies#	20190227
lovc	https://w3id.org/lovcube/ns/lovcube#	20190227
munc	http://ns.inria.fr/munc#	20190227
omg	https://w3id.org/omg#	20190227
pfeepsa	https://w3id.org/pfeepsa#	20190227
prof	http://www.w3.org/ns/dx/prof/	20190227
prop	http://dbpedia.org/property/	20190227
rls	https://w3id.org/lovcube/ns/relovstats#	20190227
rvz	http://rdfvizler.dyreriket.xyz/vocabulary/core#	20190227
sirene	https://sireneld.io/vocab/sirene#	20190227
vf	https://w3id.org/valueflows#	20190227
yaco	https://www.irit.fr/recherches/MELODI/ontologies/cinema#	20190227
accid	http://pid.accurids.com/	20230619
acp	http://www.w3.org/ns/solid/acp#	20230619
activity	https://www.w3.org/TR/activitystreams-vocabulary/	20230619
adf	http://purl.allotrope.org/ontologies/datapackage#	20230619
adr	http://kg.artsdata.ca/resource/	20230619
aec3po	https://w3id.org/lbd/aec3po/	20230619
aff	https://w3id.org/affectedBy#	20230619
afm	http://purl.allotrope.org/ontologies/material/	20230619
afn	http://jena.apache.org/ARQ/function#	20230619
afr	http://purl.allotrope.org/ontologies/result#	20230619
agro	http://purl.obolibrary.org/obo/agro.owl#	20230619
ags	https://id.agschemas.org/	20230619
alg	http://drakon.su/ADF#	20230619
ammo	http://ldf.fi/schema/ammo/	20230619
ams	http://data.amadeus.com/	20230619
antenne	https://data.zendantennes.omgeving.vlaanderen.be/ns/zendantenne#	20230619
apb	http://www.analysispartners.org/businessmodel/	20230619
apods	http://activitypods.org/ns/core#	20230619
archivo	https://archivo.dbpedia.org/onto#	20230619
arena	https://solid.ti.rw.fau.de/public/ns/arena#	20230619
arp	http://www.arpenteur.org/ontology/Arpenteur.owl#	20230619
asf	https://www.stm-assoc.org/asf/	20230619
asgs	http://linked.data.gov.au/def/asgs#	20230619
asio	http://purl.org/hercules/asio/core#	20230619
aspect	http://purl.org/aspect/	20230619
atcc	https://www.atcc.org/products/	20230619
atd	https://data.nasa.gov/ontologies/atmonto/data#	20230619
atm	https://data.nasa.gov/ontologies/atmonto/ATM#	20230619
atts	https://data.nasa.gov/ontologies/atmonto/general#	20230619
baf	https://w3id.org/baf#	20230619
bag	https://bag2.basisregistraties.overheid.nl/bag/def/	20230619
bag2	http://bag.basisregistraties.overheid.nl/def/bag#	20230619
bao	http://www.bioassayontology.org/bao#	20230619
bau	https://terminology.fraunhofer.de/voc/bau#	20230619
bcfowl	http://lbd.arch.rwth-aachen.de/bcfOWL#	20230619
bcom	https://w3id.org/bcom#	20230619
bdd	https://api.bloomberg.com/eap/catalogs/bbg/fields/	20230619
bdg	http://data.bigdatagrapes.eu/resource/ontology/	20230619
bdsubj	https://purl.org/fidbaudigital/subjects#	20230619
beer	http://beer.com/	20230619
beo	http://pi.pauwel.be/voc/buildingelement#	20230619
besluitvor	https://data.vlaanderen.be/ns/besluitvorming#	20230619
bf	http://id.loc.gov/ontologies/bibframe/	20230619
bfo	http://purl.obolibrary.org/obo/	20230619
bgcat	http://bg.dbpedia.org/resource/Категория:	20230619
bgt	https://bgt.basisregistraties.overheid.nl/bgt/def/	20230619
bibframe	http://id.loc.gov/ontologies/bibframe/	20230619
bibtex	http://purl.org/net/nknouf/ns/bibtex#	20230619
biocrm	http://ldf.fi/schema/bioc/	20230619
biogrid	http://thebiogrid.org/	20230619
biolink	https://w3id.org/biolink/vocab/	20230619
birthdate	http://schema.org/birthDate/	20230619
bitl	http://lib.bit.edu.cn/ontology/1.0/	20230619
bkb	https://budayakb.cs.ui.ac.id/ns#	20230619
bl	https://w3id.org/biolink/vocab/	20230619
bld	http://biglinkeddata.com/	20230619
bldont	http://ont.biglinkeddata.com/	20230619
ble	http://vocab.rapidthings.eu/ns/ble.ttl#	20230619
bleadapter	http://vocab.rapidthings.eu/ns/ble/adapter.ttl#	20230619
bmp	http://w3id.org/bmp#	20230619
bop	https://w3id.org/bop#	20230619
bp	http://www.biopax.org/release/biopax-level3.owl#	20230619
bp3	http://www.biopax.org/release/biopax-level3.owl#	20230619
bperson	http://data.vlaanderen.be/ns/persoon#	20230619
bpo	https://w3id.org/bpo#	20230619
brick	https://brickschema.org/schema/Brick#	20230619
brot	https://w3id.org/brot#	20230619
bs	https://w3id.org/def/basicsemantics-owl#	20230619
bsdd	http://bsdd.buildingsmart.org/def#	20230619
bsh	https://brickschema.org/schema/1.1.0/BrickShape#	20230619
ca	http://complyadvantage.com/	20230619
capes	http://vocab.capes.gov.br/def/vcav#	20230619
caso	http://www.w3id.org/def/caso#	20230619
cbb	https://data.cbb.omgeving.vlaanderen.be/ns/cbb#	20230619
cbs	http://betalinkeddata.cbs.nl/def/cbs#	20230619
cbv	https://ns.gs1.org/cbv/	20230619
cci	http://cookingbigdata.com/linkeddata/ccinstances#	20230619
ccomid	http://www.ontologyrepository.com/CommonCoreOntologies/Mid/	20230619
ccp	http://cookingbigdata.com/linkeddata/ccpricing#	20230619
ccr	http://cookingbigdata.com/linkeddata/ccregions#	20230619
ccsla	http://cookingbigdata.com/linkeddata/ccsla#	20230619
cdc	https://w3id.org/cdc#	20230619
cdt	https://w3id.org/cdt/	20230619
ceo	https://linkeddata.cultureelerfgoed.nl/def/ceo#	20230619
ceox	https://linkeddata.cultureelerfgoed.nl/def/ceox#	20230619
cerealstoo	http://rdf.ag/o/cerealstoo#	20230619
cex	http://purl.org/weso/ontology/computex#	20230619
cfrl	http://linkeddata.finki.ukim.mk/lod/ontology/cfrl#	20230619
cgo	https://www.tno.nl/agrifood/ontology/common-greenhouse-ontology#	20230619
ch	https://schema.ld.admin.ch/	20230619
chameo	http://emmo.info/emmo/domain/chameo/chameo#	20230619
chear	http://hadatac.org/ont/chear#	20230619
chebi	http://purl.obolibrary.org/obo/CHEBI_	20230619
check	http://pornhub.com/	20230619
chemrof	https://w3id.org/chemrof/	20230619
chemsci	https://w3id.org/skgo/chemsci#	20230619
chess	http://purl.org/NET/rdfchess/ontology/	20230619
ci	https://privatealpha.com/ontology/content-inventory/1#	20230619
ciao	http://ciao.it/	20230619
cido	http://purl.obolibrary.org/obo/cido.owl/	20230619
cidoc	http://www.cidoc-crm.org/cidoc-crm/	20230619
cinema	http://www.semanticweb.org/julien/morgann/cinema#	20230619
citedcat	https://w3id.org/citedcat-ap/	20230619
co	http://purl.org/ontology/co/core#	20230619
coda	http://art.uniroma2.it/coda/contracts/	20230619
cog	http://purl.org/ontology/cco/core#	20230619
comp	http://semweb.mmlab.be/ns/rml-compression#	20230619
compub	https://sireneld.io/vocab/compub#	20230619
conll	http://ufal.mff.cuni.cz/conll2009-st/task-description.html#	20230619
conllu	https://universaldependencies.org/format.html#	20230619
consolid	https://w3id.org/consolid#	20230619
constant	http://qudt.org/vocab/constant/	20230619
contax	https://w3id.org/con-tax#	20230619
contry	http://dbpedia.org/resource/Lyon#	20230619
coos	http://id.unece.org/def/coos#	20230619
coreo	http://purl.org/coreo#	20230619
country	http://eulersharp.sourceforge.net/2003/03swap/countries#	20230619
county	http://myexample.org/county#	20230619
covido	https://w3id.org/CovidO#	20230619
coy	https://schema.coypu.org/global#	20230619
cpc	https://data.epo.org/linked-data/def/cpc/	20230619
cpg	http://modellingdh.github.io/ont/odp/pgc/	20230619
crmdig	http://www.ics.forth.gr/isl/CRMdig/	20230619
crmeh	http://purl.org/crmeh#	20230619
crminf	http://www.cidoc-crm.org/cidoc-crm/CRMinf/	20230619
crmsci	http://cidoc-crm.org/crmsci/	20230619
cska	http://pfclitex.com/	20230619
cso	http://cso.kmi.open.ac.uk/schema/cso/	20230619
cto	https://w3id.org/cto#	20230619
ctrl	https://w3id.org/ibp/CTRLont#	20230619
cts	http://rdf.cdisc.org/ct/schema#	20230619
cube	https://cube.link/	20230619
cur	http://qudt.org/2.1/vocab/currency/	20230619
cvb	http://rdfs.org/resume-rdf/base.rdfs#	20230619
cwmo	http://purl.org/cwmo/#	20230619
d2s	https://w3id.org/d2s/	20230619
daap	http://daap.dsi.universite-paris-saclay.fr/wiki/	20230619
databus	https://dataid.dbpedia.org/databus#	20230619
datagc	https://data.grottocenter.org/ldp/	20230619
dave	http://theme-e.adaptcentre.ie/dave#	20230619
dbd	http://dbpedia.org/datatype/	20230619
dbm	http://purl.org/net/dbm/ontology#	20230619
dbms	http://www.openlinksw.com/ontology/dbms-app-ontology#	20230619
dbonto	http://dbepedia.org/ontology/	20230619
dbowl	http://ontology.cybershare.utep.edu/dbowl/relational-to-ontology-mapping-primitive.owl#	20230619
dbpediaowl	http://dbpedia.org/owl/	20230619
dbpg	http://dbpedia.org/page/	20230619
dby	http://dbpedia.org/class/yago/	20230619
dcatno	https://data.norge.no/vocabulary/dcatno#	20230619
dcb	http://dbpedia.org/resource/Category:	20230619
dcm	http://purl.org/dc/dcmitype/	20230619
dentsci	https://w3id.org/skgo/dentsci#	20230619
devuan	https://devuan.net.br/	20230619
dfc	http://datafoodconsortium.org/ontologies/DFC_FullModel.owl#	20230619
dfcb	http://datafoodconsortium.org/ontologies/DFC_BusinessOntology.owl#	20230619
dick	http://pornhub.com/	20230619
diso	https://purls.helmholtz-metadaten.de/diso#	20230619
djo	http://purl.org/datajourneys/	20230619
dm	http://datamusee.givingsense.eu/onto/	20230619
dmo	https://w3id.org/dmo#	20230619
dmp	http://www.sysresearch.org/rda-common-dmp#	20230619
docam	https://www.docam.ca/glossaurus/	20230619
doce	http://purl.org/nemo/doce#	20230619
dom	https://html.spec.whatwg.org/#	20230619
donto	http://reference.data.gov.au/def/ont/dataset#	20230619
dossier	https://data.omgeving.vlaanderen.be/ns/dossier#	20230619
dprov	http://promsns.org/def/do#	20230619
dpv	http://www.w3.org/ns/dpv#	20230619
dqvno	https://data.norge.no/vocabulary/dqvno#	20230619
drk	http://drakon.su/	20230619
dsd	https://w3id.org/dsd#	20230619
dsi	https://data.dsi.omgeving.vlaanderen.be/ns/dsi#	20230619
ea	http://eaontology.protect.linkeddata.es/def/	20230619
earth	http://linked.earth/ontology#	20230619
eb	https://w3id.org/eb#	20230619
ebg	http://data.businessgraph.io/ontology#	20230619
eccf	http://data.europa.eu/54i/	20230619
ecfo	https://w3id.org/ecfo#	20230619
ecos	http://purl.org/ecos#	20230619
edu	https://schema.edu.ee/	20230619
edupro	http://ns.inria.fr/semed/eduprogression#	20230619
eep	https://w3id.org/eep#	20230619
eg	http://www.example.org/	20230619
ei2a	http://opendata.aragon.es/def/ei2a#	20230619
encargado	http://semRAT.edu/	20230619
epcis	https://ns.gs1.org/epcis/	20230619
eppl	https://w3id.org/ep-plan#	20230619
epplan	https://w3id.org/ep-plan#	20230619
eppo	https://gd.eppo.int/taxon/	20230619
eproc	http://10.0.3.120/download/eproc_FORN_v02.owl#	20230619
eproc2	http://10.0.3.120/download/eproc_FORN_v04.owl#	20230619
eqp	https://data.nasa.gov/ontologies/atmonto/equipment#	20230619
era	http://data.europa.eu/949/	20230619
ermrk	http://www.essepuntato.it/2008/12/earmark#	20230619
esagen	http://vocab.ciudadesabiertas.es/def/sector-publico/agenda-municipal#	20230619
esagm	http://vocab.ciudadesabiertas.es/def/sector-publico/agenda-municipal#	20230619
esautob	http://vocab.ciudadesabiertas.es/def/transporte/autobus#	20230619
esbici	http://vocab.ciudadesabiertas.es/def/transporte/bicicleta-publica#	20230619
esc	https://solid.ti.rw.fau.de/public/ns/event-sourcing-containers#	20230619
esconv	http://vocab.ciudadesabiertas.es/def/sector-publico/convenio#	20230619
esdir	http://vocab.linkeddata.es/datosabiertos/def/urbanismo-infraestructuras/direccion-postal#	20230619
esempleo	http://vocab.ciudadesabiertas.es/def/sector-publico/empleo#	20230619
esgs	https://w3id.org/edwin/ontology/	20230619
esservicio	http://vocab.linkeddata.es/datosabiertos/def/sector-publico/servicio#	20230619
estraf	http://vocab.ciudadesabiertas.es/def/transporte/trafico#	20230619
eupont	http://elite.polito.it/ontologies/eupont.owl#	20230619
eurio	http://data.europa.eu/s66#	20230619
ewg	http://ethoinformatics.org/	20230619
exo	https://w3id.org/example#	20230619
experts	http://emmo.info/emmo/application/maeo/experts#	20230619
express	https://w3id.org/express#	20230619
ext	http://mu.semte.ch/vocabularies/ext/	20230619
extech	https://w3id.org/executionTechnique/ontology/	20230619
faas	http://semantic-faas.com/ontology#	20230619
fdof	https://w3id.org/fdof/ontology#	20230619
fdp	https://w3id.org/fdp/fdp-o#	20230619
feed	https://www.feedipedia.org/	20230619
fel	http://w3id.org/vcb/fel#	20230619
fernanda	http://fernanda.nl/	20230619
fibo	https://spec.edmcouncil.org/fibo/ontology/master/latest/	20230619
film	http://semantics.id/ns/example/film/	20230619
fno	https://w3id.org/function/ontology#	20230619
fnom	https://w3id.org/function/vocabulary/mapping#	20230619
foio	https://w3id.org/seas/FeatureOfInterestOntology/	20230619
folio	http://IBCNServices.github.io/Folio-Ontology/Folio.owl#	20230619
fpr	http://www.filmstandards.org/schemas/filmportal_relations#	20230619
freq	http://purl.org/cld/freq/	20230619
fso	https://w3id.org/fso#	20230619
fx	http://sparql.xyz/facade-x/ns/	20230619
gas	http://www.bigdata.com/rdf/gas#	20230619
gax	http://w3id.org/gaia-x/core#	20230619
gco	http://purl.jp/bio/12/glyco/conjugate#	20230619
gcon	https://w3id.org/GConsent#	20230619
gdprov	https://w3id.org/GDPRov#	20230619
gdprtext	https://w3id.org/GDPRtEXT#	20230619
generiek	https://data.vlaanderen.be/ns/generiek#	20230619
genre	http://sparql.cwrc.ca/ontologies/genre#	20230619
geodcat	http://data.europa.eu/930/	20230619
geoes	http://geo.linkeddata.es/resource/	20230619
geofabric	http://linked.data.gov.au/def/geofabric#	20230619
ggbn	http://data.ggbn.org/schemas/ggbn/terms/	20230619
ghga	http://w3id.org/ghga/	20230619
gist	https://ontologies.semanticarts.com/gist/	20230619
gleio	http://lei.info/gleio/	20230619
gmo	http://purl.jp/bio/10/gmo/	20230619
gnaf	http://linked.data.gov.au/def/gnaf#	20230619
go	http://purl.obolibrary.org/obo/GO_	20230619
goavoc	http://bio2rdf.org/goa_vocabulary:	20230619
godaddy	https://sso.godaddy.com/	20230619
gom	https://w3id.org/gom#	20230619
gql	http://www.openlinksw.com/schemas/graphql#	20230619
grel	http://users.ugent.be/~bjdmeest/function/grel.ttl#	20230619
grscicoll	https://www.gbif.org/grscicoll/collection/	20230619
gs1	https://gs1.org/voc/	20230619
gufo	http://purl.org/nemo/gufo#	20230619
gx	https://graphite.synaptica.net/extension/	20230619
hctl	https://www.w3.org/2019/wot/hypermedia#	20230619
hdgi	https://w3id.org/hdgi#	20230619
hg	http://rdf.histograph.io/	20230619
hico	http://purl.org/emmedi/hico/	20230619
hmas	https://purl.org/hmas/	20230619
hni	https://collectiedata.hetnieuweinstituut.nl/	20230619
hola	https://moodle.insa-lyon.fr/course/view.php?id=	20230619
hops	https://rdf.ag/o/hops#	20230619
hosp	http://health.data.gov/def/hospital/	20230619
hpont	https://w3id.org/hpont#	20230619
hqdm	http://www.semanticweb.org/hqdm#	20230619
hqdmontol	http://www.semanticweb.org/magma-core/ontologies/hqdm#	20230619
html	http://www.w3.org/1999/xhtml/	20230619
hu	https://mail.google.com/	20230619
hyr	https://w3id.org/simulation/data/	20230619
i18n	https://www.w3.org/ns/i18n#	20230619
iaco	https://iaco.me/	20230619
ianarel	https://www.w3.org/ns/iana/link-relations/relation#	20230619
iao	http://purl.obolibrary.org/obo/IAO_	20230619
iaph	http://www.juntadeandalucia.es/datosabiertos/portal/iaph/dataset/dataset/6c199ca2-8d2e-4c12-833c-f28	20230619
ibeacon	http://vocab.rapidthings.eu/ns/apple/ibeacon.ttl#	20230619
icon	https://w3id.org/icon/ontology/	20230619
iddo	https://w3id.org/iddo#	20230619
idot	http://identifiers.org/idot/	20230619
idpo	https://w3id.org/idpo#	20230619
idsc	https://w3id.org/idsa/code/	20230619
ii	http://sparql.cwrc.ca/ontologies/ii#	20230619
imbor	https://data.crow.nl/imbor/def/	20230619
imjv	https://data.imjv.omgeving.vlaanderen.be/ns/imjv#	20230619
inchikey	https://identifiers.org/inchikey:	20230619
ingredient	http://www.owl-ontologies.com/test.owl/ingredient/	20230619
interop	http://www.w3.org/ns/solid/interop#	20230619
io	https://iaco.me/	20230619
iospress	http://ld.iospress.nl/rdf/ontology/	20230619
iot	http://iotschema.org/	20230619
iottta	https://w3id.org/iot-tta#	20230619
isoadr	http://reference.data.gov.au/def/ont/iso19160-1-address#	20230619
istex	https://data.istex.fr/ontology/istex#	20230619
itcrdf	http://www.w3.org/2005/11/its/rdf#	20230619
itops	https://vocab.eccenca.com/itops/	20230619
jsonld	http://www.w3.org/ns/json-ld#	20230619
jsonschema	https://www.w3.org/2019/wot/json-schema#	20230619
jup	http://w3id.org/charta77/jup/	20230619
jur	http://sweet.jpl.nasa.gov/2.3/humanJurisdiction.owl#	20230619
karstlink	https://ontology.uis-speleo.org/ontology/#	20230619
kdsf	https://kerndatensatz-forschung.de/version1/technisches_datenmodell/owl/kdsf.owl#	20230619
kgi	http://ns.inria.fr/kg/index#	20230619
kko	http://kbpedia.org/kko/rc/	20230619
knows	http://semantic.komc/usu/2020/knows#	20230619
koko	https://seznam.cz/	20230619
kokot	http://www.koko.t/	20230619
kpd	http://purl.org/kpd/	20230619
ksam	http://kulturarvsdata.se/ksamsok#	20230619
la	https://linked.art/ns/terms/	20230619
lado	http://archaeology.link/ontology#	20230619
latitude	https://www.w3.org/2006/vcard/ns#	20230619
lbds	https://w3id.org/lbdserver#	20230619
lbdserver	https://w3id.org/lbdserver#	20230619
lblodlg	http://data.lblod.info/vocabularies/leidinggevenden/	20230619
lcnaf	http://id.loc.gov/authorities/names/	20230619
ld	http://linkeddata.ru/	20230619
ldc	https://tac.nist.gov/tracks/SM-KBP/2018/ontologies/SeedlingOntology#	20230619
ldes	http://w3id.org/ldes#	20230619
ldpsc	https://solid.ti.rw.fau.de/public/ns/stream-containers#	20230619
lds	https://solid.ti.rw.fau.de/public/ns/linked-data-structures#	20230619
leak	http://data.ontotext.com/resource/leak/	20230619
leaks	https://cuzin.com/	20230619
lesa	http://hadatac.org/ont/lesa#	20230619
lexicog	http://www.w3.org/ns/lemon/lexicog#	20230619
lexinfo	http://www.lexinfo.net/ontology/3.0/lexinfo#	20230619
lg	https://purl.org/lg/	20230619
lindt	http://purl.org/NET/lindt#	20230619
link	http://www.w3.org/2007/ont/link#	20230619
linkedart	https://linked.art/ns/terms/	20230619
linkedmdb	http://data.linkedmdb.org/	20230619
linkml	https://w3id.org/linkml/	20230619
lmdb	http://data.linkedmdb.org/	20230619
loci	http://linked.data.gov.au/def/loci#	20230619
lol	https://sbalot.github.io/lol/	20230619
losp	http://sparql.sstu.ru:3030/speciality/	20230619
lprov	http://id.learning-provider.data.ac.uk/terms#	20230619
lrcommon	http://landregistry.data.gov.uk/def/common/	20230619
lsqr	http://lsq.aksw.org/	20230619
luigiusai	https://www.luigiusai.it/wp#	20230619
lv2	http://lv2plug.in/ns/lv2core/	20230619
m3lite	http://purl.org/iot/vocab/m3-lite#	20230619
m4i	http://w3id.org/nfdi4ing/metadata4ing#	20230619
m8g	http://data.europa.eu/m8g/	20230619
mag	https://makg.org/property/	20230619
magmardl	http://www.semanticweb.org/magma-core/rdl#	20230619
magmauser	http://www.semanticweb.org/magma-core/user#	20230619
malaka	http://george.gr/	20230619
manto	http://com.vortic3.MANTO/	20230619
marc	http://www.loc.gov/MARC21/slim/	20230619
marcgt	https://id.loc.gov/vocabulary/marcgt/	20230619
maroc	http://fr.dbpedia.org/page/Maroc/	20230619
matmine	http://materialsmine.org/ns/	20230619
matrycs	http://matrycs.com/	20230619
matvoc	http://stream-ontology.com/matvoc/	20230619
mbkeys	https://pastebin.com/ThBfphb8#	20230619
mccv	http://purl.jp/bio/10/mccv#	20230619
mdcs	https://mdcs.monumentenkennis.nl/damageatlas/ontology#	20230619
melding	http://lblod.data.gift/vocabularies/automatische-melding/	20230619
memorix	http://memorix.io/ontology#	20230619
mesh2021	http://id.nlm.nih.gov/mesh/2021/	20230619
meta	https://krr.triply.cc/krr/sameas-meta/def/	20230619
mgv	http://mangaview.fr/mgv#	20230619
mindat	https://www.mindat.org/	20230619
misp	http://purl.org/cyber/misp#	20230619
mltd	https://mltd.pikopikopla.net/mltd-schema#	20230619
mmms	http://ldf.fi/schema/mmm/	20230619
mnx	https://rdf.metanetx.org/schema/	20230619
mobiliteit	https://data.vlaanderen.be/ns/mobiliteit#	20230619
modsci	https://w3id.org/skgo/modsci#	20230619
mondo	http://purl.obolibrary.org/obo/	20230619
motogp	http://www.motogp.com/	20230619
movieo	http://movie.com/ontology/	20230619
mpg123	https://devuan.net.br/wiki/mpg123/	20230619
mr	http://marineregions.org/ns/ontology#	20230619
mrk	http://www.mydomain.org/Mrk-ns#	20230619
mrt	http://marineregions.org/ns/placetypes#	20230619
mus	http://data.doremus.org/ontology#	20230619
mwapi	https://www.mediawiki.org/ontology#API/	20230619
nalt	https://lod.nal.usda.gov/nalt/	20230619
nanopub	http://www.nanopub.org/nschema#	20230619
nas	https://data.nasa.gov/ontologies/atmonto/NAS#	20230619
nbo	http://data.bioontology.org/ontologies/NBO/	20230619
ncbi	https://www.ncbi.nlm.nih.gov/	20230619
nen2660	https://w3id.org/nen2660/def#	20230619
nno	https://w3id.org/nno/ontology#	20230619
noise	http://vocab.linkeddata.es/datosabiertos/def/medio-ambiente/contaminacion-acustica#	20230619
nom	https://nomenclature.info/nom/	20230619
nomo	https://nomenclature.info/nom/ontology/	20230619
notify	http://www.w3.org/ns/solid/notifications#	20230619
nprl	http://data.nobelprize.org/resource/laureate/	20230619
nsd	https://w3id.org/nsd#	20230619
nsg	https://neuroshapes.org/	20230619
ntp	https://schema.finto.fi/ntp#	20230619
nutscode	http://data.europa.eu/nuts/code/	20230619
oav	http://lod.openaire.eu/vocab/	20230619
obws	http://delicias.dia.fi.upm.es/ontologies/ObjectWithStates.owl#	20230619
occ	http://w3id.org/occ#	20230619
ocds	http://purl.org/onto-ocds/ocds#	20230619
oco	https://w3id.org/oc/ontology/	20230619
ocsw	http://data.diekb.org/def/ocsw#	20230619
odf	http://docs.oasis-open.org/ns/office/1.2/meta/odf#	20230619
ods	http://lod.xdams.org/ontologies/ods/	20230619
oeo	http://openenergy-platform.org/ontology/oeo/	20230619
oeso	http://www.opensilex.org/vocabularies/oeso#	20230619
ofn	http://www.ontotext.com/sparql/functions/	20230619
ofo	https://w3id.org/ofo#	20230619
og	http://opengraphprotocol.org/schema/	20230619
ogcf	http://www.opengis.net/def/function/geosparql/	20230619
ogham	http://lod.ogham.link/data/	20230619
oghamonto	http://ontology.ogham.link/	20230619
ogura	https://sparql.crssnky.xyz/Ogura_Hyakunin_Isshu_LinkedRDF/URIs/Ogura_Hyakunin_Isshu_schema.ttl#	20230619
oidc	http://www.w3.org/ns/solid/oidc#	20230619
olias	http://purl.org/olia/system.owl#	20230619
omim	http://purl.bioontology.org/ontology/OMIM/	20230619
omnlc	http://open-multinet.info/ontology/omn-lifecycle#	20230619
omop	http://api.ohdsi.org/WebAPI/vocabulary/concept/	20230619
one	https://bioportal.bioontology.org/ontologies/ONE/	20230619
ontobras	http://www.semanticweb.org/fefar/ontologies/ontobras#	20230619
ontologia	http://ub.edu/dades/ontologia/Cinema#Cinemes#	20230619
ontouml	https://w3id.org/ontouml#	20230619
oop	http://w3id.org/oop#	20230619
oplben	http://www.openlinksw.com/ontology/benefits#	20230619
oplfeat	http://www.openlinksw.com/ontology/features#	20230619
oplsoft	http://www.openlinksw.com/ontology/software#	20230619
opltw	http://www.openlinksw.com/schemas/twitter#	20230619
ops	https://w3id.org/ops#	20230619
ordo	http://www.orpha.net/ORDO/	20230619
osdu	https://w3id.org/OSDU#	20230619
osmm	https://www.openstreetmap.org/meta/	20230619
osmnode	https://www.openstreetmap.org/node/	20230619
osmo	https://purl.org/vimmp/osmo#	20230619
osmrel	https://www.openstreetmap.org/relation/	20230619
osmt	https://wiki.openstreetmap.org/wiki/Key:	20230619
osmway	https://www.openstreetmap.org/way/	20230619
osys	http://purl.org/olia/system.owl#	20230619
otl	https://w3id.org/opentrafficlights#	20230619
oup	http://purl.org/ontology-use-patterns#	20230619
p2po	https://purl.org/p2p-o#	20230619
paam	https://lod.mediathek-tanz-theater.de/schema/paam/	20230619
paf	https://paf.link/	20230619
pair	http://virtual-assembly.org/ontologies/pair#	20230619
peco	https://w3id.org/peco#	20230619
perscido	https://perscido.univ-grenoble-alpes.fr/	20230619
persoon	http://data.vlaanderen.be/ns/persoon#	20230619
pgo	http://ii.uwb.edu.pl/pgo#	20230619
pgxo	http://pgxo.loria.fr/	20230619
pham	https://w3id.org/skgo/pham#	20230619
phto	http://rhizomik.net/ontologies/PlantHealthThreats.owl.ttl#	20230619
phy	https://w3id.org/skgo/phy#	20230619
pineapple	http://hexananas.com/pineapple#	20230619
ping	https://namso-gen.com/	20230619
pit	http://data.elsevier.com/vocabulary/ElsevierPubItemTypes/	20230619
pnv	https://w3id.org/pnv#	20230619
poke	https://pokemonkg.org/ontology#	20230619
powla	http://purl.org/powla/powla.owl#	20230619
ppeer	http://parliament.uk/ontologies/peerage/	20230619
pplan	http://purl.org/net/p-plan#	20230619
pq	http://www.wikidata.org/prop/qualifier/	20230619
premis	http://www.loc.gov/premis/rdf/v3/	20230619
prismdb	https://prismdb.takanakahiko.me/prism-schema.ttl#	20230619
probont	http://www.probonto.org/ontology#	20230619
property	http://fr.dbpedia.org/property/	20230619
proton	http://www.ontotext.com/proton/	20230619
psh	http://ns.inria.fr/probabilistic-shacl/	20230619
psys	http://proton.semanticweb.org/protonsys#	20230619
pubchem	https://pubchem.ncbi.nlm.nih.gov/	20230619
qk	http://qudt.org/vocab/quantitykind/	20230619
qkdv	http://qudt.org/vocab/dimensionvector/	20230619
qudt	http://qudt.org/schema/qudt/	20230619
quid	https://w3id.org/quid/	20230619
quran	http://khalidaloufi.sa/quran#	20230619
raad	https://raadzaam.nl/schema/	20230619
radar	http://www.radar-projekt.org/display/	20230619
rami	http://iais.fraunhofer.de/vocabs/rami#	20230619
rank	http://www.ontotext.com/owlim/RDFRank#	20230619
raum	https://terminology.fraunhofer.de/voc/raum#	20230619
rb	https://w3id.org/riverbench/schema/metadata#	20230619
rbdoc	https://w3id.org/riverbench/schema/documentation#	20230619
rc	https://w3id.org/rc#	20230619
rcgs	https://collection.rcgs.jp/terms/	20230619
rdaao	http://rdaregistry.info/Elements/a/object/	20230619
rdaed	http://rdaregistry.info/Elements/e/datatype/	20230619
rdaeo	http://rdaregistry.info/Elements/e/object/	20230619
rdaep	http://rdaregistry.info/termList/RDAExtensionPlan/	20230619
rdaid	http://rdaregistry.info/Elements/i/datatype/	20230619
rdaim	http://rdaregistry.info/termList/RDAInteractivityMode/	20230619
rdaio	http://rdaregistry.info/Elements/i/object/	20230619
rdamat	http://rdaregistry.info/termList/RDAMaterial/	20230619
rdamd	http://rdaregistry.info/Elements/m/datatype/	20230619
rdamo	http://rdaregistry.info/Elements/m/object/	20230619
rdan	http://rdaregistry.info/Elements/n/	20230619
rdand	http://rdaregistry.info/Elements/n/datatype/	20230619
rdano	http://rdaregistry.info/Elements/n/object/	20230619
rdap	http://rdaregistry.info/Elements/p/	20230619
rdapath	http://rdaregistry.info/termList/RDARecordingMethods/	20230619
rdapd	http://rdaregistry.info/Elements/p/datatype/	20230619
rdapo	http://rdaregistry.info/Elements/p/object/	20230619
rdapol	http://rdaregistry.info/termList/RDAPolarity/	20230619
rdasca	http://rdaregistry.info/termList/scale/	20230619
rdasource	http://rdaregistry.info/termList/RDARecordingSources/	20230619
rdat	http://rdaregistry.info/Elements/t/	20230619
rdatask	http://rdaregistry.info/termList/RDATasks/	20230619
rdatb	http://rdaregistry.info/termList/RDATypeOfBinding/	20230619
rdatd	http://rdaregistry.info/Elements/t/datatype/	20230619
rdato	http://rdaregistry.info/Elements/t/object/	20230619
rdaut	http://rdaregistry.info/termList/RDAUnitOfTime/	20230619
rdawd	http://rdaregistry.info/Elements/w/datatype/	20230619
rdawo	http://rdaregistry.info/Elements/w/object/	20230619
rdaxd	http://rdaregistry.info/Elements/x/datatype/	20230619
rdaxo	http://rdaregistry.info/Elements/x/object/	20230619
react	https://w3id.org/react#	20230619
refexo	http://purl.jp/bio/01/refexo#	20230619
reg	http://purl.org/linked-data/registry#	20230619
relation	http://www.iana.org/assignments/relation/	20230619
resource	http://dbpedia.org/resource/	20230619
respond	https://w3id.org/respond#	20230619
rico	https://www.ica.org/standards/RiC/ontology#	20230619
risk	https://www.w3id.org/risk#	20230619
rism	http://rism.online/	20230619
rkd	http://data.rkd.nl/def#	20230619
rl	http://rl.com/resources/	20230619
rml	http://w3id.org/rml/	20230619
rmlt	http://semweb.mmlab.be/ns/rml-target#	20230619
rnce	https://data.cultureelerfgoed.nl/id/rnce#	20230619
roar	https://w3id.org/roar#	20230619
robotarm	https://solid.ti.rw.fau.de/public/ns/robotArm#	20230619
roc	https://w3id.org/ro/curate#	20230619
rofchrda	http://rdaregistry.info/termList/rofchrda/	20230619
roffgrda	http://rdaregistry.info/termList/roffgrda/	20230619
rofitrda	http://rdaregistry.info/termList/rofitrda/	20230619
rofsfrda	http://rdaregistry.info/termList/rofsfrda/	20230619
roh	http://w3id.org/roh#	20230619
rpg	http://rpg.data.is4.site/	20230619
rro	http://semanticweb.org/patricia/ontologies/rro#	20230619
rs	http://rightsstatements.org/vocab/	20230619
rsctx	http://softeng.polito.it/rsctx#	20230619
rsp	http://www.researchspace.org/resource/	20230619
rsx	http://rdf4j.org/shacl-extensions#	20230619
rtedurp	http://purl.org/eduo/rtedurp/	20230619
rto	https://w3id.org/rail/topo#	20230619
s223	http://data.ashrae.org/standard223#	20230619
s4agri	https://saref.etsi.org/saref4agri/	20230619
s4city	https://saref.etsi.org/saref4city/	20230619
s4ee	https://w3id.org/saref4ee#	20230619
s4ener	https://saref.etsi.org/saref4ener/	20230619
s4syst	https://saref.etsi.org/saref4syst/	20230619
samian	http://lod.archaeology.link/data/samian/	20230619
saref	https://saref.etsi.org/core/	20230619
saref4envi	https://saref.etsi.org/saref4envi/	20230619
scho	http://www.scholarlydata.org/ontology/conference-ontology.owl#	20230619
schoi	https://w3id.org/scholarlydata/ontology/indicators-ontology.owl#	20230619
sct	http://snomed.info/id/	20230619
sdm	https://w3id.org/okn/o/sdm#	20230619
sdo	https://schema.org/	20230619
sds	https://w3id.org/sds#	20230619
seasd	https://w3id.org/seas/	20230619
semsur	http://purl.org/SemSur/	20230619
sense	https://w3id.org/sense#	20230619
setl	http://purl.org/twc/vocab/setl/	20230619
sfl	http://data.finlex.fi/schema/sfl/	20230619
sg	http://name.scigraph.com/ontologies/core/	20230619
she	http://shacleditor.org/	20230619
shema	http://schema.org/	20230619
shex	http://www.w3.org/ns/shex#	20230619
signify	http://purl.org/signify/ns#	20230619
sim	http://www.w3id.org/simulation/ontology/	20230619
sirext	http://t.me/sirextt/247:	20230619
skoslex	https://bp4mc2.org/def/skos-lex#	20230619
skosm	http://www.w3.org/2004/02/skos/mapping#	20230619
skosthes	http://purl.org/iso25964/skos-thes#	20230619
slm	http://urn.fi/URN:NBN:fi:au:slm:	20230619
smithy	https://awslabs.github.io/smithy/rdf-1.0#	20230619
snomedct	http://purl.bioontology.org/ontology/SNOMEDCT/	20230619
so	http://schema.org/	20230619
soall	http://sweetontology.net/sweetAll/	20230619
sohu	http://sweetontology.net/human/	20230619
sohua	http://sweetontology.net/humanAgriculture/	20230619
sohuc	http://sweetontology.net/humanCommerce/	20230619
sohud	http://sweetontology.net/humanDecision/	20230619
sohuea	http://sweetontology.net/humanEnvirAssessment/	20230619
sohueccont	http://sweetontology.net/humanEnvirControl/	20230619
sohuecons	http://sweetontology.net/humanEnvirConservation/	20230619
sohues	http://sweetontology.net/humanEnvirStandards/	20230619
sohuj	http://sweetontology.net/humanJurisdiction/	20230619
sohukd	http://sweetontology.net/humanKnowledgeDomain/	20230619
sohur	http://sweetontology.net/humanResearch/	20230619
sohut	http://sweetontology.net/humanTransportation/	20230619
sohutr	http://sweetontology.net/humanTechReadiness/	20230619
soma	http://sweetontology.net/matr/	20230619
somaae	http://sweetontology.net/matrAerosol/	20230619
somab	http://sweetontology.net/matrBiomass/	20230619
somac	http://sweetontology.net/matrCompound/	20230619
somael	http://sweetontology.net/matrElement/	20230619
somaem	http://sweetontology.net/matrElementalMolecule/	20230619
somaen	http://sweetontology.net/matrEnergy/	20230619
somaeq	http://sweetontology.net/matrEquipment/	20230619
somaf	http://sweetontology.net/matrFacility/	20230619
somaind	http://sweetontology.net/matrIndustrial/	20230619
somains	http://sweetontology.net/matrInstrument/	20230619
somaio	http://sweetontology.net/matrIon/	20230619
somais	http://sweetontology.net/matrIsotope/	20230619
somamic	http://sweetontology.net/matrMicrobiota/	20230619
somamin	http://sweetontology.net/matrMineral/	20230619
soman	http://sweetontology.net/matrAnimal/	20230619
somanr	http://sweetontology.net/matrNaturalResource/	20230619
somaoc	http://sweetontology.net/matrOrganicCompound/	20230619
somapa	http://sweetontology.net/matrParticle/	20230619
somapl	http://sweetontology.net/matrPlant/	20230619
somarock	http://sweetontology.net/matrRock/	20230619
somarocki	http://sweetontology.net/matrRockIgneous/	20230619
somas	http://sweetontology.net/matrSediment/	20230619
somaw	http://sweetontology.net/matrWater/	20230619
soph	http://sweetontology.net/phen/	20230619
sophatmo	http://sweetontology.net/phenAtmo/	20230619
sophatmoc	http://sweetontology.net/phenAtmoCloud/	20230619
sophatmofo	http://sweetontology.net/phenAtmoFog/	20230619
sophatmofr	http://sweetontology.net/phenAtmoFront/	20230619
sophatmol	http://sweetontology.net/phenAtmoLightning/	20230619
sophatmopc	http://sweetontology.net/phenAtmoPrecipitation/	20230619
sophatmops	http://sweetontology.net/phenAtmoPressure/	20230619
sophatmos	http://sweetontology.net/phenAtmoSky/	20230619
sophatmot	http://sweetontology.net/phenAtmoTransport/	20230619
sophatmow	http://sweetontology.net/phenAtmoWind/	20230619
sophatmowm	https://sweetontology.net/phenAtmoWindMesoscale/	20230619
sophb	http://sweetontology.net/phenBiol/	20230619
sophcm	http://sweetontology.net/phenCycleMaterial/	20230619
sophcr	http://sweetontology.net/phenCryo/	20230619
sophcy	http://sweetontology.net/phenCycle/	20230619
sophec	http://sweetontology.net/phenEcology/	20230619
sophei	http://sweetontology.net/phenEnvirImpact/	20230619
sophel	http://sweetontology.net/phenElecMag/	20230619
sophen	http://sweetontology.net/phenEnergy/	20230619
sophfd	http://sweetontology.net/phenFluidDynamics/	20230619
sophfi	http://sweetontology.net/phenFluidInstability/	20230619
sophft	http://sweetontology.net/phenFluidTransport/	20230619
sophg	http://sweetontology.net/phenGeol/	20230619
sophgf	http://sweetontology.net/phenGeolFault/	20230619
sophgg	http://sweetontology.net/phenGeolGeomorphology/	20230619
sophgs	http://sweetontology.net/phenGeolSeismicity/	20230619
sophgt	http://sweetontology.net/phenGeolTectonic/	20230619
sophgv	http://sweetontology.net/phenGeolVolcano/	20230619
sophhe	http://sweetontology.net/phenHelio/	20230619
sophhy	http://sweetontology.net/phenHydro/	20230619
sophm	http://sweetontology.net/phenMixing/	20230619
sopho	http://sweetontology.net/phenOcean/	20230619
sophoc	http://sweetontology.net/phenOceanCoastal/	20230619
sophod	http://sweetontology.net/phenOceanDynamics/	20230619
sophpc	http://sweetontology.net/phenPlanetClimate/	20230619
sophr	http://sweetontology.net/phenReaction/	20230619
sophso	http://sweetontology.net/phenSolid/	20230619
sophst	http://sweetontology.net/phenStar/	20230619
sophsy	http://sweetontology.net/phenSystem/	20230619
sophsyc	http://sweetontology.net/phenSystemComplexity/	20230619
sophw	http://sweetontology.net/phenWave/	20230619
sophwn	http://sweetontology.net/phenWaveNoise/	20230619
soproc	http://sweetontology.net/proc/	20230619
soprocc	http://sweetontology.net/procChemical/	20230619
soprocp	http://sweetontology.net/procPhysical/	20230619
soprocsc	http://sweetontology.net/procStateChange/	20230619
soprocw	http://sweetontology.net/procWave/	20230619
soprop	http://sweetontology.net/prop/	20230619
sopropb	http://sweetontology.net/propBinary/	20230619
sopropcap	http://sweetontology.net/propCapacity/	20230619
sopropcat	http://sweetontology.net/propCategorical/	20230619
sopropcha	http://sweetontology.net/propCharge/	20230619
sopropche	http://sweetontology.net/propChemical/	20230619
sopropcon	http://sweetontology.net/propConductivity/	20230619
sopropcou	http://sweetontology.net/propCount/	20230619
sopropdife	http://sweetontology.net/propDifference/	20230619
sopropdifu	http://sweetontology.net/propDiffusivity/	20230619
sopropdr	http://sweetontology.net/propDimensionlessRatio/	20230619
soprope	http://sweetontology.net/propEnergy/	20230619
sopropef	http://sweetontology.net/propEnergyFlux/	20230619
sopropfr	http://sweetontology.net/propFraction/	20230619
sopropfu	http://sweetontology.net/propFunction/	20230619
sopropi	http://sweetontology.net/propIndex/	20230619
sopropm	http://sweetontology.net/propMass/	20230619
sopropmf	http://sweetontology.net/propMassFlux/	20230619
sopropo	http://sweetontology.net/propOrdinal/	20230619
sopropp	http://sweetontology.net/propPressure/	20230619
sopropq	http://sweetontology.net/propQuantity/	20230619
sopropr	http://sweetontology.net/propRotation/	20230619
soprops	http://sweetontology.net/propSpace/	20230619
sopropsdir	http://sweetontology.net/propSpaceDirection/	20230619
sopropsdis	http://sweetontology.net/propSpaceDistance/	20230619
sopropsh	http://sweetontology.net/propSpaceHeight/	20230619
sopropsl	http://sweetontology.net/propSpaceLocation/	20230619
sopropsm	http://sweetontology.net/propSpaceMultidimensional/	20230619
sopropsp	http://sweetontology.net/propSpeed/	20230619
sopropst	http://sweetontology.net/propSpaceThickness/	20230619
sopropt	http://sweetontology.net/propTemperature/	20230619
soproptf	http://sweetontology.net/propTimeFrequency/	20230619
soproptg	http://sweetontology.net/propTemperatureGradient/	20230619
sopropti	http://sweetontology.net/propTime/	20230619
sorea	http://sweetontology.net/realm/	20230619
soreaa	http://sweetontology.net/realmAtmo/	20230619
soreaab	http://sweetontology.net/realmAstroBody/	20230619
soreaabl	http://sweetontology.net/realmAtmoBoundaryLayer/	20230619
soreaah	http://sweetontology.net/realmAstroHelio/	20230619
soreaas	http://sweetontology.net/realmAstroStar/	20230619
soreaaw	http://sweetontology.net/realmAtmoWeather/	20230619
soreabb	http://sweetontology.net/realmBiolBiome/	20230619
soreac	http://sweetontology.net/realmCryo/	20230619
soreacz	http://sweetontology.net/realmClimateZone/	20230619
soreaer	http://sweetontology.net/realmEarthReference/	20230619
soreahb	http://sweetontology.net/realmHydroBody/	20230619
soreal	http://sweetontology.net/realmLandform/	20230619
soreala	http://sweetontology.net/realmLandAeolian/	20230619
sorealc	http://sweetontology.net/realmLandCoastal/	20230619
sorealf	http://sweetontology.net/realmLandFluvial/	20230619
sorealg	http://sweetontology.net/realmLandGlacial/	20230619
sorealo	http://sweetontology.net/realmLandOrographic/	20230619
sorealp	http://sweetontology.net/realmLandProtected/	20230619
sorealt	http://sweetontology.net/realmLandTectonic/	20230619
sorealv	http://sweetontology.net/realmLandVolcanic/	20230619
soreao	http://sweetontology.net/realmOcean/	20230619
soreaofe	http://sweetontology.net/realmOceanFeature/	20230619
soreaofl	http://sweetontology.net/realmOceanFloor/	20230619
sorear	http://sweetontology.net/realmRegion/	20230619
soreas	http://sweetontology.net/realmSoil/	20230619
sorel	http://sweetontology.net/rela/	20230619
sorelch	http://sweetontology.net/relaChemical/	20230619
sorelcl	http://sweetontology.net/relaClimate/	20230619
sorelh	http://sweetontology.net/relaHuman/	20230619
sorelm	http://sweetontology.net/relaMath/	20230619
sorelph	http://sweetontology.net/relaPhysical/	20230619
sorelpr	http://sweetontology.net/relaProvenance/	20230619
sorelsc	http://sweetontology.net/relaSci/	20230619
sorelsp	http://sweetontology.net/relaSpace/	20230619
sorelt	http://sweetontology.net/relaTime/	20230619
sorep	http://sweetontology.net/repr/	20230619
sorepdf	http://sweetontology.net/reprDataFormat/	20230619
sorepdm	http://sweetontology.net/reprDataModel/	20230619
sorepdp	http://sweetontology.net/reprDataProduct/	20230619
sorepds	http://sweetontology.net/reprDataService/	20230619
sorepdsa	http://sweetontology.net/reprDataServiceAnalysis/	20230619
sorepdsg	http://sweetontology.net/reprDataServiceGeospatial/	20230619
sorepdsr	http://sweetontology.net/reprDataServiceReduction/	20230619
sorepdsv	http://sweetontology.net/reprDataServiceValidation/	20230619
sorepm	http://sweetontology.net/reprMath/	20230619
sorepmf	http://sweetontology.net/reprMathFunction/	20230619
sorepmfo	http://sweetontology.net/reprMathFunctionOrthogonal/	20230619
sorepmg	http://sweetontology.net/reprMathGraph/	20230619
sorepmo	http://sweetontology.net/reprMathOperation/	20230619
sorepmso	http://sweetontology.net/reprMathSolution/	20230619
sorepmst	http://sweetontology.net/reprMathStatistics/	20230619
soreps	http://sweetontology.net/reprSpace/	20230619
sorepsc	http://sweetontology.net/reprSciComponent/	20230619
sorepscd	http://sweetontology.net/reprSpaceCoordinate/	20230619
sorepsd	http://sweetontology.net/reprSpaceDirection/	20230619
sorepsf	http://sweetontology.net/reprSciFunction/	20230619
sorepsg3	http://sweetontology.net/reprSpaceGeometry3D/	20230619
sorepsl	http://sweetontology.net/reprSciLaw/	20230619
sorepsme	http://sweetontology.net/reprSciMethodology/	20230619
sorepsmo	http://sweetontology.net/reprSciModel/	20230619
sorepsp	http://sweetontology.net/reprSciProvenance/	20230619
sorepsrs	http://sweetontology.net/reprSpaceReferenceSystem/	20230619
sorepsu	http://sweetontology.net/reprSciUnits/	20230619
sorept	http://sweetontology.net/reprTime/	20230619
soreptd	http://sweetontology.net/reprTimeDay/	20230619
sorepts	http://sweetontology.net/reprTimeSeason/	20230619
sost	http://sweetontology.net/state/	20230619
sostb	http://sweetontology.net/stateBiological/	20230619
sostc	http://sweetontology.net/stateChemical/	20230619
sostdp	http://sweetontology.net/stateDataProcessing/	20230619
sostef	http://sweetontology.net/stateEnergyFlux/	20230619
sostf	http://sweetontology.net/stateFluid/	20230619
sosto	http://sweetontology.net/stateOrdinal/	20230619
sostp	http://sweetontology.net/statePhysical/	20230619
sostrb	http://sweetontology.net/stateRoleBiological/	20230619
sostrc	http://sweetontology.net/stateRoleChemical/	20230619
sostre	http://sweetontology.net/stateRealm/	20230619
sostrg	http://sweetontology.net/stateRoleGeographic/	20230619
sostri	http://sweetontology.net/stateRoleImpact/	20230619
sostro	http://sweetontology.net/stateRole/	20230619
sostrr	http://sweetontology.net/stateRoleRepresentative/	20230619
sostrt	http://sweetontology.net/stateRoleTrust/	20230619
sostsb	http://sweetontology.net/stateSpectralBand/	20230619
sostsc	http://sweetontology.net/stateSpaceConfiguration/	20230619
sostsl	http://sweetontology.net/stateSpectralLine/	20230619
sostso	http://sweetontology.net/stateSolid/	20230619
sostsp	http://sweetontology.net/stateSpace/	20230619
sostss	http://sweetontology.net/stateSpaceScale/	20230619
sostst	http://sweetontology.net/stateStorm/	20230619
sostsy	http://sweetontology.net/stateSystem/	20230619
sosttc	http://sweetontology.net/stateTimeCycle/	20230619
sosttf	http://sweetontology.net/stateTimeFrequency/	20230619
sosttg	http://sweetontology.net/stateTimeGeologic/	20230619
sostth	http://sweetontology.net/stateThermodynamic/	20230619
sostti	http://sweetontology.net/stateTime/	20230619
sostv	http://sweetontology.net/stateVisibility/	20230619
sou	http://qudt.org/vocab/sou/	20230619
spatialf	http://jena.apache.org/function/spatial#	20230619
spec	http://www.w3.org/ns/spec#	20230619
sport	http://purl.org/ontology/sport/	20230619
spvqa	https://bmake.th-brandenburg.de/spv#	20230619
srmo	https://w3id.org/srmo#	20230619
srr	https://w3id.org/srr#	20230619
srt	http://w3id.org/srt#	20230619
srtun	https://www.inf.bi.rub.de/srtun#	20230619
srv	http://www.daml.org/services/owl-s/1.2/Service.owl#	20230619
ssnx	http://purl.oclc.org/NET/ssnx/ssn#	20230619
st	http://ns.inria.fr/sparql-template/	20230619
stat	http://www.w3.org/ns/posix/stat#	20230619
status	http://www.w3.org/2003/06/sw-vocab-status/ns#	20230619
stencila	http://schema.stenci.la/	20230619
stirdata	https://w3id.org/stirdata/vocabulary/	20230619
stix	http://purl.org/cyber/stix#	20230619
stx	http://purl.org/cyber/stix#	20230619
sty	http://purl.bioontology.org/ontology/STY/	20230619
summa	http://purl.org/voc/summa/	20230619
sure	http://ns.inria.fr/sure#	20230619
swa	http://topbraid.org/swa#	20230619
sweet	http://sweetontology.net/	20230619
taxref	http://taxref.mnhn.fr/lod/taxon/	20230619
taxrefprop	http://taxref.mnhn.fr/lod/property/	20230619
tb	https://w3id.org/timebank#	20230619
tci	https://w3id.org/lbs/tci#	20230619
td	https://www.w3.org/2019/wot/td#	20230619
tempo	http://purl.org/tempo/	20230619
terms	http://purl.org/dc/terms/	20230619
tern	http://w3id.org/tern/ontologies/tern/	20230619
test	http://test.example.com/	20230619
textgrid	https://textgridrep.org/	20230619
tg	https://triplydb.com/Triply/tg/def/	20230619
threat	https://cve.mitre.org/	20230619
thub	http://vocabularis.crai.ub.edu/thub/	20230619
toaru	https://metadata.moe/toaru-sparql/elements/	20230619
tp	https://triplydb.com/Triply/tp/def/	20230619
trak	https://trakmetamodel.sourceforge.io/vocab/rdf-schema.rdf#	20230619
trao	http://linkeddata.finki.ukim.mk/lod/ontology/tao#	20230619
tree	https://w3id.org/tree#	20230619
trek	https://w3id.org/trek/	20230619
tro	https://w3id.org/TRO/	20230619
tso	https://w3id.org/tso#	20230619
tsso	https://scch.org/technical_standards#	20230619
ttrpg	https://w3id.org/TTRpg#	20230619
uberon	http://purl.obolibrary.org/obo/UBERON_	20230619
ucum	http://purl.oclc.org/NET/muo/ucum/	20230619
ufo	http://ufo.com/#	20230619
uimo	http://vocab.sti2.at/uimo/	20230619
ul	http://underlay.mit.edu/ns/	20230619
ultragaz	https://ultragaz24horas.com/	20230619
unit	http://qudt.org/vocab/unit/	20230619
univ	http://univ.io/	20230619
up	http://purl.uniprot.org/core/	20230619
url	http://schema.org/	20230619
value	http://gfgfd.vs/	20230619
vcs	https://data.vlaanderen.be/ns/chemische_stof#	20230619
veelana	http://onlyfans.com/veelana/	20230619
veo	http://linkeddata.finki.ukim.mk/lod/ontology/veo#	20230619
version	https://version.link/	20230619
vhbieo	https://w3id.org/vhbieo#	20230619
viaf	http://viaf.org/viaf/	20230619
vir	http://w3id.org/vir#	20230619
vl	https://version.link/	20230619
vlueprint	https://vlueprint.org/schema/	20230619
vntourism	http://www.semanticweb.org/minhn/ontologies/2021/0/vntourism#	20230619
vocals	http://w3id.org/rsp/vocals#	20230619
vph	http://purl.org/ozo/vph.owl#	20230619
vr	https://www.w3.org/2018/credentials/v1/	20230619
vra	http://purl.org/vra/	20230619
w3geo	http://www.w3.org/2003/01/geo/wgs84_pos#	20230619
w3id	https://w3id.org/	20230619
waa	http://purl.oclc.org/NET/WebApiAuthentication#	20230619
walmart	https://www.amazon.de/	20230619
wasa	http://vocab.sti2.at/wasa/	20230619
wdno	http://www.wikidata.org/prop/novalue/	20230619
wds	http://www.wikidata.org/entity/statement/	20230619
wdtn	http://www.wikidata.org/prop/direct-normalized/	20230619
weki	https://en.wikipedia.org/wiki/	20230619
wfont	https://w3id.org/wfont#	20230619
wikipedia	https://en.wikipedia.org/wiki/	20230619
wild	http://purl.org/wild/vocab#	20230619
won	https://w3id.org/won/core#	20230619
wotc	http://purl.org/wot-catalogue#	20230619
wotsec	https://www.w3.org/2019/wot/security#	20230619
xapi	https://w3id.org/xapi/ontology#	20230619
xbrll	https://w3id.org/vocab/xbrll#	20230619
xmlns	http://xmlns.com/foaf/0.1/	20230619
xyz	http://sparql.xyz/facade-x/data/	20230619
yandex	http://yandex.ru/	20230619
yanice	http://yanice-boady.webflow.io/	20230619
